@@ -27,7 +27,7 @@
 	(do ((n 0 (+ n 1)))
 	    ((= n (+ L M)))
 	  (let ((sum 0.0)
-		(start (max 0 (- n (+ L 1))))
+		(start (max 0 (- n L 1)))
 		(end (min n M)))
 	    (do ((m start (+ m 1)))
 		((> m end))
@@ -48,48 +48,49 @@
 	 (j 0 (+ j 3))
 	 (k 0 (+ k 4)))
 	((>= i n))
-      (let* ((nt0 (/ (num (+ j 0)) (* wc wc)))
+      (let* ((nt0 (/ (num j) (* wc wc)))
 	     (nt1 (/ (num (+ j 1)) wc))
 	     (nt2 (num (+ j 2)))
-	     (dt0 (/ (den (+ j 0)) (* wc wc)))
+	     (dt0 (/ (den j) (* wc wc)))
 	     (dt1 (/ (den (+ j 1)) (* wc Q)))
 	     (dt2 (den (+ j 2)))
 	     (kd (+ dt0 dt1 dt2))
 	     (kn (+ nt0 nt1 nt2)))
 	(set! (c    k   ) (/ (- (* 2.0 dt2) (* 2.0 dt0)) kd))
-	(set! (c (+ k 1)) (/ (+ dt0 (- dt1) dt2) kd))
+	(set! (c (+ k 1)) (/ (- (+ dt0 dt2) dt1) kd))
 	(set! (c (+ k 2)) (/ (- (* 2.0 nt2) (* 2.0 nt0)) kn))
-	(set! (c (+ k 3)) (/ (+ nt0 (- nt1) nt2) kn))
+	(set! (c (+ k 3)) (/ (- (+ nt0 nt2) nt1) kn))
 	(set! g (* g (/ kn kd)))))
     
-    (let ((a ())
-	  (b ()))
-      (do ((i 0 (+ i 2))
-	   (k 0 (+ k 4))) ; c
-	  ((>= i n))
-	(set! a (cons (float-vector (c (+ k 3)) (c (+ k 2)) (c (+ k 3))) a))
-	(set! b (cons (float-vector 1.0 (c k) (c (+ k 1))) b)))
+    (do ((a ())
+	 (b ())
+	 (i 0 (+ i 2))
+	 (k 0 (+ k 4))) ; c
+	((>= i n)
+	 (list (float-vector-scale! (cascade->canonical a) g) ; scale entire numerator because this is the convolved form
+	       (cascade->canonical b)))
+      (set! a (cons (float-vector (c (+ k 3)) (c (+ k 2)) (c (+ k 3))) a))
+      (set! b (cons (float-vector 1.0 (c k) (c (+ k 1))) b)))))
       
-      (list (float-vector-scale! (cascade->canonical a) g) ; scale entire numerator because this is the convolved form
-	    (cascade->canonical b)))))
 
-(define (prototype->highpass n num den)
-  (let ((g 1.0)
-	(numt (make-float-vector (length num)))
-	(dent (make-float-vector (length den))))
-    (do ((k 0 (+ k 2))
+(define (prototype->highpass n proto)
+  (let ((num (car proto))
+	(den (cadr proto)))
+    (do ((g 1.0)
+	 (numt (make-float-vector (length num)))
+	 (dent (make-float-vector (length den)))
+	 (k 0 (+ k 2))
 	 (i 0 (+ i 3)))
-	((>= k n)) 
+	((>= k n)
+	 (set! (numt 0) g)
+	 (list numt dent))
       (set! g (* g (/ (num (+ i 2)) (den (+ i 2)))))
       (set! (numt    i   ) 1.0)
       (set! (numt (+ i 1)) (/ (num (+ i 1)) (num (+ i 2))))
       (set! (numt (+ i 2)) (/ (num i) (num (+ i 2))))
       (set! (dent    i   ) 1.0)
       (set! (dent (+ i 1)) (/ (den (+ i 1)) (den (+ i 2))))
-      (set! (dent (+ i 2)) (/ (den i) (den (+ i 2)))))
-    (set! (numt 0) g)
-    (list numt dent)))
-
+      (set! (dent (+ i 2)) (/ (den i) (den (+ i 2)))))))
 
 
 ;;; ---------------- Butterworth ----------------
@@ -125,7 +126,7 @@ freq (srate = 1.0): (make-butterworth-highpass 8 .1)"))
     (lambda (n fc)
       (if (odd? n) (set! n (+ n 1)))
       (let* ((proto (butterworth-prototype n))
-	     (hproto (prototype->highpass n (car proto) (cadr proto)))
+	     (hproto (prototype->highpass n proto))
 	     (coeffs (analog->digital n (car hproto) (cadr hproto) fc)))
 	(make-filter :xcoeffs (car coeffs) :ycoeffs (cadr coeffs))))))
 
@@ -159,11 +160,11 @@ are (1.0-based) edge freqs: (make-butterworth-bandstop 4 .1 .2)"))
 	 (len (/ (* n 3) 2))
 	 (num (make-float-vector len))
 	 (den (make-float-vector len)))
-    (do ((l 1.0 (+ l 2.0))
+    (do ((k 1.0 (+ k 2.0))
 	 (j 0 (+ j 3)))
-	((>= l n))
-      (let ((u (- (* (sinh v0) (sin (/ (* l pi) (* 2.0 n))))))
-	    (w (* (cosh v0) (cos (/ (* l pi) (* 2.0 n))))))
+	((>= k n))
+      (let ((u (- (* (sinh v0) (sin (/ (* k pi) (* 2.0 n))))))
+	    (w (* (cosh v0) (cos (/ (* k pi) (* 2.0 n))))))
 	(set! (num    j   ) 0.0)
 	(set! (num (+ j 1)) 0.0)
 	(set! (num (+ j 2)) 1.0)
@@ -189,7 +190,7 @@ fc = cutoff freq (srate = 1.0): (make-chebyshev-highpass 8 .1 .01)"))
     (lambda* (n fc (ripple 1.0))
       (if (odd? n) (set! n (+ n 1)))
       (let* ((proto (chebyshev-prototype n ripple))
-	     (hproto (prototype->highpass n (car proto) (cadr proto)))
+	     (hproto (prototype->highpass n proto))
 	     (coeffs (analog->digital n (car hproto) (cadr hproto) fc)))
 	(make-filter :xcoeffs (car coeffs) :ycoeffs (cadr coeffs))))))
 
@@ -223,19 +224,19 @@ fl and fh = edge freqs (srate = 1.0): (make-chebyshev-bandstop 8 .1 .4 .01)"))
 	 (len (/ (* n 3) 2))
 	 (num (make-float-vector len))
 	 (den (make-float-vector len)))
-    (let ((pl 0.0))
-      (do ((l 1.0 (+ l 2.0))
-	   (j 0 (+ j 3)))
-	  ((>= l n))
-	(let ((u (- (* (sinh v0) (sin (/ (* l pi) (* 2.0 n))))))
-	      (w (* (cosh v0) (cos (/ (* l pi) (* 2.0 n)))))
-	      (t (/ 1.0 (sin (/ (* (+ l pl) pi) (* 2.0 n))))))
-	  (set! (num    j   ) 1.0)
-	  (set! (num (+ j 1)) 0.0)
-	  (set! (num (+ j 2)) (* t t))
-	  (set! (den    j   ) 1.0)
-	  (set! (den (+ j 1)) (/ (* -2.0 u) (+ (* u u) (* w w))))
-	  (set! (den (+ j 2)) (/ 1.0 (+ (* u u) (* w w)))))))
+    (do ((pl 0.0)
+	 (L 1.0 (+ L 2.0))
+	 (j 0 (+ j 3)))
+	((>= L n))
+      (let ((u (- (* (sinh v0) (sin (/ (* L pi) (* 2.0 n))))))
+	    (w (* (cosh v0) (cos (/ (* L pi) (* 2.0 n)))))
+	    (t (/ 1.0 (sin (/ (* (+ L pl) pi) (* 2.0 n))))))
+	(set! (num    j   ) 1.0)
+	(set! (num (+ j 1)) 0.0)
+	(set! (num (+ j 2)) (* t t))
+	(set! (den    j   ) 1.0)
+	(set! (den (+ j 1)) (/ (* -2.0 u) (+ (* u u) (* w w))))
+	(set! (den (+ j 2)) (/ 1.0 (+ (* u u) (* w w))))))
     (list num den
 	  (expt 1.122 (- loss-dB))))) ; argh
 
@@ -254,7 +255,7 @@ fc = cutoff freq (srate = 1.0): (make-inverse-chebyshev-highpass 10 .1 120)"))
     (lambda* (n fc (loss-dB 60.0))
       (if (odd? n) (set! n (+ n 1)))
       (let* ((proto (inverse-chebyshev-prototype n loss-dB))
-	     (hproto (prototype->highpass n (car proto) (cadr proto)))
+	     (hproto (prototype->highpass n proto))
 	     (coeffs (analog->digital n (car hproto) (cadr hproto) fc)))
 	(make-filter :xcoeffs (float-vector-scale! (car coeffs) (caddr proto)) :ycoeffs (cadr coeffs))))))
 
@@ -282,33 +283,34 @@ fl and fh are edge freqs (srate=1.0): (make-inverse-chebyshev-bandstop 8 .1 .4 9
 
 (define (bessel-prototype n)
   
-  (define (fact n)
-    (let ((x 1))
-      (do ((i 2 (+ i 1)))
-	  ((> i n))
-	(set! x (* x i)))
-      x))
-					; this form overflows if we don't have bignums
-					;  (define (bessel-i n)
-					;    (let ((cs (make-float-vector (+ n 1))))
-					;      (do ((i 0 (+ i 1)))
-					;	  ((> i n))
-					;	(set! (cs i) (/ (fact (- (* 2 n) i))
-					;			(* (expt 2 (- n i))
-					;			   (fact i)
-					;			   (fact (- n i))))))
-					;      cs))
   (define (bessel-i n)
-    (let ((cs (make-float-vector (+ n 1))))
-      (do ((i 0 (+ i 1)))
-	  ((> i n))
-	(let ((val (/ 1.0 (* (fact i) (expt 2 (- n i))))))
-	  (do ((k 1 (+ k 1))
-	       (f (- n i -1) (+ f 1)))  ; (f (+ 1 (- n i)) (+ 1 f))
-	      ((> k n))
-	    (set! val (* val f)))
-	  (set! (cs i) val)))
-      cs))
+
+    (define (fact n)
+      (let ((x 1))
+	(do ((i 2 (+ i 1)))
+	    ((> i n))
+	  (set! x (* x i)))
+	x))
+    ;; this form overflows if we don't have bignums
+    ;;  (define (bessel-i n)
+    ;;    (let ((cs (make-float-vector (+ n 1))))
+    ;;      (do ((i 0 (+ i 1)))
+    ;;	  ((> i n))
+    ;;	(set! (cs i) (/ (fact (- (* 2 n) i))
+    ;;			(* (expt 2 (- n i))
+    ;;			   (fact i)
+    ;;			   (fact (- n i))))))
+    ;;      cs))
+    
+    (do ((cs (make-float-vector (+ n 1)))
+	 (i 0 (+ i 1)))
+	((> i n) cs)
+      (do ((val (/ 1.0 (* (fact i) (expt 2 (- n i)))))
+	   (k 1 (+ k 1))
+	   (f (- n i -1) (+ f 1)))  ; (f (+ 1 (- n i)) (+ 1 f))
+	  ((> k n)
+	   (set! (cs i) val))   
+	(set! val (* val f)))))
   
   (let* ((len (/ (* n 3) 2))
 	 (num (make-float-vector len))
@@ -342,7 +344,7 @@ fl and fh are edge freqs (srate=1.0): (make-inverse-chebyshev-bandstop 8 .1 .4 9
     (lambda* (n fc)
       (if (odd? n) (set! n (+ n 1)))
       (let* ((proto (bessel-prototype n))
-	     (hproto (prototype->highpass n (car proto) (cadr proto)))
+	     (hproto (prototype->highpass n proto))
 	     (coeffs (analog->digital n (car hproto) (cadr hproto) fc)))
 	(make-filter :xcoeffs (car coeffs) :ycoeffs (cadr coeffs))))))
 
@@ -376,12 +378,12 @@ fl and fh are edge freqs (srate=1.0): (make-inverse-chebyshev-bandstop 8 .1 .4 9
 	   (fx (f xmin arg1 arg2)))
       (do ((i 0 (+ i 1)))
 	  ((= i n))
-	(let ((step (/ (- xmax xmin) (- n 1.0))))
-	  (do ((j 0 (+ j 1))
-	       (s xmin (+ s step)))
-	      ((= j (- n 1)))
-	    (float-vector-set! x j s))
-	  (set! (x (- n 1)) xmax))
+	(do ((step (/ (- xmax xmin) (- n 1.0)))
+	     (j 0 (+ j 1))
+	     (s xmin (+ s step)))
+	    ((= j (- n 1)))
+	  (float-vector-set! x j s))
+	(set! (x (- n 1)) xmax)
 	(do ((j 0 (+ j 1)))
 	    ((= j n))
 	  (let ((ft (f (x j) arg1 arg2)))
@@ -402,17 +404,17 @@ fl and fh are edge freqs (srate=1.0): (make-inverse-chebyshev-bandstop 8 .1 .4 9
   (let* ((e (sqrt (- (expt 10.0 (* 0.1 ripple)) 1.0)))
 	 (k1 (/ e (sqrt (- (expt 10.0 (* 0.1 loss-dB)) 1.0))))
 	 (k1p (sqrt (- 1.0 (* k1 k1))))
-	 (kr 0.0)
 	 (m 0.0)
 	 (k 0.0)
 	 (len (/ (* n 3) 2))
 	 (num (make-float-vector len))
 	 (den (make-float-vector len))
-	 (g 1.0)
-	 (eps 0.0000001))
-    (if (> (abs (- 1.0 (* k1p k1p))) eps)
-	(set! kr (* n (/ (gsl-ellipk (* k1 k1)) (gsl-ellipk (* k1p k1p))))))
-    (set! m (minimize-function findm 0.001 0.999 kr))
+	 (g 1.0))
+    (let ((eps 0.0000001)
+	  (kr 0.0))
+      (if (> (abs (- 1.0 (* k1p k1p))) eps)
+	  (set! kr (* n (/ (gsl-ellipk (* k1 k1)) (gsl-ellipk (* k1p k1p))))))
+      (set! m (minimize-function findm 0.001 0.999 kr)))
     (set! k (gsl-ellipk m))
     (let ((cv (make-float-vector (floor (* 0.5 3 (+ n 1))))))
       (do ((i 0 (+ i 2))
@@ -431,9 +433,7 @@ fl and fh are edge freqs (srate=1.0): (make-inverse-chebyshev-bandstop 8 .1 .4 9
 	    (set! (num    j   ) 1.0)
 	    (set! (num (+ j 1)) (* -2.0 (real-part z)))
 	    (set! (num (+ j 2)) pz))))
-      (let* ((optarg0 (* k1p k1p))
-	     (optarg1 (/ 1.0 e))
-	     (minf (minimize-function findv 0.0 (/ 1.0 e) optarg0 optarg1))
+      (let* ((minf (minimize-function findv 0.0 (/ 1.0 e) (* k1p k1p) (/ 1.0 e)))
 	     (v0 (/ (* k minf)
 		    (* n (gsl-ellipk (* k k1)))))
 	     (vals (gsl-ellipj v0 (- 1.0 m)))
@@ -443,15 +443,15 @@ fl and fh are edge freqs (srate=1.0): (make-inverse-chebyshev-bandstop 8 .1 .4 9
 	(do ((i 0 (+ i 2))
 	     (j 0 (+ j 3)))
 	    ((>= i n))
-	  (let ((p (/ (- (+ (* (cv (+ j 1)) (cv (+ j 2)) sn cn)
-			    (* 0.0+i (cv j) dn)))
-		      (- 1.0 (* (cv (+ j 2)) sn
-				(cv (+ j 2)) sn)))))
-	    (let ((pp (real-part (* p (complex (real-part p) (- (imag-part p)))))))
-	      (set! g (* g pp))
-	      (set! (den    j   ) 1.0)
-	      (set! (den (+ j 1)) (* -2.0 (real-part p)))
-	      (set! (den (+ j 2)) pp))))))
+	  (let* ((p (/ (- (+ (* (cv (+ j 1)) (cv (+ j 2)) sn cn)
+			     (* 0.0+i (cv j) dn)))
+		       (- 1.0 (* (cv (+ j 2)) sn
+				 (cv (+ j 2)) sn))))
+		 (pp (real-part (* p (complex (real-part p) (- (imag-part p)))))))
+	    (set! g (* g pp))
+	    (set! (den    j   ) 1.0)
+	    (set! (den (+ j 1)) (* -2.0 (real-part p)))
+	    (set! (den (+ j 2)) pp)))))
     (set! g (abs (/ g (sqrt (+ 1.0 (* e e))))))
     (list num den g)))
 
@@ -470,7 +470,7 @@ fc = cutoff freq (srate = 1.0): (make-elliptic-highpass 8 .25 .01 90)"))
     (lambda* (n fc (ripple 1.0) (loss-dB 60.0))
       (if (odd? n) (set! n (+ n 1)))
       (let* ((proto (elliptic-prototype n ripple loss-dB))
-	     (hproto (prototype->highpass n (car proto) (cadr proto)))
+	     (hproto (prototype->highpass n proto))
 	     (coeffs (analog->digital n (car hproto) (cadr hproto) fc)))
 	(make-filter :xcoeffs (float-vector-scale! (car coeffs) (caddr proto)) :ycoeffs (cadr coeffs))))))
 
