@@ -51,7 +51,7 @@
 	(do ((i 0 (+ i 1)))
 	    ((= i *clm-rt-bufsize*))
 	  (set! (data i) (func)))
-	(mus-audio-write *output* (copy data (make-float-vector (list 1 *clm-rt-bufsize*) 0.0)) *clm-rt-bufsize*)
+	(mus-audio-write *output* (copy data (make-float-vector (list 1 *clm-rt-bufsize*))) *clm-rt-bufsize*)
 	#f)
       (begin
 	(mus-audio-close *output*)
@@ -118,24 +118,21 @@
 		  (if (> (random 1.0) 0.5) (set! cellsiz (+ 1 cellsiz)))
 		  (set! cellctr cellbeg)))
 
-	    (format () "dur: ~A, freq: ~A, amp: ~A, index: ~A~%"
-		    dur
-		    (let ((freq (* cfreq 16.351 16
-				   (expt 2 (/ (vmode (vpits cellctr))
-					      12.0)))))
+	    (let ((freq (* cfreq 16.351 16
+			   (expt 2 (/ (vmode (vpits cellctr)) 12.0)))))
+	      (format () "dur: ~A, freq: ~A, amp: ~A, index: ~A~%"
+		      dur
 		      (if (< (* 8 freq) *clm-srate*)
 			  freq
-			  (/ freq 4)))
-		    (* camp 0.3) cindex)
+			  (/ freq 4))
+		      (* camp 0.3) 
+		      cindex)
 
-	    (set! func (make-rt-violin dur
-				       (let ((freq (* cfreq 16.351 16
-						      (expt 2 (/ (vmode (vpits cellctr))
-								 12.0)))))
+	      (set! func (make-rt-violin dur
 					 (if (< (* 8 freq) *clm-srate*)
 					     freq
-					     (/ freq 4)))
-				       (* camp 0.3) :fm-index cindex))
+					     (/ freq 4))
+					 (* camp 0.3) :fm-index cindex)))
 	    (set! len (ceiling (/ (seconds->samples dur) bufsize)))))
       func)))
 
@@ -262,8 +259,7 @@
 	 (app (cadr shell-app))
 	 (shell (car shell-app))
 	 (dpy (XtDisplay shell))
-	 (screen (DefaultScreenOfDisplay dpy))
-	 (black (BlackPixelOfScreen screen)))
+	 (black (BlackPixelOfScreen (DefaultScreenOfDisplay dpy))))
 
     (define (get-color color)
       (let ((col (XColor))
