@@ -6,8 +6,7 @@
 (define goertzel-channel
   (let ((documentation "(goertzel-channel freq beg dur snd (chn 0)) returns the amplitude of the 'freq' spectral component"))
     (lambda* (freq (beg 0) dur snd chn)
-      (let* ((sr (srate snd))
-	     (rfreq (/ (* 2.0 pi freq) sr))
+      (let* ((rfreq (/ (* 2.0 pi freq) (srate snd)))
 	     (cs (* 2.0 (cos rfreq))))
 	(let ((reader (make-sampler beg snd chn))
 	      (len (- (if (number? dur) dur (- (framples snd chn) beg)) 2))
@@ -21,12 +20,12 @@
 
 
 (define* (check-freq freq snd chn)
-  (let ((hum 0.0))
-    (do ((i 0 (+ i 1))
-	 (loc 0.0 (+ loc (round (/ (framples snd chn) 5)))))
-	((= i 4))
-      (set! hum (+ hum (goertzel-channel freq loc 2048 snd chn))))
-    (/ hum 4.0)))
+  (do ((hum 0.0)
+       (i 0 (+ i 1))
+       (loc 0.0 (+ loc (round (/ (framples snd chn) 5)))))
+      ((= i 4)
+       (/ hum 4.0))
+    (set! hum (+ hum (goertzel-channel freq loc 2048 snd chn)))))
 
 
 ;;; -------- single sample clicks
@@ -39,7 +38,7 @@
 	 (samp2 0.0)
 	 (fixed 0)
 	 (len (framples snd chn))
-	 (block-size (min len (* 1024 1024))) ; do edits by blocks rather than sample-at-a-time (saves time, memory etc)
+	 (block-size (min len 1048576)) ; do edits by blocks rather than sample-at-a-time (saves time, memory etc) 1048576=1024*1024
 	 (block-ctr 0)
 	 (block-beg 0)
 	 (block (make-float-vector block-size))
@@ -73,7 +72,7 @@
 		 (begin
 		   (float-vector->channel block block-beg block-size snd chn)
 		   (set! block-changed #f)))
-	     (set! block-beg (+ block-beg (- block-size 1)))
+	     (set! block-beg (- (+ block-beg block-size) 1))
 	     (set! block-ctr 1)
 	     (set! (block 0) samp2))))
      (if block-changed
@@ -93,7 +92,7 @@
       (let ((mx (maxamp))
 	    (loc (maxamp-position)))
 	(if (> mx 0.06)
-	    (format #t "~%;remove-single-sample-clicks 0: ~A (at ~D)" mx loc)))
+	    (format () "~%;remove-single-sample-clicks 0: ~A (at ~D)" mx loc)))
       (revert-sound)
       (do ((i 0 (+ i 1))
 	   (ang 0.0 (+ ang .01)))
@@ -102,7 +101,7 @@
       (float-vector->channel data)
       (remove-single-sample-clicks)
       (if (fneq (maxamp) .2)
-	  (format #t "~%;remove-single-sample-clicks sin max: ~A" (maxamp)))
+	  (format () "~%;remove-single-sample-clicks sin max: ~A" (maxamp)))
       (let ((cur-data (channel->float-vector 0))
 	    (diff 0.0))
 	(do ((i 0 (+ i 1))
@@ -110,7 +109,7 @@
 	    ((= i 1000))
 	  (set! diff (max diff (abs (- ( cur-data i) (* .2 (sin ang)))))))
 	(if (> diff .2)
-	    (format #t "~%;remove-single-sample-clicks sine max diff: ~A" diff))))
+	    (format () "~%;remove-single-sample-clicks sine max diff: ~A" diff))))
     (close-sound test)))
 
 ;;; -------- pops
@@ -143,7 +142,7 @@
 	 (len (framples snd chn))
 
 	 (pad (* 8 size))
-	 (block-size (min (+ len pad) (* 1024 1024)))
+	 (block-size (min (+ len pad) 1048576)) ; 1048576=1024*1024
 	 (block-ctr 0)
 	 (block-beg 0)
 	 (block (make-float-vector block-size))
@@ -158,14 +157,12 @@
        (do ((ctr 0 (+ ctr 1)))
 	   ((= ctr len))
 	 (let* ((ahead-samp (next-sample reader))
-		(diff-ahead (abs (- ahead-samp last-ahead-samp)))
-		(avg-ahead (moving-average mx-ahead diff-ahead))
+		(avg-ahead (moving-average mx-ahead (abs (- ahead-samp last-ahead-samp))))
 		(dly0-samp (delay dly0 ahead-samp))
 		(cur-diff (abs (- dly0-samp last-dly0-samp)))
 		(cur-avg (moving-average mx cur-diff))
 		(dly1-samp (delay dly1 ahead-samp))
-		(diff-behind (abs (- dly1-samp last-dly1-samp)))
-		(avg-behind (moving-average mx-behind diff-behind)))
+		(avg-behind (moving-average mx-behind (abs (- dly1-samp last-dly1-samp)))))
 	   (set! last-ahead-samp ahead-samp)
 	   (set! last-dly0-samp dly0-samp)
 	   (set! last-dly1-samp dly1-samp)
@@ -209,7 +206,7 @@
 		     (begin
 		       (float-vector->channel block block-beg (- block-ctr pad) snd chn)
 		       (set! block-changed #f)))
-		 (set! block-beg (+ block-beg (- block-ctr pad)))
+		 (set! block-beg (- (+ block-beg block-ctr) pad))
 		 (do ((i 0 (+ i 1))
 		      (j (- block-ctr pad) (+ j 1)))
 		     ((= i pad))
@@ -234,7 +231,7 @@
     (remove-pops)
     (let ((mx (maxamp)))
       (if (> mx .01)
-	  (format #t "~%;test remove-pops 0 case: ~A" mx)))
+	  (format () "~%;test remove-pops 0 case: ~A" mx)))
     (revert-sound)
     (do ((i 0 (+ i 1))
 	 (ang 0.0 (+ ang .01)))
@@ -245,7 +242,7 @@
     (remove-pops)
     (let ((mx (maxamp)))
       (if (fneq mx .2)
-	  (format #t "~%;test remove-pops sine case: ~A" mx)))
+	  (format () "~%;test remove-pops sine case: ~A" mx)))
     (close-sound)))
 	
 
@@ -262,7 +259,7 @@
     (notch-channel (list 60.0) #f #f #f #f #f #f #t 8)
     (let ((mx (maxamp)))
       (if (> mx .02)
-	  (format #t "~%;notch hum 0: ~A" mx)))
+	  (format () "~%;notch hum 0: ~A" mx)))
     (close-sound (find-sound test)))
   (let ((test (with-sound ("test.snd" :srate 22050)
 		(let ((p (make-polywave 20.0 (list 2 1 3 1 4 1)))
@@ -281,7 +278,7 @@
 	(if (or (fneq (/ e60 v60) 0.0)
 		(fneq (/ e40 v40) 1.0)
 		(fneq (/ e80 v80) 1.0))
-	    (format #t "~%;notch 60: ~A ~A ~A -> ~A ~A ~A" v40 v60 v80 e40 e60 e80))))
+	    (format () "~%;notch 60: ~A ~A ~A -> ~A ~A ~A" v40 v60 v80 e40 e60 e80))))
     (close-sound (find-sound test)))
 
   (let ((test (with-sound ("test.snd" :srate 22050)
@@ -301,7 +298,7 @@
 	(if (or (> (/ e60 v60) 0.01)
 		(< (/ e40 v40) 0.99)
 		(< (/ e80 v80) 0.99))
-	    (format #t "~%;notch 60 tight: ~A ~A ~A -> ~A ~A ~A" v40 v60 v80 e40 e60 e80))))
+	    (format () "~%;notch 60 tight: ~A ~A ~A -> ~A ~A ~A" v40 v60 v80 e40 e60 e80))))
     (close-sound (find-sound test))))
 
 
@@ -323,7 +320,7 @@
 	      (nsig (goertzel 35.0)))
 	  (if (or (> (/ ndc dc) .1)
 		  (< (/ nsig sig) .4))
-	      (format #t "~%;remove-DC: ~A -> ~A (~A), ~A -> ~A (~A)" dc ndc (/ ndc dc) sig nsig (/ nsig sig))))))
+	      (format () "~%;remove-DC: ~A -> ~A (~A), ~A -> ~A (~A)" dc ndc (/ ndc dc) sig nsig (/ nsig sig))))))
     (close-sound test)))
 
 
@@ -370,31 +367,25 @@
 	 xhatminus))
      0 size snd chn)
 
-    (let ((mx1 (maxamp snd chn)))
-      (scale-channel (/ mx mx1) snd chn))
-
-;    (format #t ";K ~A to ~A, avg ~A to ~A" minK maxK ming maxg)
-;    avg-data
-    ))
-
+    (scale-channel (/ mx (maxamp snd chn)) snd chn)))
 
 
 (define* (clean-channel snd chn)
 
   ;; look for obvious simple clicks
   (let ((clicks (as-one-edit (lambda () (remove-single-sample-clicks 8 snd chn)))))
-    (if (> clicks 0)
-	(format #t "~%; fixed ~D single sample clicks" clicks)
-	(format #t "~%; no single-sample clicks found")))
+    (format () (if (> clicks 0)
+		   (values "~%; fixed ~D single sample clicks" clicks)
+		   "~%; no single-sample clicks found")))
 
   ;; look for obvious clipping and try to reconstruct
   (let ((mx (maxamp snd chn)))
     (if (>= mx 1.0)
 	(let ((clips (unclip-channel snd chn)))
-	  (if (eq? clips 'no-clips)
-	      (format #t "~%; no clipped portions found")
-	      (format #t "~%; reconstructed ~D clipped portions" (list-ref clips 3))))
-	(format #t "~%; no obvious clipping (max amp: ~A)" mx)))
+	  (format () (if (eq? clips 'no-clips)
+			 "~%; no clipped portions found"
+			 (values "~%; reconstructed ~D clipped portions" (list-ref clips 3)))))
+	(format () "~%; no obvious clipping (max amp: ~A)" mx)))
 
   ;; look for pops
   (let ((total-pops 0))
@@ -405,11 +396,11 @@
 	  (let ((pops (as-one-edit (lambda () (remove-pops size snd chn)))))
 	    (set! total-pops (+ total-pops pops))
 	    (if (> pops 0)
-		(format #t "~%; fixed ~D ~D-sample ~A" pops size (if (= pops 1) "pop" "pops"))
+		(format () "~%; fixed ~D ~D-sample ~A" pops size (if (= pops 1) "pop" "pops"))
 		(quit))))
-	(list 4 8 16 32))))
+	'(4 8 16 32))))
     (if (= total-pops 0)
-	(format #t "~%; no pops found")))
+	(format () "~%; no pops found")))
 
   ;; look for hum
   (let* ((hum60 (check-freq 60.0 snd chn))
@@ -418,14 +409,14 @@
     (if (> hum 30.0)
 	(let ((humf (if (> hum60 hum55) 60.0 55.0)))
 	  (notch-channel (list humf) 4096 0 (framples snd chn) snd chn #f #t 4)
-	  (format #t "~%; notch out ~D cycle hum: ~A -> ~A" (floor humf) hum (check-freq humf snd chn)))))
+	  (format () "~%; notch out ~D cycle hum: ~A -> ~A" (floor humf) hum (check-freq humf snd chn)))))
 
   ;; look for DC
   (let ((dc (check-freq 0.0 snd chn)))
     (if (> dc 30.0)
 	(let ((dcflt (make-filter 2 (float-vector 1 -1) (float-vector 0 -0.99))))
 	  (map-channel (lambda (y) (filter dcflt y)) 0 (framples snd chn) snd chn)
-	  (format #t "~%; block DC: ~A -> ~A" dc (check-freq 0.0 snd chn)))))
+	  (format () "~%; block DC: ~A -> ~A" dc (check-freq 0.0 snd chn)))))
 
   ;; time-varying low-pass filter
   (tvf-channel snd chn)
