@@ -1,4 +1,4 @@
-;;; these are CLM test instruments
+;;; these are (ancient!) CLM test instruments
 
 (provide 'snd-clm23.scm)
 (if (provided? 'snd)
@@ -40,9 +40,6 @@
 			  (sin (phases i))))))
     sum))
 
-
-(define open-input make-file->sample)
-
 (define two-pi (* 2 pi))
 
 (define (simple-out beg dur freq amp)
@@ -78,11 +75,10 @@
 	(if (> revb 0.0) (outb i (* revb val) *reverb*))))))
 
 (define (simple-ssb beg dur freq amp)
-  (let ((os (make-ssb-am freq))
-	(start (seconds->samples beg))
+  (let ((start (seconds->samples beg))
 	(end (seconds->samples (+ beg dur)))
 	(arr (make-vector 3)))
-    (set! (arr 0) os)
+    (set! (arr 0) (make-ssb-am freq))
     (set! (arr 1) #f)
     (set! (arr 2) (make-ssb-am 660 40))
     (do ((k 0 (+ k 1)))
@@ -138,14 +134,12 @@
 (define (simple-osc beg dur freq amp)
   (let ((start (seconds->samples beg))
 	(end (seconds->samples (+ beg dur)))
-	(freqs (make-float-vector 20)))
-    (let ((obank (make-oscil-bank freqs 
-				  (let ((fv (make-float-vector 20 0.0)))
-				    (do ((i 0 (+ i 1)))
-					((= i 20) fv)
-				      (set! (freqs i) (hz->radians (* (+ i 1) 100)))))
-				  (make-float-vector 20 1.0)
-				  #t)))
+	(freqs (make-float-vector 20))
+	(fv (make-float-vector 20)))
+    (do ((i 0 (+ i 1)))
+	((= i 20))
+      (set! (freqs i) (hz->radians (* (+ i 1) freq))))
+    (let ((obank (make-oscil-bank freqs fv (make-float-vector 20 1.0) #t)))
       (set! amp (* 0.05 amp))
       (do ((i start (+ i 1))) 
 	  ((= i end))
@@ -246,7 +240,7 @@
 					;(define w1 (make-polyshape :frequency 100.0 
 					;			   :partials (let ((frqs ()))
 					;				       (do ((i 1 (+ i 1)))
-					;					   ((= i 10) (begin (format #t frqs) (reverse frqs)))
+					;					   ((= i 10) (begin (format () frqs) (reverse frqs)))
 					;					 (set! frqs (cons (/ 1.0 (* i i)) (cons i frqs)))))))
 
 (define (simple-poly beg dur freq amp)
@@ -398,12 +392,12 @@
   (let ((foflen (if (= *clm-srate* 22050) 100 200)))
     (let ((start (seconds->samples beg))
 	  (end (seconds->samples (+ beg dur)))
-	  (ampf (make-env :envelope (or ae (list 0 0 25 1 75 1 100 0)) :scaler amp :duration dur))
+	  (ampf (make-env :envelope (or ae '(0 0 25 1 75 1 100 0)) :scaler amp :duration dur))
 	  (frq0 (hz->radians f0))
 	  (frq1 (hz->radians f1))
 	  (frq2 (hz->radians f2))
 	  (vibr (make-oscil 6))
-	  (vibenv (make-env :envelope (or ve (list 0 1 100 1)) :scaler vib :duration dur))
+	  (vibenv (make-env :envelope (or ve '(0 1 100 1)) :scaler vib :duration dur))
 	  (win-freq (/ two-pi foflen))
 	  (wt0 (make-wave-train :size foflen :frequency frq)))
       (let ((foftab (mus-data wt0)))
@@ -417,7 +411,7 @@
 	(outa i (* (env ampf) (wave-train wt0 (* (env vibenv) (oscil vibr)))))))))
 
 (define (simple-amb beg dur freq amp)
-  (let ((os (if (> freq 1) (make-oscil freq) (make-rand freq)))
+  (let ((os ((if (> freq 1) make-oscil make-rand) freq))
 	(start (seconds->samples beg))
 	(end (seconds->samples (+ beg dur))))
     (do ((i start (+ i 1))) ((= i end))
@@ -504,12 +498,7 @@
 	  ((= i end))
 	(outa i (* amp (src sr)))))))
 
-(define (simple-sr2a beg dur amp speed file)
-  (let ((start (seconds->samples beg))
-	(end (seconds->samples (+ beg dur)))
-	(sr (make-src :input (make-readin file) :srate speed)))
-    (do ((i start (+ i 1))) ((= i end))
-      (outa i (* amp (src sr))))))
+(define simple-sr2a simple-src)
 
 (define (simple-sro beg dur amp speed freq)
   (let ((os (make-oscil freq)))
@@ -540,7 +529,7 @@
 (define (simple-ina beg dur amp file)
   (let ((start (seconds->samples beg))
 	(end (seconds->samples (+ beg dur)))
-	(fil (open-input file)))
+	(fil (make-file->sample file)))
     (do ((i start (+ i 1))
 	 (ctr 0 (+ ctr 1)))
 	((= i end))
@@ -567,12 +556,7 @@
 	((= i end))
       (outa i (* amp (file->sample fil ctr))))))
 
-(define (simple-rdf beg dur amp file)
-  (let ((rd (make-readin file))
-	(start (seconds->samples beg))
-	(end (seconds->samples (+ beg dur))))
-    (do ((i start (+ i 1))) ((= i end))
-      (outa i (* amp (readin rd))))))
+(define simple-rdf simple-rd)
 
 (define (simple-loc beg dur freq amp)
   (let ((os (make-oscil freq))
@@ -622,8 +606,8 @@
     (do ((i start (+ i 1))) ((= i end))
       (let ((amp .3)
 	    (j 4))
-	(if (not (= j 4)) (format #t "local j is ~D\n" j))
-	(if (> (abs (- amp .3)) .001) (format #t "local amp is ~F\n" amp)))
+	(if (not (= j 4)) (format () "local j is ~D\n" j))
+	(if (> (abs (- amp .3)) .001) (format () "local amp is ~F\n" amp)))
       (if (= j 2)
 	  (outa i (* amp (oscil os)))))))
 
@@ -635,11 +619,11 @@
 	(start (seconds->samples beg))
 	(end (seconds->samples (+ beg dur))))
     (do ((i start (+ i 1))) ((= i end))
-      (if (not (= j 2199023256786)) (format #t "local j is ~A" j))
-      (if (not (= jj -1099511632097)) (format #t "local jj is ~A" jj))
+      (if (not (= j 2199023256786)) (format () "local j is ~A" j))
+      (if (not (= jj -1099511632097)) (format () "local jj is ~A" jj))
       (if (= mj -3)
 	  (outa i (* amp (oscil os)))
-	  (format #t "minus 3: ~D" mj)))))
+	  (format () "minus 3: ~D" mj)))))
 
 (define (sample-desc beg dur freq amp)
   (let ((os (make-oscil freq))
@@ -650,9 +634,9 @@
       (if (not printed)
 	  (begin
 	    (if (not (string=? (mus-describe os) "oscil freq: 440.000Hz, phase: 0.000"))
-		(format #t "describe oscil: ~A~%" (mus-describe os)))
+		(format () "describe oscil: ~A~%" (mus-describe os)))
 	    (if (> (abs (- (mus-frequency os) freq)) .001)
-		(format #t "osc freq: ~A (~A)~%" (mus-frequency os) freq))
+		(format () "osc freq: ~A (~A)~%" (mus-frequency os) freq))
 	    (set! printed #t)))
       (outa i (* amp (oscil os))))))
 
@@ -719,10 +703,10 @@
   (let ((start (seconds->samples beg))
 	(end (seconds->samples (+ beg dur)))
 	(os (make-oscil freq)))
-    (let ((sr2 (make-src :srate speed :input (lambda (dir) (oscil os)))))
-      (let ((sr1 (make-src :srate speed :input (lambda (dir) (src sr2)))))
-	(do ((i start (+ i 1))) ((= i end))
-	  (outa i (* amp (src sr1))))))))
+    (let* ((sr2 (make-src :srate speed :input (lambda (dir) (oscil os))))
+	   (sr1 (make-src :srate speed :input (lambda (dir) (src sr2)))))
+      (do ((i start (+ i 1))) ((= i end))
+	(outa i (* amp (src sr1)))))))
 
 (define (sample-srl3 beg dur amp speed freq)
   (let ((start (seconds->samples beg))
@@ -787,7 +771,7 @@
 				:fft-size size
 				:edit (lambda (pv)
 					(if (not (= (mus-location pv) 0))
-					    (format #t "outctr: ~A" (mus-location pv)))
+					    (format () "outctr: ~A" (mus-location pv)))
 					#t))))
       (do ((i start (+ i 1))) ((= i end))
 	(outa i (* amp (phase-vocoder sr))))))
@@ -831,7 +815,7 @@
 	    (begin
 	      (set! (mus-frequency g) frq)
 	      (if (> (abs (- (mus-frequency g) frq)) .001)
-		  (format #t "oops ~A ~A" (mus-frequency g) frq))
+		  (format () "oops ~A ~A" (mus-frequency g) frq))
 	      (do ((k start (+ k 1))) 
 		  ((= k end))
 		(outa k (* amp (oscil g))))))))))
@@ -851,10 +835,10 @@
       (do ((i 0 (+ i 1)))
 	  ((= i (length phases)))
 	(set! (phases i) (+ (phases i) (freqs i))))
-      (if (not (= (ints 0) 32)) (format #t "int array trouble"))
+      (if (not (= (ints 0) 32)) (format () "int array trouble"))
       (set! (ints 1) 3)
-      (if (not (= (ints 1) 3)) (format #t "set int array trouble"))
-      (if (not (= (length amps) 3)) (format #t "amps len: ~A" (length amps)))
+      (if (not (= (ints 1) 3)) (format () "set int array trouble"))
+      (if (not (= (length amps) 3)) (format () "amps len: ~A" (length amps)))
       (outa i (clm23-sine-bank amps phases 3)))))
 
 (define (sample-flt beg dur freq amp)
@@ -872,13 +856,13 @@
       (let ((xs (mus-xcoeffs flt)))
 	(if (or (> (abs (- (xs 1) (mus-xcoeff flt 1))) .001)
 		(> (abs (- (xs 1) 0.0625)) .001))
-	    (format #t "~A ~A~%" (xs 1) (mus-xcoeff flt 1))))
+	    (format () "~A ~A~%" (xs 1) (mus-xcoeff flt 1))))
       (let ((data (mus-data flt)))
-	(if (> (data 0) 1.0) (format #t "data overflow? ~A~%" (data 0))))
-      (let ((is intdat)
-	    (fs fltdat))
-	(if (not (= (is 1) 3)) (format #t "intdat let: ~A~%" (is 1)))
-	(if (> (abs (- (fs 1) 3.14)) .001) (format #t "fltdat let: ~A~%" (fs 1))))
+	(if (> (data 0) 1.0) (format () "data overflow? ~A~%" (data 0))))
+      (if (not (= (intdat 1) 3))
+          (format () "intdat let: ~A~%" (intdat 1)))
+      (if (> (abs (- (fltdat 1) 3.14)) 0.001)
+          (format () "fltdat let: ~A~%" (fltdat 1)))
       (outa i (* amp (filter flt (oscil os)))))))
 
 (define (sample-arrintp beg dur freq amp)
@@ -897,73 +881,6 @@
 	  ((= i end))
 	(outa i (* amp (array-interp arr loc) (oscil os)))))))
 
-(define (sample-if beg dur freq amp)
-  (let ((os (make-oscil freq))
-	(start (seconds->samples beg))
-	(end (seconds->samples (+ beg dur)))
-	(k -123)
-	(j 0)
-	(bool #t))
-    (do ((i start (+ i 1))) ((= i end))
-      (if (and (= i start) (not (= k -123))) (format #t "init k: ~A~%" k))
-      (if (not bool) (format #t "bool: ~A~%" bool))
-      (set! j (if bool 1 2))
-      (if (not (= j 1)) (format #t "if expr: ~A~%" j))
-      (if bool (set! j 3) (set! j 4))
-      (if (not (= j 3)) (format #t "if statement: ~A~%" j))
-      (if (integer? k) (set! j 5))
-      (if (not (= j 5)) (format #t "int k? ~A ~A~%" (integer? k) j))
-      (if (= j k) (set! j 6))
-      (if (= j 6) (format #t "j if false: ~A~%" j))
-      (set! j (if (= j k) (+ k 7) (+ k 8)))
-      (if (not (= j (+ k 8))) (format #t "if false expr: ~A ~A~%" j k))
-      (set! j (if (> j -1234) (if (> k -1234) 9 10) 11))
-      (if (not (= j 9)) (format #t "if 2 expr: ~A~%" j))
-      (set! j (if (> j -1234) (begin (set! k 0) 12) 13))
-      (if (not (= j 12)) (format #t "if begin expr: ~A~%" j))
-      (if (> j -1234) (begin (set! j 1234) (set! j 14)) (set! j 15))
-      (if (not (= j 14)) (format #t "if begin: ~A~%" j))
-					;	 (if (> j -1234) (set! j (prog1 16 (set! k 0))))
-					;	 (if (not (= j 16)) (format #t "if prog1: ~A~%" j))
-					;	 (if (> j -1234) (set! j (prog2 (set! k 0) 17 (set! k 0))))
-					;	 (if (not (= j 17)) (format #t "if prog2: ~A~%" j))
-					;       (set! k (loop for j from 1 to 4 sum j))
-					;       (if (not (= k 10)) (format #t "loop sum: ~A~%" k))
-					;	 (if (> j -1234) (set! j (prog2 (set! k 0) (if (> j -1234) (begin (set! k 123) 18) 19) (set! k 0))))
-					;	 (if (not (= j 18)) (format #t "if nested prog2: ~A~%" j))
-      (set! j 123)
-      (cond ((= j 0) (set! k -1))
-	    ((= j 12) (set! k -2))
-	    ((= j 123) (set! k -3))
-	    (#t (set! k -4)))
-      (if (not (= k -3)) (format #t "cond: ~A ~A~%" j k))
-      (set! k (cond ((= j 0) -4)
-		    ((= j 12) -5)
-		    (#t -6)))
-      (if (not (= k -6)) (format #t "cond expr: ~A ~A~%" j k))
-      (set! k (let ((a 123))
-		(if (> a 0)
-		    20
-		    32)))
-      (if (not (= k 20)) (format #t "let expr: ~A ~A~%" j k))
-      (let ((a 123))
-	(set! k a))
-      (if (not (= k 123)) (format #t "let: ~A ~A~%" j k))
-      (set! k 123)
-      (set! bool (= k 123))
-      (if (not bool) (format #t "bool expr: ~A~%" bool))
-      (set! bool (if (= k 123) (> k 0) (< k 0)))
-      (if (not bool) (format #t "if bool expr: ~A~%" bool))
-      (set! j 0)
-      (set! k (do ((m 0 (+ 1 m)))
-		  ((= m 3) j)
-		(set! j (+ j 1))))
-      (if (not (= k 3)) (format #t "do expr: ~A~%" k))
-					;	 (dotimes (m 2)
-					;		  (set! k (- k 1)))
-					;	 (if (not (= k 1)) (format #t "dotimes: ~A~%" k))
-      (outa i (* amp (oscil os))))))
-
 (define (sample-arrfile beg dur freq amp)
   (let ((os (make-oscil freq))
 	(start (seconds->samples beg))
@@ -973,7 +890,7 @@
 	(dir 1))
     (do ((i 0 (+ i 1)))
 	((= i 100))
-      (set! (arr i) (* amp (+ -.5 (* i .01)))))
+      (set! (arr i) (* amp (- (* i .01) 0.5))))
     (array->file "testx.data" arr 100 22050 1)
     (fill! arr 0.0)
     (file->array "testx.data" 0 0 100 arr)
@@ -1001,23 +918,9 @@
       (outa i (* amp (granulate sr))))))
 
 					;(with-sound () (simple-grn-f2 0 1 1 2 "oboe.snd"))
-
-(define (simple-grn-f3 beg dur amp speed file)
-  (let ((start (seconds->samples beg))
-	(end (seconds->samples (+ beg dur)))
-	(sr (make-granulate :input (make-readin file) :expansion speed)))
-    (do ((i start (+ i 1))) ((= i end))
-      (outa i (* amp (granulate sr))))))
-
+(define simple-grn-f3 simple-grn-f2)
 					;(with-sound () (simple-grn-f3 0 1 1 2 "oboe.snd"))
-
-(define (simple-grn-f4 beg dur amp speed file)
-  (let ((start (seconds->samples beg))
-	(end (seconds->samples (+ beg dur)))
-	(sr (make-granulate :input (make-readin file) :expansion speed)))
-    (do ((i start (+ i 1))) ((= i end))
-      (outa i (* amp (granulate sr))))))
-
+(define simple-grn-f4 simple-grn-f2)
 					;(with-sound () (simple-grn-f4 0 1 1 2 "oboe.snd"))
 
 (define (simple-grn-f5 beg dur amp speed file)
@@ -1121,7 +1024,6 @@
   (sample-ardcl 5.5 .2 440 .1)
   (sample-flt 6 .2 440 .1)
   (sample-arrintp 6.25 .2 440 .1)
-  (sample-if 6.5 .2 440 .1)
   (sample-arrfile 6.75 .2 440 .15)
   (sample-pvoc5 7 .2 .1 256 "oboe.snd" 440.0)
   )
@@ -1168,24 +1070,23 @@
 						     ((= k size))
 						   (float-vector-set! paincrs buf (* (in-data k) (window k)))
 						   (set! buf (+ buf 1))
-						   (if (>= buf size) (set! buf 0)))
-						 (set! filptr (+ filptr D))
-						 (mus-fft paincrs freqs size 1)
-						 (rectangular->polar paincrs freqs)
-						 #f))
+						   (if (>= buf size) (set! buf 0))))
+					       (set! filptr (+ filptr D))
+					       (mus-fft paincrs freqs size 1)
+					       (rectangular->polar paincrs freqs)
+					       #f)
 				    :edit (lambda (pv)
-					    (let ((pscl (/ 1.0 D))
-						  (kscl (/ two-pi size)))
-					      (do ((k 0 (+ k 1))
-						   (ks 0.0 (+ ks kscl)))
-						  ((= k N2))
-						(let* ((freq (freqs k))
-						       (diff (- freq (lastphases k))))
-						  (set! (lastphases k) freq)
-						  (if (> diff pi) (set! diff (- diff two-pi)))
-						  (if (< diff (- pi)) (set! diff (+ diff two-pi)))
-						  (float-vector-set! freqs k (+ (* diff  pscl) ks))))
-					      #f))
+					    (do ((pscl (/ 1.0 D))
+						 (kscl (/ two-pi size))
+						 (k 0 (+ k 1))
+						 (ks 0.0 (+ ks kscl)))
+						((= k N2) #f)
+					      (let* ((freq (freqs k))
+						     (diff (- freq (lastphases k))))
+						(set! (lastphases k) freq)
+						(if (> diff pi) (set! diff (- diff two-pi)))
+						(if (< diff (- pi)) (set! diff (+ diff two-pi)))
+						(float-vector-set! freqs k (+ (* diff  pscl) ks)))))
 				    :synthesize (lambda (pv)
 						  (float-vector-add! amps paincrs)
 						  (float-vector-add! ppincrs freqs)
@@ -1202,122 +1103,6 @@
 	  ((= i end))
 	(outa i (* amp (phase-vocoder sr))))))))
 
-(define (or1)
-  (let ((e1 (make-env '(0 0 1 1) :length 10))
-	(e2 (make-env '(0 1 1 0) :length 10))
-	(e3 #f)
-	(ok1 0.0))
-    (do ((i 0 (+ i 1)))
-	((= i 1))
-      (set! ok1 0.0)
-      (if (or e1 e2)
-	  (set! ok1 (+ ok1 (env e1)))
-	  (format #t ";or1 a~%"))
-      (if (not (or e1 e2))
-	  (format #t ";or1 1~%"))
-      (if (and e1 e2)
-	  (set! ok1 (+ ok1 (env e2)))
-	  (format #t ";or1 b~%"))
-      (if (not (and e1 e2))
-	  (format #t ";or1 2~%"))
-      (if (or e3 e1 e2)
-	  (mus-reset e2) ; resets e2 -> 1.0
-	  (format #t ";or1 c~%"))
-      (if (and e1 e3 e2)
-	  (format #t ";or1 3~%"))
-      (if (not e1)
-	  (format #t ";or1 4~%"))
-      (if (< (abs ok1) .001)
-	  (format #t ";or1 ok1: ~A~%" ok1)))))
-
-(define (or2)
-  (let ((e1 (make-env '(0 0 1 1) :length 10))
-	(e2 (make-env '(0 1 1 0) :length 10))
-	(e3 #f)
-	(ok1 0.0)
-	(oki 0)
-	(okb #f))
-    (do ((i 0 (+ i 1)))
-	((= i 1))
-      (set! ok1 0.0)
-      (set! oki (+ oki 1))
-      (set! okb #t)
-      (if (or e1 e2)
-	  (set! ok1 (+ ok1 (env e1)))
-	  (format #t ";or2 a~%"))
-      (if (not (or e1 e2 okb))
-	  (format #t ";or2 1~%"))
-      (if (and e1 e2)
-	  (set! ok1 (+ ok1 (env e2)))
-	  (format #t ";or2 b~%"))
-      (if (not (and e1 e2))
-	  (format #t ";or2 2~%"))
-      (if (or e3 e1 e2)
-	  (mus-reset e2) ; resets e2 -> 1.0
-	  (format #t ";or2 c~%"))
-      (if (and e1 e3 e2)
-	  (format #t ";or2 3~%"))
-      (if (not e1)
-	  (format #t ";or2 4~%"))
-      (if (< (abs ok1) .001)
-	  (format #t ";or1 ok1: ~A~%" ok1)))))
-
-(define (or3)
-  (let ((e1 (make-env '(0 0 1 1) :length 10))
-	(i1 (make-vector 3 32))
-	(f1 (make-float-vector 3 3.14))
-	(i2 (make-vector 3 3))
-	(f2 (make-vector 3 1.5))
-	(ok1 0.0)
-	(oki 0))
-    (do ((i 0 (+ i 1)))
-	((= i 1))
-      (cond (e1 (set! ok1 (+ ok1 (env e1))))
-	    (#t (format #t ";or3 1~%")))
-      (if (or f1 f2)
-	  (set! ok1 (+ ok1 (f2 0)))
-	  (format #t ";or3 a~%"))
-      (if (not (or f2 f1))
-	  (format #t ";or3 2~%"))
-      (if (and f2 f1)
-	  (set! ok1 (+ ok1 (f1 1)))
-	  (format #t ";or3 b~%"))
-      (if (or i1 i2)
-	  (set! oki (+ oki (i2 0)))
-	  (format #t ";or3 d~%"))
-      (if (not (or i2 i1))
-	  (format #t ";or3 3~%"))
-      (if (and i2 i1)
-	  (set! oki (+ oki (i1 1)))
-	  (format #t ";or3 e~%")))))
-
-(define (or4)
-  (let ((e1 (make-env '(0 0 1 1) :length 10))
-	(e2 (make-env '(0 1 1 0) :length 10))
-  	(i1 (make-vector 3 32))
-	(f1 (make-float-vector 3 3.14))
-	(i2 (make-vector 3 3))
-	(f2 (make-vector 3 1.5))
-	(oki 0))
-    (do ((i 0 (+ i 1)))
-	((= i 1))
-      (if (or (and e1 e2)
-	      (and f1 f2)
-	      (and i1 i2))
-	  (set! oki (+ oki 1))
-	  (format #t ";or4 a~%"))
-      (if (and (or f1 f2)
-	       (not (or i1 i2))
-	       (or e1 e2))
-	  (format #t ";or4 1~%"))
-      (if f1
-	  (if e1
-	      (if (not e2)
-		  (format #t ";or4 2~%")
-		  (set! oki (+ oki 1)))
-	      (format #t ";or4 3~%"))
-	  (format #t ";or4 4~%")))))
-
 
 ;;; --------------------------------------------------------------------------------
 ;;;
@@ -1335,8 +1120,7 @@
         (modulator-phase-incr (hz->radians (* mc-ratio freq))))
     (do ((i beg (+ i 1)))
 	((= i end))
-      (let* ((modulation (* index (sin modulator-phase)))
-	     (pm-val (* amp (sin (+ carrier-phase modulation))))) 
+      (let ((pm-val (* amp (sin (+ carrier-phase (* index (sin modulator-phase)))))))
 	;; no integration in phase modulation (it's a phase change)
 	(set! carrier-phase (+ carrier-phase carrier-phase-incr))
 	(set! modulator-phase (+ modulator-phase modulator-phase-incr))
@@ -1431,7 +1215,7 @@
 	      ((= i n))
 	    (set! (modulators i) (hz->radians (* freq (mc-ratios i) (mod-phases i))))
 	    (set! (fm-indices i) (hz->radians (* freq (indexes i) (mc-ratios i)))))
-	  (let ((ob (make-oscil-bank modulators (make-float-vector n 0.0) fm-indices #t)))
+	  (let ((ob (make-oscil-bank modulators (make-float-vector n) fm-indices #t)))
 	    (do ((i start (+ i 1)))
 		((= i end))
 	      (outa i (* amp (oscil cr (oscil-bank ob))))))))))
@@ -1443,7 +1227,7 @@
 	(frq-scl (hz->radians frequency)))
     (let ((maxdev (* frq-scl fm-index)))
       (let ((index1 (* maxdev (/ 5.0 (log frequency))))
-	    (index2 (* maxdev 3.0 (/ (- 8.5 (log frequency)) (+ 3.0 (/ frequency 1000)))))
+	    (index2 (/ (* maxdev 3.0 (- 8.5 (log frequency))) (+ 3.0 (/ frequency 1000))))
 	    (index3 (* maxdev (/ 4.0 (sqrt frequency))))
 	    (carrier (make-oscil frequency))
 	    (fmosc1 (make-oscil frequency))
@@ -1461,9 +1245,9 @@
 	      (outa i (* (env ampf)
 			 (oscil carrier
 				(+ vib 
-				   (+ (* (env indf1) (oscil fmosc1 vib))
-				      (* (env indf2) (oscil fmosc2 (* 3.0 vib)))
-				      (* (env indf3) (oscil fmosc3 (* 4.0 vib)))))))))))))))
+				   (* (env indf1) (oscil fmosc1 vib))
+				   (* (env indf2) (oscil fmosc2 (* 3.0 vib)))
+				   (* (env indf3) (oscil fmosc3 (* 4.0 vib))))))))))))))
 
 (define (fmdoc-cascade beg dur freq amp modrat modind casrat casind caspha)
   (let ((start (seconds->samples beg))
@@ -1472,7 +1256,7 @@
 	(md (make-oscil (* freq modrat)))
 	(ca (make-oscil (* freq casrat) caspha))
 	(fm-ind0 (hz->radians (* modind modrat freq)))
-	(fm-ind1 (hz->radians (* casind (/ casrat modrat) freq))))
+	(fm-ind1 (hz->radians (/ (* casind casrat freq) modrat))))
     (do ((i start (+ i 1)))
 	((= i end))
       (outa i (* amp 
@@ -1591,29 +1375,9 @@
 	((= i end))
       (outa i (* amp (oscil os))))))
 
-(define (sndclmdoc-simp-1 beg dur freq amp)
-  (let ((os (make-oscil freq))
-	(start (seconds->samples beg))
-	(end (seconds->samples (+ beg dur))))
-    (do ((i start (+ i 1))) 
-	((= i end))
-      (outa i (* amp (oscil os))))))
-
-(define (sndclmdoc-simp-2 beg dur freq amp)
-  (let ((os (make-oscil freq))
-	(start (seconds->samples beg))
-	(end (seconds->samples (+ beg dur))))
-    (do ((i start (+ i 1))) 
-	((= i end))
-      (outa i (* amp (oscil os))))))
-
-(definstrument (sndclmdoc-simp-3 beg dur freq amp)
-  (let ((os (make-oscil freq))
-	(start (seconds->samples beg))
-	(end (seconds->samples (+ beg dur))))
-    (do ((i start (+ i 1))) 
-	((= i end))
-      (outa i (* amp (oscil os))))))
+(define sndclmdoc-simp-1 simple-out)
+(define sndclmdoc-simp-2 simple-out)
+(define sndclmdoc-simp-3 simple-out)
 
 (define (sndclmdoc-telephone start telephone-number)
   (let ((touch-tab-1 '(0 697 697 697 770 770 770 852 852 852 941 941 941))
@@ -1688,7 +1452,7 @@
       (let ((zval (env zv))) 
 	(outa i 
 	      (* amp 
-		 (sin (* pi2 zval (* zval zval)))
+		 (sin (* pi2 zval zval zval))
 		 (oscil osc)))))))
 
 (definstrument (sndclmdoc-simple-table dur)
@@ -1704,11 +1468,10 @@
 	    (<= (cadr loop-data) (car loop-data)))
 	(error 'no-loop-positions)
 	(let* ((loop-start (car loop-data))
-	       (loop-end (cadr loop-data))
-	       (loop-length (+ 1 (- loop-end loop-start)))
+	       (loop-length (- (+ (cadr loop-data) 1) loop-start))
 	       (sound-section (float-vector-scale! (file->array sound 0 loop-start loop-length (make-float-vector loop-length)) amp))
-	       (original-loop-duration (/ loop-length (srate sound)))
-	       (tbl (make-table-lookup :frequency (/ freq original-loop-duration) :wave sound-section)))
+	       (tbl (make-table-lookup :frequency (/ (* freq (srate sound)) loop-length)
+				       :wave sound-section)))
 	  ;; "freq" here is how fast we read (transpose) the sound -- 1.0 returns the original
 	  (do ((i beg (+ i 1)))
 	      ((= i end))
@@ -1762,10 +1525,13 @@
 		      (polynomial cos-coeffs ax))))))))
 
 (definstrument (sndclmdoc-bl-saw start dur frequency order)
-  (let ((norm (if (= order 1) 1.0           ; these peak amps were determined empirically
-		  (if (= order 2) 1.3       ;   actual limit is supposed to be pi/2 (G&R 1.441)
-		      (if (< order 9) 1.7   ;   but Gibbs phenomenon pushes it to 1.851
-			  1.9))))           ;   if order>25, numerical troubles -- use table-lookup
+  (let ((norm (cond ((assoc order '((1 . 1.0) (2 . 1.3)) =) => cdr)
+		    ((< order 9) 1.7)
+		    (else 1.9)))
+	;; these peak amps were determined empirically
+	;;   actual limit is supposed to be pi/2 (G&R 1.441)
+	;;   but Gibbs phenomenon pushes it to 1.851
+	;;   if order>25, numerical troubles -- use table-lookup
 	(freqs ()))
     (do ((i 1 (+ i 1)))
 	((> i order))
@@ -1803,17 +1569,16 @@
     (let ((top (* 0.5 range))
 	  (val (if (= ang 0.0) 1.0 (/ (sin ang) ang)))
 	  (new-ang (+ ang frq fm)))
-      (if (> new-ang top)
-	  (set! (gen 0) (- new-ang range))
-	  (set! (gen 0) new-ang))
+      (set! (gen 0) (if (> new-ang top)
+			(- new-ang range)
+			new-ang))
       val)))
 
 (define (sndclmdoc-make-sum-of-odd-sines frequency n)
   (float-vector 0.0 (hz->radians frequency) (* 1.0 n)))
 
 (define (sndclmdoc-sum-of-odd-sines gen fm)
-  (let* ((angle (gen 0))
-	 (a2 (* angle 0.5))
+  (let* ((a2 (* (gen 0) 0.5))
 	 (n (gen 2))
 	 (den (* n (sin a2)))
 	 (result (if (< (abs den) 1.0e-9)
@@ -1877,12 +1642,12 @@
     (let ((foftab (make-float-vector foflen)))
       (let ((start (seconds->samples beg))
 	    (end (seconds->samples (+ beg dur)))
-	    (ampf (make-env :envelope (or ae (list 0 0 25 1 75 1 100 0)) :scaler amp :duration dur))
+	    (ampf (make-env :envelope (or ae '(0 0 25 1 75 1 100 0)) :scaler amp :duration dur))
 	    (frq0 (hz->radians f0))
 	    (frq1 (hz->radians f1))
 	    (frq2 (hz->radians f2))
 	    (vibr (make-oscil 6))
-	    (vibenv (make-env :envelope (or ve (list 0 1 100 1)) :scaler vib :duration dur))
+	    (vibenv (make-env :envelope (or ve '(0 1 100 1)) :scaler vib :duration dur))
 	    (win-freq (/ (* 2 pi) foflen))
 	    (wt0 (make-wave-train :wave foftab :frequency frq)))
 	(do ((i 0 (+ i 1)))
@@ -1970,11 +1735,9 @@
       (outa i (convolve ff)))))
 
 (definstrument (sndclmdoc-granulate-sound file beg dur (orig-beg 0.0) (exp-amt 1.0))
-  (let* ((f-srate (srate file))
-	 (f-start (round (* f-srate orig-beg)))
-         (f (make-readin file :start f-start))
-	 (st (seconds->samples beg))
-	 (new-dur (or dur (- (mus-sound-duration file) orig-beg))))
+  (let ((f (make-readin file :start (round (* (srate file) orig-beg))))
+	(st (seconds->samples beg))
+	(new-dur (or dur (- (mus-sound-duration file) orig-beg))))
     (let ((exA (make-granulate :input f :expansion exp-amt))
 	  (nd (+ st (seconds->samples new-dur))))
       (do ((i st (+ i 1)))
@@ -1989,13 +1752,7 @@
 	((= i stop))
       (outa i (granulate exA)))))
 
-(definstrument (sndclmdoc-simple-pvoc beg dur amp size file)
-  (let ((start (seconds->samples beg))
-	(end (seconds->samples (+ beg dur)))
-	(sr (make-phase-vocoder (make-readin file) :fft-size size)))
-    (do ((i start (+ i 1)))
-	((= i end))
-      (outa i (* amp (phase-vocoder sr))))))
+(define sndclmdoc-simple-pvoc sample-pvoc1)
 
 (definstrument (sndclmdoc-asy beg dur freq amp index (r 1.0) (ratio 1.0))
   (let ((st (seconds->samples beg))
@@ -2005,14 +1762,7 @@
 	((= i nd))
       (outa i (* amp (asymmetric-fm asyf index))))))
 
-(define (sndclmdoc-simple-f2s beg dur amp file)
-  (let ((start (seconds->samples beg))
-	(end (seconds->samples (+ beg dur)))
-	(fil (make-file->sample file)))
-    (do ((i start (+ i 1))
-	 (ctr 0 (+ ctr 1)))
-	((= i end))
-      (outa i (* amp (file->sample fil ctr))))))
+(define sndclmdoc-simple-f2s simple-f2s)
 
 (definstrument (sndclmdoc-simple-ina beg dur amp file)
   (let ((start (seconds->samples beg))
@@ -2070,24 +1820,7 @@
 	  (if *reverb* (locsig-reverb-set! loc 0 (* reverb-amount (sqrt dist-scaler))))
 	  (locsig loc i (* (env amp-env) (readin rdA)))))))
 
-(define (sndclmdoc-simple-dloc beg dur freq amp)
-  (let ((os (make-oscil freq))
-	(start (seconds->samples beg))
-	(end (seconds->samples (+ beg dur))))
-    (let ((loc (make-move-sound (list start end 4 0
-				      (make-delay 12) 
-				      (make-env '(0 0 10 1) :duration dur)
-				      #f
-				      (make-vector 4 #f)
-				      (vector (make-env '(0 0 1 1 2 0 3 0 4 0) :duration dur)
-					      (make-env '(0 0 1 0 2 1 3 0 4 0) :duration dur)
-					      (make-env '(0 0 1 0 2 0 3 1 4 0) :duration dur)
-					      (make-env '(0 0 1 0 2 0 3 0 4 1) :duration dur))
-				      #f
-				      (vector 0 1 2 3)))))
-      (do ((i start (+ i 1)))
-	  ((= i end))
-	(move-sound loc i (* amp (oscil os)))))))
+(define sndclmdoc-simple-dloc simple-dloc-4)
 
 (definstrument (when? start-time duration start-freq end-freq grain-file)
   (let ((beg (seconds->samples start-time))
@@ -2216,11 +1949,7 @@
   freq phase fm res)
 
 (define* (sndscm-osc1 gen fm)
-  (let-set! gen 'fm fm)
-  (with-let gen
-    (set! res (sin phase))
-    (set! phase (+ phase freq fm))
-    res))
+  (sndscm-osc gen fm))
 
 (definstrument (sndscm-osc1-fm beg dur freq amp mc-ratio (fm-index 1.0))
   (let ((start (seconds->samples beg))
@@ -2258,11 +1987,7 @@
   freq phase fm res)
 
 (define* (sndscm-osc2 gen fm)
-  (let-set! gen 'fm fm)
-  (with-let gen
-    (set! res (sin phase))
-    (set! phase (+ phase freq fm))
-    res))
+  (sndscm-osc gen fm))
 
 (definstrument (sndscm-osc2-fm beg dur freq amp mc-ratio (fm-index 1.0))
   (let ((start (seconds->samples beg))
@@ -2271,7 +1996,7 @@
 	(modulator (make-sndscm-osc2 (* mc-ratio freq)))
 	(index (hz->radians (* freq mc-ratio fm-index))))
     (if (fneq (mus-frequency carrier) freq)
-	(format #t ";sndscm-osc2 (sclm23.scm) mus-frequency ~A: ~A ~A" (mus-describe carrier) (mus-frequency carrier) freq))
+	(format () ";sndscm-osc2 (sclm23.scm) mus-frequency ~A: ~A ~A" (mus-describe carrier) (mus-frequency carrier) freq))
     (do ((i start (+ i 1)))
 	((= i end))
       (outa i (* amp (sndscm-osc2 carrier (* index (sndscm-osc2 modulator 0.0))))))))
@@ -2341,15 +2066,6 @@
       (if (< i end)
 	  (loop (+ i 1))))))
 
-(define (simp-tail-recursion beg dur freq amp)
-  (let ((o (make-oscil freq))
-	 (start (seconds->samples beg))
-	 (end (seconds->samples (+ beg dur))))
-    (define (simper i)
-      (outa i (* amp (oscil o)))
-      (if (< i end)
-	  (simper (+ i 1))))
-    (simper start)))
 
 
 ;;; --------------------------------------------------------------------------------
@@ -2421,7 +2137,7 @@
   (with-sound () ; one of JC's favorite demos
     (sndclmdoc-fofins 0 4 270 .2 0.005 730 .6 1090 .3 2440 .1 '(0 0 40 0 75 .2 100 1) 
 		      '(0 0 .5 1 3 .5 10 .2 20 .1 50 .1 60 .2 85 1 100 0))
-    (sndclmdoc-fofins 0 4 (* 6/5 540) .2 0.005 730 .6 1090 .3 2440 .1 '(0 0 40 0 75 .2 100 1) 
+    (sndclmdoc-fofins 0 4 648 .2 0.005 730 .6 1090 .3 2440 .1 '(0 0 40 0 75 .2 100 1) 
 		      '(0 0 .5 .5 3 .25 6 .1 10 .1 50 .1 60 .2 85 1 100 0))
     (sndclmdoc-fofins 0 4 135 .2 0.005 730 .6 1090 .3 2440 .1 '(0 0 40 0 75 .2 100 1) 
 		      '(0 0 1 3 3 1 6 .2 10 .1 50 .1 60 .2 85 1 100 0)))
@@ -2453,12 +2169,9 @@
     (sndclmdoc-space "pistol.snd" 0 1 :distance-env '(0 1 1 2) :degree-env '(0 0 1 90)))
   
   (with-sound ()
-    (let ((gen (sndclmdoc-make-sum-of-odd-sines 440.0 10)))
-      (sndclmdoc-sum-of-odd-sines gen 0.0))
-    (let ((gen (sndclmdoc-make-sinc-train 440.0)))
-      (sndclmdoc-sinc-train gen))
-    (let ((gen (sndclmdoc-make-moving-max)))
-      (sndclmdoc-moving-max gen 0.1))
+    (sndclmdoc-sum-of-odd-sines (sndclmdoc-make-sum-of-odd-sines 440.0 10) 0.0)
+    (sndclmdoc-sinc-train (sndclmdoc-make-sinc-train 440.0))
+    (sndclmdoc-moving-max (sndclmdoc-make-moving-max) 0.1)
     (sndclmdoc-asy 0 .1 440 .1 1.0)
     (sndclmdoc-simple-table 1000)
     (sndclmdoc-simple-f2s .1 .1 .1 "oboe.snd")
@@ -2497,8 +2210,7 @@
     (sndscm-osc-fm 0 1 440 .1 1 1)
     (sndscm-osc1-fm 0 1 440 .1 1)
     (sndscm-osc2-fm 0 1 440.0 .1 1)
-    (simp-named-let 0 .01 440 .1)
-    (simp-tail-recursion 0 .01 440 .1))
+    (simp-named-let 0 .01 440 .1))
   
   (with-sound () 
     (let ((gen (make-dsp-asyfm :freq 2000 :ratio .1))) 
