@@ -38,9 +38,7 @@
   (let ((documentation "(src-duration envelope) returns the new duration of a sound after using 'envelope' for time-varying sampling-rate conversion"))
     (lambda (e)
       (let* ((len (length e))
-	     (ex0 (e 0))
-	     (ex1 (e (- len 2)))
-	     (all-x (- ex1 ex0))
+	     (all-x (- (e (- len 2)) (e 0))) ; last x - first x
 	     (dur 0.0))
 	(do ((i 0 (+ i 2)))
 	    ((>= i (- len 2)) dur)
@@ -137,8 +135,7 @@
       ;;  the power-of-2 limitation is based on the underlying fft function's insistence on power-of-2 data sizes
       ;;  see stretch-sound-via-dft below for a general version
       (let* ((len (framples snd chn))
-	     (pow2 (ceiling (log len 2)))
-	     (fftlen (floor (expt 2 pow2)))
+	     (fftlen (floor (expt 2 (ceiling (log len 2)))))
 	     (fftlen2 (/ fftlen 2))
 	     (fft-1 (- (* n fftlen) 1))
 	     (fftscale (/ 1.0 fftlen))
@@ -176,7 +173,7 @@ squeezing in the frequency domain, then using the inverse DFT to get the time do
 	  ;; DFT + split
 	  (if (< i n2)
 	      (set! (fr i) (edot-product (* freq 0.0-1.0i i) in-data))
-	      (set! (fr (+ i (- out-n n 1))) (edot-product (* freq 0.0-1.0i i) in-data))))
+	      (set! (fr (- (+ i out-n) n 1)) (edot-product (* freq 0.0-1.0i i) in-data))))
 	(set! freq (/ (* 2 pi) out-n))
 	(do ((i 0 (+ i 1)))
 	    ((= i out-n))
@@ -228,7 +225,7 @@ squeezing in the frequency domain, then using the inverse DFT to get the time do
 	 (s1 (- size 1)))
     (float-vector-scale! x2 (/ -1.0 denom))
     (copy x1 x0)
-    (float-vector-scale! x0 (/ (+ 2.0 (- dm (* 2.0 km))) denom))
+    (float-vector-scale! x0 (/ (- (+ 2.0 dm) (* 2.0 km)) denom))
     (float-vector-add! x0 x2)
     (set! (x0 0) (+ (x0 0) (* p2 (+ (x1 s1) (x1 1)))))
     (do ((i 1 (+ i 1)))
@@ -247,7 +244,7 @@ squeezing in the frequency domain, then using the inverse DFT to get the time do
 	    (km (/ (xsprings i) mass))
 	    (cm (/ (esprings i) mass)))
 	(let ((denom (+ 1.0 dm cm)))
-	  (let ((p1 (/ (+ 2.0 (- dm (* 2.0 km))) denom))
+	  (let ((p1 (/ (- (+ 2.0 dm) (* 2.0 km)) denom))
 		(p2 (/ km denom))
 		(p3 (/ -1.0 denom))
 		(p4 (/ (haptics i) (* mass denom)))
@@ -352,8 +349,7 @@ squeezing in the frequency domain, then using the inverse DFT to get the time do
 (define spot-freq
   (let ((documentation "(spot-freq samp snd chn) tries to determine the current pitch: (spot-freq (left-sample))"))
     (lambda* (s0 snd chn)
-      (let* ((pow2 (ceiling (log (/ (srate snd) 20.0) 2)))
-	     (fftlen (floor (expt 2 pow2)))
+      (let* ((fftlen (floor (expt 2 (ceiling (log (/ (srate snd) 20.0) 2)))))
 	     (data (autocorrelate (channel->float-vector s0 fftlen snd chn)))
 	     (cor-peak (float-vector-peak data)))
 	(if (= cor-peak 0.0)
@@ -384,23 +380,22 @@ squeezing in the frequency domain, then using the inverse DFT to get the time do
 (define chorus
   (let ((documentation "(chorus) tries to produce the chorus sound effect"))
     (lambda ()
+      (let ((make-flanger
+	     (let ((chorus-time .05)
+		   (chorus-amount 20.0)
+		   (chorus-speed 10.0))
+	       (lambda ()
+		 (let ((ri (make-rand-interp :frequency chorus-speed :amplitude chorus-amount))
+		       (len (floor (random (* 3.0 chorus-time (srate))))))
+		   (list (make-delay len :max-size (+ len chorus-amount 1)) ri)))))
+
+	    (flanger (lambda (dly inval)
+		       (+ inval 
+			  (delay (car dly)
+				 inval
+				 (rand-interp (cadr dly))))))
+	    (dlys (make-vector chorus-size)))
 
-      (define make-flanger
-	(let ((chorus-time .05)
-	      (chorus-amount 20.0)
-	      (chorus-speed 10.0))
-	  (lambda ()
-	    (let ((ri (make-rand-interp :frequency chorus-speed :amplitude chorus-amount))
-		  (len (floor (random (* 3.0 chorus-time (srate))))))
-	      (list (make-delay len :max-size (+ len chorus-amount 1)) ri)))))
-      
-      (define (flanger dly inval)
-	(+ inval 
-	   (delay (car dly)
-		  inval
-		  (rand-interp (cadr dly)))))
-      
-      (let ((dlys (make-vector chorus-size)))
 	(do ((i 0 (+ i 1)))
 	    ((= i chorus-size))
 	  (set! (dlys i) (make-flanger)))
@@ -436,8 +431,7 @@ squeezing in the frequency domain, then using the inverse DFT to get the time do
   (let ((documentation "(zero-phase snd chn) calls fft, sets all phases to 0, and un-ffts"))
     (lambda* (snd chn)
       (let* ((len (framples snd chn))
-	     (pow2 (ceiling (log len 2)))
-	     (fftlen (floor (expt 2 pow2)))
+	     (fftlen (floor (expt 2 (ceiling (log len 2)))))
 	     (fftscale (/ 1.0 fftlen))
 	     (rl (channel->float-vector 0 fftlen snd chn))
 	     (old-pk (float-vector-peak rl))
@@ -456,8 +450,7 @@ squeezing in the frequency domain, then using the inverse DFT to get the time do
   (let ((documentation "(rotate-phase func snd chn) calls fft, applies func to each phase, then un-ffts"))
     (lambda* (func snd chn)
       (let* ((len (framples snd chn))
-	     (pow2 (ceiling (log len 2)))
-	     (fftlen (floor (expt 2 pow2)))
+	     (fftlen (floor (expt 2 (ceiling (log len 2)))))
 	     (fftlen2 (floor (/ fftlen 2)))
 	     (fftscale (/ 1.0 fftlen))
 	     (rl (channel->float-vector 0 fftlen snd chn))
@@ -536,21 +529,20 @@ squeezing in the frequency domain, then using the inverse DFT to get the time do
 (define spectrum->coeffs
   (let ((documentation "(spectrum->coeffs order spectr) returns FIR filter coefficients given the filter order and desired spectral envelope (a float-vector)"))
     (lambda (order spectr)
-      (let* ((coeffs (make-float-vector order))
-	     (n order)
-	     (m (floor (/ (+ n 1) 2)))
-	     (am (* 0.5 (+ n 1)))
-	     (q (/ (* pi 2.0) n)))
+      (let ((coeffs (make-float-vector order))
+	    (m (floor (/ (+ order 1) 2)))
+	    (am (* 0.5 (+ order 1)))
+	    (q (/ (* pi 2.0) order)))
 	(if (not (float-vector? spectr))
 	    (error "spectrum->coeffs spectrum argument should be a float-vector"))
 	(do ((j 0 (+ j 1))
-	     (jj (- n 1) (- jj 1)))
+	     (jj (- order 1) (- jj 1)))
 	    ((= j m) coeffs)
 	  (let ((xt (* 0.5 (spectr 0))))
 	    (do ((i 1 (+ i 1)))
 		((= i m))
 	      (set! xt (+ xt (* (spectr i) (cos (* q i (- am j 1)))))))
-	    (let ((coeff (* 2.0 (/ xt n))))
+	    (let ((coeff (* 2.0 (/ xt order))))
 	      (set! (coeffs j) coeff)
 	      (set! (coeffs jj) coeff))))))))
 
@@ -823,7 +815,7 @@ squeezing in the frequency domain, then using the inverse DFT to get the time do
 				   c1)
 		     (float-vector 0.0 
 				   (* 2.0 (- r2 1.0) c1)
-				   (* (+ (- 1.0 (* r (sqrt 2.0))) r2) c1)))))))
+				   (* (- (+ 1.0 r2) (* r (sqrt 2.0))) c1)))))))
 
 (define make-butter-low-pass
   (let ((documentation "(make-butter-low-pass freq) makes a Butterworth filter with low pass cutoff at 'freq'.  The result \
@@ -836,7 +828,7 @@ can be used directly: (filter-sound (make-butter-low-pass 500.0)), or via the 'b
 		     (float-vector c1 (* 2.0 c1) c1)
 		     (float-vector 0.0 
 				   (* 2.0 (- 1.0 r2) c1)
-				   (* (+ (- 1.0 (* r (sqrt 2.0))) r2) c1)))))))
+				   (* (- (+ 1.0 r2) (* r (sqrt 2.0))) c1)))))))
 
 (define make-butter-band-pass
   (let ((documentation "(make-butter-band-pass freq band) makes a bandpass Butterworth filter with low edge at 'freq' and width 'band'"))
@@ -879,6 +871,9 @@ can be used directly: (filter-sound (make-butter-low-pass 500.0)), or via the 'b
 		   (float-vector a0 a1 a2) 
 		   (float-vector 0.0 b1 b2)))))
 
+(define (make-local-biquad a0 a1 a2 gamma beta)
+  (make-biquad a0 a1 a2 (* -2.0 gamma) (* 2.0 beta)))
+
 (define* (make-iir-low-pass-2 fc din) ; din=(sqrt 2.0) for example (suggested range 0.2.. 10)
   (let* ((theta (/ (* 2 pi fc) *clm-srate*))
 	 (d (or din (sqrt 2.0)))
@@ -886,7 +881,7 @@ can be used directly: (filter-sound (make-butter-low-pass 500.0)), or via the 'b
 			 (+ 1.0 (* (/ d 2) (sin theta))))))
 	 (gamma (* (+ 0.5 beta) (cos theta)))
 	 (alpha (* 0.5 (- (+ 0.5 beta) gamma))))
-    (make-biquad alpha (* 2.0 alpha) alpha (* -2.0 gamma) (* 2.0 beta))))
+    (make-local-biquad alpha (* 2.0 alpha) alpha gamma beta)))
 
 (define* (make-iir-high-pass-2 fc din)
   (let* ((theta (/ (* 2 pi fc) *clm-srate*))
@@ -895,7 +890,7 @@ can be used directly: (filter-sound (make-butter-low-pass 500.0)), or via the 'b
 			 (+ 1.0 (* (/ d 2) (sin theta))))))
 	 (gamma (* (+ 0.5 beta) (cos theta)))
 	 (alpha (* 0.5 (+ 0.5 beta gamma))))
-    (make-biquad alpha (* -2.0 alpha) alpha (* -2.0 gamma) (* 2.0 beta))))
+    (make-local-biquad alpha (* -2.0 alpha) alpha gamma beta)))
 
 (define (make-iir-band-pass-2 f1 f2)
   (let* ((theta (/ (* 2 pi (sqrt (* f1 f2))) *clm-srate*))
@@ -905,7 +900,7 @@ can be used directly: (filter-sound (make-butter-low-pass 500.0)), or via the 'b
 			 (+ 1.0 t2))))
 	 (gamma (* (+ 0.5 beta) (cos theta)))
 	 (alpha (- 0.5 beta)))
-    (make-biquad alpha 0.0 (- alpha) (* -2.0 gamma) (* 2.0 beta))))
+    (make-local-biquad alpha 0.0 (- alpha) gamma beta)))
 
 (define (make-iir-band-stop-2 f1 f2)
   (let* ((theta (/ (* 2 pi (sqrt (* f1 f2))) *clm-srate*))
@@ -915,7 +910,7 @@ can be used directly: (filter-sound (make-butter-low-pass 500.0)), or via the 'b
 			 (+ 1.0 t2))))
 	 (gamma (* (+ 0.5 beta) (cos theta)))
 	 (alpha (+ 0.5 beta)))
-    (make-biquad alpha (* -2.0 gamma) alpha (* -2.0 gamma) (* 2.0 beta))))
+    (make-local-biquad alpha (* -2.0 gamma) alpha gamma beta)))
 
 #|
 (define* (old-make-eliminate-hum (hum-freq 60.0) (hum-harmonics 5) (bandwidth 10))
@@ -964,7 +959,7 @@ can be used directly: (filter-sound (make-butter-low-pass 500.0)), or via the 'b
 			 (+ 1.0 t2))))
 	 (gamma (* (+ 0.5 beta) (cos theta)))
 	 (alpha (- 0.5 beta))
-	 (flt (make-biquad alpha 0.0 (- alpha) (* -2.0 gamma) (* 2.0 beta)))
+	 (flt (make-local-biquad alpha 0.0 (- alpha) gamma beta))
 	 (m1 (- m 1.0)))
     (lambda (x) (+ x (* m1 (filter flt x))))))
 
@@ -1102,7 +1097,7 @@ can be used directly: (filter-sound (make-butter-low-pass 500.0)), or via the 'b
 		 (betajk (* 0.5 (/ (- 1.0 (* 0.5 dk1 (sin thetajk)))
 				   (+ 1.0 (* 0.5 dk1 (sin thetajk))))))
 		 (gammajk (* (+ 0.5 betajk) (cos thetajk)))
-		 (alphajk (* 0.5 (+ 0.5 betajk) (/ (- 1.0 (cos thetajk)) (- 1.0 ct)))))
+		 (alphajk (/ (* 0.5 (+ 0.5 betajk) (- 1.0 (cos thetajk))) (- 1.0 ct))))
 	    (set! xcoeffs (cons (float-vector (* 2 alphajk) (* -4 ct alphajk) (* 2 alphajk)) xcoeffs))
 	    (set! ycoeffs (cons (float-vector 1.0 (* -2.0 gammajk) (* 2.0 betajk)) ycoeffs))
 	    (if (= j 1)
@@ -1191,7 +1186,7 @@ can be used directly: (filter-sound (make-butter-low-pass 500.0)), or via the 'b
     (lambda (f n z)
       ;; using vector to allow complex sums (z=e^2*pi*i/n -> fourier transform)
       ;;   (z-transform data n (exp (complex 0.0 (* (/ 2.0 n) pi))))
-      (let ((res (if (float-vector? f) (make-float-vector n) (make-vector n))))
+      (let ((res ((if (float-vector? f) make-float-vector make-vector) n)))
 	(do ((w 0 (+ 1 w)))
 	    ((= w n))
 	  (let ((sum 0.0)
@@ -1249,8 +1244,7 @@ can be used directly: (filter-sound (make-butter-low-pass 500.0)), or via the 'b
 (define goertzel
   (let ((documentation "(goertzel freq beg dur snd) returns the amplitude of the 'freq' spectral component"))
     (lambda* (freq (beg 0) dur snd)
-      (let* ((sr (srate snd))
-	     (rfreq (/ (* 2.0 pi freq) sr))
+      (let* ((rfreq (/ (* 2.0 pi freq) (srate snd)))
 	     (cs (* 2.0 (cos rfreq))))
 	(let ((reader (make-sampler beg snd 0))
 	      (len (- (if (number? dur) dur (- (framples snd 0) beg)) 2))
@@ -1281,7 +1275,7 @@ can be used directly: (filter-sound (make-butter-low-pass 500.0)), or via the 'b
   (let ((documentation "(make-spencer-filter) is a version of make-fir-filter; it returns one of the standard smoothing filters from \
 the era when computers were human beings"))
     (lambda ()
-      (make-fir-filter 15 (apply float-vector (map (lambda (n) (/ n 320.0)) (list -3 -6 -5 3 21 46 67 74 67 46 21 3 -5 -6 -3)))))))
+      (make-fir-filter 15 (apply float-vector (map (lambda (n) (/ n 320.0)) '(-3 -6 -5 3 21 46 67 74 67 46 21 3 -5 -6 -3)))))))
 
 
 ;;; -------- any-random
@@ -1294,9 +1288,8 @@ the era when computers were human beings"))
       (if (not e)
 	  (random amount)
 	  (let next-random ()
-	    (let* ((len (length e))
-		   (x (random (* 1.0 (e (- len 2)))))
-		   (y (random 1.0)))
+	    (let ((x (random (* 1.0 (e (- (length e) 2)))))
+		  (y (random 1.0)))
 	      (if (<= y (envelope-interp x e))
 		  x
 		  (next-random)))))))
@@ -1559,7 +1552,7 @@ shift the given channel in pitch without changing its length.  The higher 'order
     (let ((data (channel->float-vector beg dur snd chn edpos)))
       (let ((len (length data))
 	    (mx (float-vector-peak data)))
-	(let ((summer (make-float-vector len 0.0)))
+	(let ((summer (make-float-vector len)))
 	  (set! *output* summer)
 	  (do ((i 0 (+ i 1)))
 	      ((= i pairs))
@@ -1597,7 +1590,7 @@ shift the given channel in pitch without changing its length.  The higher 'order
     (let ((data (channel->float-vector beg dur snd chn edpos)))
       (let ((len (length data))
 	    (mx (float-vector-peak data)))
-	(let ((summer (make-float-vector len 0.0)))
+	(let ((summer (make-float-vector len)))
 	  (set! *output* summer)
 	  (do ((i 0 (+ i 1)))
 	      ((= i pairs))
@@ -1665,8 +1658,8 @@ shift the given channel in pitch without changing its length.  The higher 'order
 	 (fft-len (if (< num-coeffs 2) 
 		      len 
 		      (expt 2 (ceiling (log (* (- num-coeffs 1) len) 2)))))
-	 (rl1 (make-float-vector fft-len 0.0))
-	 (rl2 (make-float-vector fft-len 0.0))
+	 (rl1 (make-float-vector fft-len))
+	 (rl2 (make-float-vector fft-len))
 	 (newv (make-float-vector fft-len)))
     (if (> (coeffs 0) 0.0)
 	(let ((dither (coeffs 0)))
@@ -1961,8 +1954,7 @@ and replaces it with the spectrum given in coeffs"))
 	(let* ((snd (hook 'snd))
 	       (chn (hook 'chn))
 	       (ls (left-sample snd chn))
-	       (rs (right-sample snd chn))
-	       (fftlen (floor (expt 2 (ceiling (log (+ 1 (- rs ls)) 2))))))
+	       (fftlen (floor (expt 2 (ceiling (log (- (+ (right-sample snd chn) 1) ls) 2))))))
 	  (when (> fftlen 0)
 	    (let ((data (channel->float-vector ls fftlen snd chn))
 		  (normalized (not (= (transform-normalization snd chn) dont-normalize)))
@@ -1979,20 +1971,17 @@ and replaces it with the spectrum given in coeffs"))
 			   
 			   ;; bark settings
 			   (bark-low (floor (bark 20.0)))
-			   (bark-high (ceiling (bark (* 0.5 sr))))
-			   (bark-frqscl (/ data-len (- bark-high bark-low)))
+			   (bark-frqscl (/ data-len (- (ceiling (bark (* 0.5 sr))) bark-low)))
 			   (bark-data (make-float-vector data-len))
 			   
 			   ;; mel settings
 			   (mel-low (floor (mel 20.0)))
-			   (mel-high (ceiling (mel (* 0.5 sr))))
-			   (mel-frqscl (/ data-len (- mel-high mel-low)))
+			   (mel-frqscl (/ data-len (- (ceiling (mel (* 0.5 sr))) mel-low)))
 			   (mel-data (make-float-vector data-len))
 			   
 			   ;; erb settings
 			   (erb-low (floor (erb 20.0)))
-			   (erb-high (ceiling (erb (* 0.5 sr))))
-			   (erb-frqscl (/ data-len (- erb-high erb-low)))
+			   (erb-frqscl (/ data-len (- (ceiling (erb (* 0.5 sr))) erb-low)))
 			   (erb-data (make-float-vector data-len)))
 		      
 		      (set! bark-fft-size fftlen)
@@ -2049,72 +2038,69 @@ and replaces it with the spectrum given in coeffs"))
 		 (minor-tick-len 6)
 		 (major-tick-len 12)
 		 (bark-label-font (snd-font 3))
-		 (label-pos (+ axis-x0 (* .45 (- axis-x1 axis-x0))))
-		 (cr (make-cairo (car (channel-widgets snd chn)))))
+		 (label-pos (round (+ axis-x0 (* .45 (- axis-x1 axis-x0)))))
+		 (cr (make-cairo (car (channel-widgets snd chn))))
+		 (scale-position (let ((sr2 (* 0.5 (srate snd))))
+				   (lambda (scale f)
+				     (let ((b20 (scale 20.0)))
+				       (round (+ axis-x0 
+						 (/ (* (- axis-x1 axis-x0) (- (scale f) b20)) 
+						    (- (scale sr2) b20))))))))
+		 (bark-position (lambda (f) (scale-position bark f)))
+		 (mel-position (lambda (f) (scale-position mel f)))
+		 (erb-position (lambda (f) (scale-position erb f))))
 	    
-	    (define scale-position 
-	      (let ((sr2 (* 0.5 (srate snd))))
-		(lambda (scale f)
-		  (let ((b20 (scale 20.0)))
-		    (round (+ axis-x0 
-			      (/ (* (- axis-x1 axis-x0) (- (scale f) b20)) 
-				 (- (scale sr2) b20))))))))
-	    
-	    (define (bark-position f) (scale-position bark f))
-	    (define (mel-position f) (scale-position mel f))
-	    (define (erb-position f) (scale-position erb f))
-	    
-	    (define draw-bark-ticks
-	      (let ((tick-y0 axis-y1)
-		    (minor-y0 (+ axis-y1 minor-tick-len))
-		    (major-y0 (+ axis-y1 major-tick-len))
-		    (axis-y0 (axinfo 13))
-		    (bark-numbers-font (snd-font 2)))
-		
-		(lambda (bark-function)
-		  (if bark-numbers-font (set! (current-font snd chn copy-context) bark-numbers-font))
-		  
-		  (draw-line axis-x0 tick-y0 axis-x0 major-y0 snd chn copy-context cr)
-		  (let ((i1000 (scale-position bark-function 1000.0))
-			(i10000 (scale-position bark-function 10000.0)))
-		    
-		    (draw-line i1000 tick-y0 i1000 major-y0 snd chn copy-context cr)
-		    (draw-line i10000 tick-y0 i10000 major-y0 snd chn copy-context cr)
-		    
-		    (draw-string "20" axis-x0 major-y0 snd chn copy-context cr)
-		    (draw-string "1000" (- i1000 12) major-y0 snd chn copy-context cr)
-		    (draw-string "10000" (- i10000 24) major-y0 snd chn copy-context cr)
-		    
-		    (draw-string (format #f "fft size: ~D" bark-fft-size) (+ axis-x0 10) axis-y0 snd chn copy-context cr)
-		    
-		    (do ((i 100 (+ i 100)))
-			((= i 1000))
-		      (let ((i100 (scale-position bark-function i)))
-			(draw-line i100 tick-y0 i100 minor-y0 snd chn copy-context cr)))
-		    
-		    (do ((i 2000 (+ i 1000)))
-			((= i 10000))
-		      (let ((i1000 (scale-position bark-function i)))
-			(draw-line i1000 tick-y0 i1000 minor-y0 snd chn copy-context cr)))))))
-	    
-	    ;; bark label/ticks
-	    (set! (foreground-color snd chn copy-context) color1)
-	    (if (= bark-tick-function 0) (draw-bark-ticks bark-position))
-	    (if bark-label-font (set! (current-font snd chn copy-context) bark-label-font))
-	    (draw-string "bark," label-pos (+ axis-y1 label-height) snd chn copy-context cr)
-	    
-	    ;; mel label/ticks
-	    (set! (foreground-color snd chn copy-context) color2)
-	    (if (= bark-tick-function 1) (draw-bark-ticks mel-position))
-	    (if bark-label-font (set! (current-font snd chn copy-context) bark-label-font))
-	    (draw-string "mel," (+ (* char-width 6) label-pos) (+ axis-y1 label-height) snd chn copy-context cr)
-	    
-	    ;; erb label/ticks
-	    (set! (foreground-color snd chn copy-context) color3)
-	    (if (= bark-tick-function 2) (draw-bark-ticks erb-position))
-	    (if bark-label-font (set! (current-font snd chn copy-context) bark-label-font))
-	    (draw-string "erb" (+ (* char-width 11) label-pos) (+ axis-y1 label-height) snd chn copy-context cr)
-	    (free-cairo cr))
+	    (let ((draw-bark-ticks
+		   (let ((tick-y0 axis-y1)
+			 (minor-y0 (+ axis-y1 minor-tick-len))
+			 (major-y0 (+ axis-y1 major-tick-len))
+			 (axis-y0 (axinfo 13))
+			 (bark-numbers-font (snd-font 2)))
+		     
+		     (lambda (bark-function)
+		       (if bark-numbers-font (set! (current-font snd chn copy-context) bark-numbers-font))
+		       
+		       (draw-line axis-x0 tick-y0 axis-x0 major-y0 snd chn copy-context cr)
+		       (let ((i1000 (scale-position bark-function 1000.0))
+			     (i10000 (scale-position bark-function 10000.0)))
+			 
+			 (draw-line i1000 tick-y0 i1000 major-y0 snd chn copy-context cr)
+			 (draw-line i10000 tick-y0 i10000 major-y0 snd chn copy-context cr)
+			 
+			 (draw-string "20" axis-x0 major-y0 snd chn copy-context cr)
+			 (draw-string "1000" (- i1000 12) major-y0 snd chn copy-context cr)
+			 (draw-string "10000" (- i10000 24) major-y0 snd chn copy-context cr)
+			 
+			 (draw-string (format #f "fft size: ~D" bark-fft-size) (+ axis-x0 10) axis-y0 snd chn copy-context cr)
+			 
+			 (do ((i 100 (+ i 100)))
+			     ((= i 1000))
+			   (let ((i100 (scale-position bark-function i)))
+			     (draw-line i100 tick-y0 i100 minor-y0 snd chn copy-context cr)))
+			 
+			 (do ((i 2000 (+ i 1000)))
+			     ((= i 10000))
+			   (let ((i1000 (scale-position bark-function i)))
+			     (draw-line i1000 tick-y0 i1000 minor-y0 snd chn copy-context cr))))))))
+	      
+	      ;; bark label/ticks
+	      (set! (foreground-color snd chn copy-context) color1)
+	      (if (= bark-tick-function 0) (draw-bark-ticks bark-position))
+	      (if bark-label-font (set! (current-font snd chn copy-context) bark-label-font))
+	      (draw-string "bark," label-pos (+ axis-y1 label-height) snd chn copy-context cr)
+	      
+	      ;; mel label/ticks
+	      (set! (foreground-color snd chn copy-context) color2)
+	      (if (= bark-tick-function 1) (draw-bark-ticks mel-position))
+	      (if bark-label-font (set! (current-font snd chn copy-context) bark-label-font))
+	      (draw-string "mel," (+ (* char-width 6) label-pos) (+ axis-y1 label-height) snd chn copy-context cr)
+	      
+	      ;; erb label/ticks
+	      (set! (foreground-color snd chn copy-context) color3)
+	      (if (= bark-tick-function 2) (draw-bark-ticks erb-position))
+	      (if bark-label-font (set! (current-font snd chn copy-context) bark-label-font))
+	      (draw-string "erb" (+ (* char-width 11) label-pos) (+ axis-y1 label-height) snd chn copy-context cr)
+	      (free-cairo cr)))
 	  
 	  (set! (foreground-color snd chn copy-context) old-foreground-color)))
       
@@ -2163,10 +2149,10 @@ and replaces it with the spectrum given in coeffs"))
     (lambda (data n m)
       
       ;; translated and changed to use 0-based arrays from memcof of NRinC
-      (let ((d (make-float-vector m 0.0))
-	    (wk1 (make-float-vector n 0.0))
-	    (wk2 (make-float-vector n 0.0))
-	    (wkm (make-float-vector n 0.0)))
+      (let ((d (make-float-vector m))
+	    (wk1 (make-float-vector n))
+	    (wk2 (make-float-vector n))
+	    (wkm (make-float-vector n)))
 	(copy data wk1)
 	(do ((j 1 (+ j 1))
 	     (k 0 (+ k 1)))
@@ -2204,8 +2190,8 @@ and replaces it with the spectrum given in coeffs"))
 'n' data points of 'data' (a float-vector), and produces 'nf' new data points (in a float-vector) as its prediction. If 'clipped' is #t, the new data \
 is assumed to be outside -1.0 to 1.0."))
     (lambda* (data n coeffs m nf clipped)
-      (let ((future (make-float-vector nf 0.0))
-	    (reg (make-float-vector m 0.0)))
+      (let ((future (make-float-vector nf))
+	    (reg (make-float-vector m)))
 	(do ((i 0 (+ i 1))
 	     (j (- n 1) (- j 1)))
 	    ((= i m))
@@ -2270,9 +2256,8 @@ is assumed to be outside -1.0 to 1.0."))
 		     ((>= clip clips))
 		   (let* ((clip-beg (clip-data clip))  ; clip-beg to clip-end inclusive are clipped
 			  (clip-end (clip-data (+ 1 clip)))
-			  (clip-len (+ 1 (- clip-end clip-beg)))
-			  (min-data-len 32)  
-			  (data-len (max min-data-len (* clip-len 4))))
+			  (clip-len (- (+ clip-end 1) clip-beg))
+			  (data-len (max 32 (* clip-len 4))))
 		     
 		     (set! max-len (max max-len clip-len))
 		     
@@ -2306,7 +2291,7 @@ is assumed to be outside -1.0 to 1.0."))
 				       backward-predict-len
 				       clip-len #f))
 				
-				(new-data (make-float-vector clip-len 0.0)))
+				(new-data (make-float-vector clip-len)))
 			   
 			   (if (> clip-len 1)
 			       (do ((i 0 (+ i 1))
@@ -2323,9 +2308,7 @@ is assumed to be outside -1.0 to 1.0."))
 			       ;; todo perhaps if multichannel and channels are correlated and one is not clipped -- use
 			       ;;   its data to help reconstruct clipped case?
 			       
-			       (set! (new-data 0) (if (> (future 0) 0.0)
-						      (max (future 0) (past 0))
-						      (min (future 0) (past 0)))))
+			       (set! (new-data 0) ((if (> (future 0) 0.0) max min) (future 0) (past 0))))
 			   
 			   ;; write reconstruction
 			   (float-vector->channel new-data clip-beg clip-len snd chn))))))))
@@ -2426,8 +2409,8 @@ is assumed to be outside -1.0 to 1.0."))
 	       (set! (pivots col) (+ (pivots col) 1))
 					;(format () "i: ~D, row: ~D, col: ~A~%" i row col)
 	       (if (not (= row col))
-		   (let ((temp (if b (b row) 0.0)))
-		     (if b
+		   (let ((temp (if (sequence? b) (b row) 0.0)))
+		     (if (sequence? b)
 			 (begin
 			   (set! (b row) (b col))
 			   (set! (b col) temp)))
@@ -2473,7 +2456,7 @@ is assumed to be outside -1.0 to 1.0."))
   (if (even? size) 
       (set! size (+ size 1)))
   (let ((n (/ (- size 1) 2))
-	(a (make-float-vector (list (+ 1 order) (+ 1 order)) 0.0)))
+	(a (make-float-vector (list (+ 1 order) (+ 1 order)))))
     (do ((i 0 (+ i 1)))
 	((> i (* order 2)))
       (let ((sum (if (= i 0) 1.0 0.0)))
@@ -2488,10 +2471,10 @@ is assumed to be outside -1.0 to 1.0."))
 	  (do ((k (- m) (+ k 2)))
 	      ((> k m))
 	    (set! (a (/ (+ i k) 2) (/ (- i k) 2)) sum)))))
-    (let ((b (matrix-solve a (let ((f (make-float-vector (+ order 1) 0.0)))
+    (let ((b (matrix-solve a (let ((f (make-float-vector (+ order 1))))
 			       (set! (f 0) 1.0) ; set others instead for derivative
 			       f)))
-	  (result (make-float-vector size 0.0)))
+	  (result (make-float-vector size)))
       (do ((k (- n) (+ k 1))
 	   (i 0 (+ i 1)))
 	  ((> k n))
