@@ -62,29 +62,27 @@
             pos
             (search-point (cddr e) (+ pos 2)))))
     
-    (define on-dot? 
-      (let ((mouse-radius .03))
-	(lambda (x y cur-env pos)
-	  (and (pair? cur-env)
-	       (pair? (cdr cur-env))
-	       (or (and (< (abs (- (car cur-env) x)) mouse-radius)
-			(< (abs (- (cadr cur-env) y)) mouse-radius)
-			pos)
-		   (on-dot? x y (cddr cur-env) (+ pos 2)))))))
-    
-    (let* ((x (max 0.0 (min ux 1.0)))
-	   (y (max 0.0 (min uy 1.0)))
-	   (cur-env (channel-envelope snd chn))
-	   (pos (on-dot? x y cur-env 0)))
-      (set! mouse-new (not pos))
-      (set! mouse-down (get-internal-real-time))
-      (if pos
-	  (set! mouse-pos pos)
-	  (let ((new-x (max 0.001 (min x .999))))
-	    (set! (channel-envelope snd chn) 
-		  (add-envelope-point new-x y cur-env))
-	    (set! mouse-pos (envelope-position new-x (channel-envelope snd chn))))))))
-	  
+    (letrec ((on-dot? (let ((mouse-radius .03))
+			(lambda (x y cur-env pos)
+			  (and (pair? cur-env)
+			       (pair? (cdr cur-env))
+			       (or (and (< (abs (- (car cur-env) x)) mouse-radius)
+					(< (abs (- (cadr cur-env) y)) mouse-radius)
+					pos)
+				   (on-dot? x y (cddr cur-env) (+ pos 2))))))))
+      (let* ((x (max 0.0 (min ux 1.0)))
+	     (y (max 0.0 (min uy 1.0)))
+	     (cur-env (channel-envelope snd chn))
+	     (pos (on-dot? x y cur-env 0)))
+	(set! mouse-new (not pos))
+	(set! mouse-down (get-internal-real-time))
+	(if pos
+	    (set! mouse-pos pos)
+	    (let ((new-x (max 0.001 (min x .999))))
+	      (set! (channel-envelope snd chn) 
+		    (add-envelope-point new-x y cur-env))
+	      (set! mouse-pos (envelope-position new-x (channel-envelope snd chn)))))))))
+
 
 (define (mouse-drag-envelope hook)
   (let ((snd (hook 'snd))
