@@ -82,7 +82,7 @@
     (lambda* (snd chn)
       (let ((wl (left-sample snd chn))
 	    (wr (right-sample snd chn)))
-	(channel->float-vector wl (+ 1 (- wr wl)) snd chn)))))
+	(channel->float-vector wl (- (+ wr 1) wl) snd chn)))))
 
 
 (define display-energy 
@@ -135,8 +135,7 @@
   (let ((documentation "(window-rms) -> rms of data in currently selected graph window"))
     (lambda ()
       (let* ((ls (left-sample))
-	     (rs (right-sample))
-	     (data (channel->float-vector ls (+ 1 (- rs ls))))
+	     (data (channel->float-vector ls (- (+ (right-sample) 1) ls)))
 	     (len (length data)))
 	(sqrt (/ (dot-product data data) len))))))
 
@@ -183,10 +182,7 @@
 		      (> (framples snd 1) 1)))
 	    (status-report "display-correlation wants stereo input")
 	    (let* ((ls (left-sample snd 0))
-		   (rs (right-sample snd 0))
-		   (ilen (+ 1 (- rs ls)))
-		   (pow2 (ceiling (log ilen 2)))
-		   (fftlen (floor (expt 2 pow2)))
+		   (fftlen (floor (expt 2 (ceiling (log (- (+ (right-sample snd 0) 1) ls) 2)))))
 		   (fftscale (/ 1.0 fftlen))
 		   (rl1 (channel->float-vector ls fftlen snd 0))
 		   (rl2 (channel->float-vector ls fftlen snd 1))
@@ -248,8 +244,7 @@
 								   (+ 1 maxsync)))
 							     (sounds))))))
 	    (let* ((ls (left-sample snd chn))
-		   (rs (right-sample snd chn))
-		   (pow2 (ceiling (log (max 1 (- rs ls)) 2)))
+		   (pow2 (ceiling (log (max 1 (- (right-sample snd chn) ls)) 2)))
 		   (fftlen (floor (expt 2 pow2))))
 	      (if (> pow2 2)
 		  (let ((ffts ()))
@@ -466,23 +461,22 @@ read an ASCII sound file"))
       (let* ((keysnd (or (selected-sound) (car (sounds))))
 	     (keychn (or (selected-channel keysnd) 0))
 	     (chan-marks (marks keysnd keychn)))
-	(define find-leftmost-mark 
-	  (let ((current-left-sample (left-sample keysnd keychn)))
-	    (lambda (samps)
-	      (and (pair? samps)
-		   (if (> (car samps) current-left-sample)
-		       (car samps)
-		       (find-leftmost-mark (cdr samps)))))))
-	(if (null? chan-marks)
-	    (status-report "no marks!")
-	    (let ((leftmost (find-leftmost-mark (map mark-sample chan-marks))))
-	      (if (number? leftmost)
-		  (begin
-		    (set! (left-sample keysnd keychn) leftmost)
-		    keyboard-no-action)
-		  (status-report "no mark in window"))))))))
+	(letrec ((find-leftmost-mark (let ((current-left-sample (left-sample keysnd keychn)))
+				       (lambda (samps)
+					 (and (pair? samps)
+					      (if (> (car samps) current-left-sample)
+						  (car samps)
+						  (find-leftmost-mark (cdr samps))))))))
+	  (if (null? chan-marks)
+	      (status-report "no marks!")
+	      (let ((leftmost (find-leftmost-mark (map mark-sample chan-marks))))
+		(if (number? leftmost)
+		    (begin
+		      (set! (left-sample keysnd keychn) leftmost)
+		      keyboard-no-action)
+		    (status-report "no mark in window")))))))))
     
-					;(bind-key #\m 0 (lambda () "align window left edge with mark" (first-mark-in-window-at-left)))
+;; (bind-key #\m 0 (lambda () "align window left edge with mark" (first-mark-in-window-at-left)))
 
 
 ;;; -------- flash selected data red and green
@@ -780,8 +774,7 @@ then inverse ffts."))
 (define fft-env-data 
   (let ((documentation "(fft-env-data fft-env snd chn) applies fft-env as spectral env to current sound, returning float-vector of new data"))
     (lambda* (fft-env snd chn)
-      (let* ((len (framples snd chn))
-	     (fsize (expt 2 (ceiling (log len 2))))
+      (let* ((fsize (expt 2 (ceiling (log (framples snd chn) 2))))
 	     (rdata (channel->float-vector 0 fsize snd chn))
 	     (idata (make-float-vector fsize))
 	     (e (make-env (concatenate-envelopes fft-env (reverse-envelope fft-env)) :length fsize))
@@ -1089,9 +1082,8 @@ formants, then calls map-channel: (osc-formants .99 (float-vector 400.0 800.0 12
 (define ring-mod 
   (let ((documentation "(ring-mod freq gliss-env) returns a time-varying ring-modulation filter: (map-channel (ring-mod 10 (list 0 0 1 (hz->radians 100))))"))
     (lambda (freq gliss-env)
-      (let* ((os (make-oscil :frequency freq))
-	     (len (framples))
-	     (genv (make-env gliss-env :length len)))
+      (let ((os (make-oscil :frequency freq))
+	    (genv (make-env gliss-env :length (framples))))
 	(lambda (inval)
 	  (* (oscil os (env genv)) inval))))))
 
@@ -1195,8 +1187,7 @@ to produce a sound at a new pitch but at the original tempo.  It returns a funct
 				 :jitter 0
 				 :input (make-sampler 0 snd chn)))
 	     (ge (make-env gr-env :duration dur))
-	     (sound-len (round (* (srate snd) dur)))
-	     (len (max sound-len (framples snd chn)))
+	     (len (max (round (* (srate snd) dur)) (framples snd chn)))
 	     (out-data (make-float-vector len)))
 	(do ((i 0 (+ i 1)))
 	    ((= i len))
