@@ -17,8 +17,8 @@
 
 (define remove-if 
   (let ((documentation "(remove-if func lst) removes any element from 'lst' that 'func' likes"))
-    (lambda (pred l)
-      (map (lambda (x) (if (pred x) (values) x)) l))))
+    (lambda (pred lst)
+      (map (lambda (x) (if (pred x) (values) x)) lst))))
 
 
 (if (not (defined? 'all-chans))
@@ -55,14 +55,14 @@ two sounds open (indices 0 and 1 for example), and the second has two channels,
       (let ((original-maxamp (maxamp snd chn)))
 	(mix filename beg in-chan snd chn)
 	(let ((new-maxamp (maxamp snd chn)))
-	  (if (not (= original-maxamp new-maxamp))
+	  (if (= original-maxamp new-maxamp)
+	      1.0
 	      (let ((scaler (/ original-maxamp new-maxamp))
 		    (old-sync (sync snd)))
 		(set! (sync snd) (+ (sync-max) 1))
 		(scale-by scaler snd chn)
 		(set! (sync snd) old-sync)
-		scaler)
-	      1.0))))))
+		scaler)))))))
 
 
 ;;;-------- mix with envelope on mixed-in file
@@ -112,15 +112,13 @@ two sounds open (indices 0 and 1 for example), and the second has two channels,
   (let ((documentation "(match-sound-files func dir) applies func to each sound file in dir and returns a list of files for which func does not return #f"))
     (lambda* (func dir)
       (let ((matches ()))
-	(for-each
-	 (lambda (file)
-	   (if (func file)
-	       (set! matches (cons file matches))))
-	 (sound-files-in-directory (or dir ".")))
+	(for-each-sound-file (lambda (file) 
+			       (if (func file) 
+				   (set! matches (cons file matches)))) 
+			     dir)
 	matches))))
 
 
-
 ;;; -------- mix-channel, insert-channel, c-channel
 
 (define mix-channel 
@@ -157,38 +155,32 @@ a list (file-name-or-sound-object [beg [channel]])."))
 	     (start (or beg 0)))
 	(if (< start 0) 
 	    (error 'no-such-sample "mix-channel: begin time < 0: ~A" beg)
-	    (if (> len 0)
-		(if (not with-tag)
-		    
-		    ;; not a virtual mix
-		    (let ((d1 (samples input-beg len input input-channel))
-			  (d2 (samples start len snd chn edpos)))
-		      (float-vector-add! d1 d2)
-		      (float-vector->channel d1 start len snd chn current-edit-position
-					     (if (string? input-data)
-						 (format #f "mix-channel ~S ~A ~A" input-data beg dur)
-						 (format #f "mix-channel '~A ~A ~A" input-data beg dur))))
-		    
+	    (when (> len 0)
+	      (cond ((not with-tag)
+		     ;; not a virtual mix
+		     (let ((d1 (samples input-beg len input input-channel))
+			   (d2 (samples start len snd chn edpos)))
+		       (float-vector-add! d1 d2)
+		       (float-vector->channel d1 start len snd chn
+					      current-edit-position
+					      (format #f (if (string? input-data)
+							     "mix-channel ~S ~A ~A"
+							     "mix-channel '~A ~A ~A")
+						      input-data beg dur))))
 		    ;; a virtual mix -- use simplest method available
-		    (if (sound? input)
-			
-			;; sound object case
-			(channel->mix input input-channel input-beg len snd chn start)
-			
-			;; file input
-			(if (and (= start 0) 
-				 (= len (framples input)))
-			    
-			    ;; mixing entire file
-			    (mix input start 0 snd chn #t #f) ; don't delete it!
-			    
-			    ;; mixing part of file
-			    (let* ((output-name (snd-tempnam))
-				   (output (new-sound output-name :size len)))
-			      (float-vector->channel (samples input-beg len input input-channel) 0 len output 0)
-			      (save-sound output)
-			      (close-sound output)
-			      (mix output-name start 0 snd chn #t #t)))))))))))
+		    ((sound? input)          ; sound object case
+		     (channel->mix input input-channel input-beg len snd chn start))
+		    ((and (= start 0)        ; file input
+			  (= len (framples input)))
+		     (mix input start 0 snd chn #t #f)) ; mix entire file (don't delete it)
+		    (else
+		     ;; mix part of file
+		     (let* ((output-name (snd-tempnam))
+			    (output (new-sound output-name :size len)))
+		       (float-vector->channel (samples input-beg len input input-channel) 0 len output 0)
+		       (save-sound output)
+		       (close-sound output)
+		       (mix output-name start 0 snd chn #t #t))))))))))
 
 
 (define insert-channel 
@@ -210,9 +202,10 @@ a list (file-name-or-sound-object [beg [channel]])."))
 	    (insert-samples start len 
 			    (samples file-beg len file-name file-channel)
 			    snd chn edpos #f 
-			    (if (string? file-data)
-				(format #f "insert-channel ~S ~A ~A" file-data beg dur)
-				(format #f "insert-channel '~A ~A ~A" file-data beg dur))))))))
+			    (format #f (if (string? file-data)
+					   "insert-channel ~S ~A ~A"
+					   "insert-channel '~A ~A ~A")
+				    file-data beg dur)))))))
 
 
 ;;; -------- redo-channel, undo-channel
@@ -240,33 +233,33 @@ a list (file-name-or-sound-object [beg [channel]])."))
 connects them with 'func', and applies the result as an amplitude envelope to the given channel"))
     (lambda* (e func (beg 0) dur snd chn edpos origin)
       ;; handled as a sequence of funcs and scales
-      (if (pair? e)
-	  (let ((pts (/ (length e) 2)))
-	    (if (= pts 1)
-		(scale-channel (car e) beg dur snd chn edpos)
-		(let ((x0 0)
-		      (y0 0)
-		      (x1 (car e))
-		      (y1 (cadr e))
-		      (xrange (- (e (- (length e) 2)) (car e)))
-		      (ramp-beg beg)
-		      (ramp-dur 0))
-		  (if (not (number? dur)) (set! dur (framples snd chn)))
-		  (as-one-edit 
-		   (lambda ()
-		     (do ((i 1 (+ 1 i))
-			  (j 2 (+ j 2)))
-			 ((= i pts))
-		       (set! x0 x1)
-		       (set! y0 y1)
-		       (set! x1 (e j))
-		       (set! y1 (e (+ 1 j)))
-		       (set! ramp-dur (round (* dur (/ (- x1 x0) xrange))))
-		       (if (= y0 y1)
-			   (scale-channel y0 ramp-beg ramp-dur snd chn edpos)
-			   (func y0 y1 ramp-beg ramp-dur snd chn edpos))
-		       (set! ramp-beg (+ ramp-beg ramp-dur))))
-		   origin))))))))
+      (when (pair? e)
+	(let ((pts (/ (length e) 2)))
+	  (if (= pts 1)
+	      (scale-channel (car e) beg dur snd chn edpos)
+	      (let ((x0 0)
+		    (y0 0)
+		    (x1 (car e))
+		    (y1 (cadr e))
+		    (xrange (- (e (- (length e) 2)) (car e)))
+		    (ramp-beg beg)
+		    (ramp-dur 0))
+		(if (not (number? dur)) (set! dur (framples snd chn)))
+		(as-one-edit 
+		 (lambda ()
+		   (do ((i 1 (+ 1 i))
+			(j 2 (+ j 2)))
+		       ((= i pts))
+		     (set! x0 x1)
+		     (set! y0 y1)
+		     (set! x1 (e j))
+		     (set! y1 (e (+ 1 j)))
+		     (set! ramp-dur (round (* dur (/ (- x1 x0) xrange))))
+		     (if (= y0 y1)
+			 (scale-channel y0 ramp-beg ramp-dur snd chn edpos)
+			 (func y0 y1 ramp-beg ramp-dur snd chn edpos))
+		     (set! ramp-beg (+ ramp-beg ramp-dur))))
+		 origin))))))))
 
 ;;; -------- sine-ramp sine-env-channel 
 
@@ -277,12 +270,12 @@ connects them with 'func', and applies the result as an amplitude envelope to th
 	(let ((data (samples beg len snd chn edpos))
 	      (incr (/ pi len))
 	      (scl (* 0.5 (- rmp1 rmp0))))
-	  (let ((off (+ rmp0 scl)))
-	    (do ((i 0 (+ i 1))
-		 (angle (- pi) (+ angle incr)))
-		((= i len))
-	      (float-vector-set! data i (* (float-vector-ref data i)
-					   (+ off (* scl (cos angle)))))))
+	  (do ((off (+ rmp0 scl))
+	       (i 0 (+ i 1))
+	       (angle (- pi) (+ angle incr)))
+	      ((= i len))
+	    (float-vector-set! data i (* (float-vector-ref data i)
+					 (+ off (* scl (cos angle))))))
 	  (float-vector->channel data 
 				 beg len snd chn current-edit-position
 				 (format #f "sine-ramp ~A ~A ~A ~A" rmp0 rmp1 beg dur)))))))
@@ -448,14 +441,14 @@ connects them with 'func', and applies the result as an amplitude envelope to th
 (define dither-channel 
   (let ((documentation "(dither-channel (amount .00006) (beg 0) dur snd chn edpos) adds amount dither to each sample"))
     (lambda* ((amount .00006) (beg 0) dur snd chn edpos)
-      (let ((dither (* .5 amount)))
-	(let* ((len (if (number? dur) dur (- (framples snd chn) beg)))
-	       (data (samples beg len snd chn edpos)))
-	  (do ((i 0 (+ i 1)))
-	      ((= i len))
-	    (float-vector-set! data i (+ (float-vector-ref data i) (mus-random dither) (mus-random dither))))
-	  (float-vector->channel data beg len snd chn current-edit-position
-				 (format #f "dither-channel ~,8F ~A ~A" amount beg dur)))))))
+      (let* ((dither (* .5 amount))
+	     (len (if (number? dur) dur (- (framples snd chn) beg)))
+	     (data (samples beg len snd chn edpos)))
+	(do ((i 0 (+ i 1)))
+	    ((= i len))
+	  (float-vector-set! data i (+ (float-vector-ref data i) (mus-random dither) (mus-random dither))))
+	(float-vector->channel data beg len snd chn current-edit-position
+			       (format #f "dither-channel ~,8F ~A ~A" amount beg dur))))))
 
 
 (define dither-sound 
@@ -554,10 +547,8 @@ connects them with 'func', and applies the result as an amplitude envelope to th
 (define channels-equal? 
   (let ((documentation "(channels-equal? s1 c1 s2 c2 (diff 0.0)) -> #t if the two channels are the same (within diff)"))
     (lambda* (snd1 chn1 snd2 chn2 (allowable-difference 0.0))
-      (let ((len1 (framples snd1 chn1))
-	    (len2 (framples snd2 chn2)))
-	(and (= len1 len2)
-	     (channels=? snd1 chn1 snd2 chn2 allowable-difference))))))
+      (and (= (framples snd1 chn1) (framples snd2 chn2))
+	   (channels=? snd1 chn1 snd2 chn2 allowable-difference)))))
 
 
 ;;; -------- mono->stereo, mono-files->stereo
