@@ -48,16 +48,17 @@
 	 (ycutoff (and cutoff (expt base (+ offset (* cutoff scaler)))))
 	 (result ()))
 
-    ;; linear interpolation
-    (define (interpolate xl yl xh yh xi)
-      (+ yl (* (- xi xl) (/ (- yh yl) (- xh xl)))))
-    
     ;; recursively render one segment
     ;;   xl,xh   = x coordinates of segment ends
     ;;   yl,yh   = y coordinates of segment ends
     ;;   yle,yhe = exponential values of y coords of segment ends
     ;;   error   = linear domain error bound for rendering
     (define (exp-seg xl yle xh yhe yl yh error)
+
+      ;; linear interpolation
+      (define (interpolate xl yl xh yh xi)
+	(+ yl (* (- xi xl) (/ (- yh yl) (- xh xl)))))
+    
       (let* ((xint (/ (+ xl xh) 2.0))
 	     (yint (interpolate xl yl xh yh xint))
 	     (yinte (interpolate xl yle xh yhe xint))
@@ -66,14 +67,14 @@
 	;; is the linear approximation accurate enough?
 	;; are we still over the cutoff limit?
 	(if (not (and (> (abs (- yexp yinte)) yerr)
-		      (or (not ycutoff)
+		      (or (not (real? ycutoff))
 			  (> yinte ycutoff))))
 	    ;; yes --> don't need to add nu'ting to the envelope
 	    (values () ())
 	    ;; no --> add a breakpoint and recurse right and left
 	    ((lambda (xi yi xj yj)
-	       (values (append xi (list xint) xj)
-		       (append yi (list yexp) yj)))
+	       (values (append xi (cons xint xj))
+		       (append yi (cons yexp yj))))
 	     (exp-seg xl yle xint yexp yl yint error)
 	     (exp-seg xint yexp xh yhe yint yh error)))))
     
@@ -85,7 +86,7 @@
 	     (ny (* 1.0 (cadddr en)))
 	     (yscl (+ offset (* y scaler)))
 	     (nyscl (+ offset (* ny scaler)))
-	     (xy (list x (if (or (not ycutoff)
+	     (xy (list x (if (or (not (real? ycutoff))
 				 (>= (expt base yscl) ycutoff))
 			     (* out-scaler (expt base yscl))
 			     0.0))))
@@ -101,7 +102,7 @@
 		       (vals (cdr xx) (cdr yy)))))))
 	 (exp-seg x (expt base yscl) nx (expt base nyscl) yscl nyscl error))
 	(if (<= (length en) 4)
-	    (append result (list nx (if (or (not ycutoff)
+	    (append result (list nx (if (or (not (real? ycutoff))
 					    (>= (expt base nyscl) ycutoff))
 					(* out-scaler (expt base nyscl))
 					0.0)))
@@ -247,15 +248,13 @@
   (let* ((v (make-float-vector len))
 	 (active (* len duty-cycle 0.01))
 	 (incr (/ pi (- active 1)))
-	 (start (/ (- len active) 2))
-	 (end (/ (+ len active) 2))
-	 (s 0))
-    (do ((i 0 (+ 1 i)))
-	((= i len) v)
-      (if (and (>= i start) (< i end))
-	  (let ((sine (sin (* s incr))))
-	    (set! s (+ 1 s))
-	    (set! (v i) (* sine sine)))))))
+	 (start (max 0 (/ (- len active) 2)))
+	 (end (min len (/ (+ len active) 2))))
+    (do ((i start (+ i 1))
+	 (s 0.0 (+ s incr)))
+	((= i end) v)
+      (let ((sine (sin s)))
+	(set! (v i) (* sine sine))))))
 
 ;;;=============================================================================
 ;;; Granular synthesis instrument
