@@ -34,9 +34,7 @@
 (define find-two-marks
   (let ((documentation "(find-two-marks) looks for the marks for the marks-menu functions to use"))
     (lambda ()
-      (let* ((snd (selected-sound))
-	     (chn (selected-channel))
-	     (ms (marks snd chn)))
+      (let ((ms (marks (selected-sound) (selected-channel))))
 	(if (> (length ms) 1)
 	    (map mark->integer (list (car ms) (cadr ms)))
 	    (list))))))
@@ -261,7 +259,7 @@
 						       XmNbottomAttachment    XmATTACH_FORM
 						       XmNlabelString         s1
 						       XmNbackground          *basic-color*)))
-		     (buffer-labels (map XmStringCreateLocalized (list "64" "128" "256" "512" "1024" "2048" "4096")))
+		     (buffer-labels (map XmStringCreateLocalized '("64" "128" "256" "512" "1024" "2048" "4096")))
 		     (combo (XtCreateManagedWidget "buffersize" xmComboBoxWidgetClass frm
 						   (list XmNleftAttachment      XmATTACH_WIDGET
 							 XmNleftWidget          lab
@@ -322,7 +320,7 @@
 							      XmNset                  (= size loop-between-marks-buffer-size)))))
 		     (if (= size loop-between-marks-buffer-size)
 			 (set! loop-between-marks-default-buffer-widget button))))
-		 (list 64 128 256 512 1024 2048 4096))
+		 '(64 128 256 512 1024 2048 4096))
 		(XmStringFree s1)))))
       (activate-dialog loop-between-marks-dialog))
     
@@ -417,9 +415,9 @@
 (define cp-fit-to-marks
   (let ((documentation "(cp-fit-to-marks) fits the selection between two marks (marks-menu)"))
     (lambda ()
-      (if (selection?)
-	  (fit-selection-between-marks (integer->mark fit-to-mark-one) (integer->mark fit-to-mark-two))
-	  (define-selection-via-marks (integer->mark fit-to-mark-one) (integer->mark fit-to-mark-two))))))
+      ((if (selection?) fit-selection-between-marks define-selection-via-marks)
+       (integer->mark fit-to-mark-one) 
+       (integer->mark fit-to-mark-two)))))
 
 (if (not (or (provided? 'xm) 
 	     (provided? 'xg)))
@@ -844,7 +842,7 @@ between two marks,using the granulate generator to fix up the selection duration
 					 (set! (loop-data (+ loc (* offset 2))) (max ml (- (loop-data (+ loc (* offset 2))) 1)))
 					 (update-labels midlab1 midlab2 midlab3 offset range-in-secs))))))
 		  (list rowlefttop rowleftbottom)
-		  (list 0 1))
+		  '(0 1))
 		 
 		 (for-each
 		  (lambda (rparent loc)
@@ -874,11 +872,11 @@ between two marks,using the granulate generator to fix up the selection duration
 					   (set! (loop-data (+ loc (* offset 2))) ml)
 					   (update-labels midlab1 midlab2 midlab3 offset range-in-secs)))))))
 		  (list rowrighttop rowrightbottom)
-		  (list 0 1))))
+		  '(0 1))))
 	     
 	     (list leftform rightform)
-	     (list "Sustain" "Release")
-	     (list 0 1)))
+	     '("Sustain" "Release")
+	     '(0 1)))
 	  (for-each-child
 	   loop-dialog
 	   (lambda (n)
@@ -891,8 +889,7 @@ between two marks,using the granulate generator to fix up the selection duration
 		       (XtVaSetValues n (list XmNselectColor
 					      (let* ((col (XColor))
 						     (dpy (XtDisplay (cadr (main-widgets))))
-						     (scr (DefaultScreen dpy))
-						     (cmap (DefaultColormap dpy scr)))
+						     (cmap (DefaultColormap dpy (DefaultScreen dpy))))
 						(XAllocNamedColor dpy cmap "yellow" col col)
 						(.pixel col)))))))))
 	  ))
