@@ -30,12 +30,7 @@
      (lambda (w)
        (if (and (Widget? w)
 		(or (not (XmIsPushButton w))
-		    (string=? (XtName w) "revlen-label")
-		    (string=? (XtName w) "revscl-label")
-		    (string=? (XtName w) "contrast-label")
-		    (string=? (XtName w) "expand-label")
-		    (string=? (XtName w) "srate-label")
-		    (string=? (XtName w) "amp-label")))
+		    (member (XtName w) '("revscl-label" "contrast-label" "expand-label" "srate-label" "amp-label") string=?)))
 	   (XtSetValues w (list XmNbackgroundPixmap wd))))))
 
 (paint-all (cadr (main-widgets)))
@@ -58,33 +53,8 @@
 
 (add-mark-pane)
 
-(add-sound-file-extension "ogg")
-(add-sound-file-extension "OGG")
-(add-sound-file-extension "sf")
-(add-sound-file-extension "SF2")
-(add-sound-file-extension "mp3")
-(add-sound-file-extension "MP3")
-(add-sound-file-extension "W01")
-(add-sound-file-extension "W02")
-(add-sound-file-extension "W03")
-(add-sound-file-extension "W04")
-(add-sound-file-extension "W05")
-(add-sound-file-extension "W06")
-(add-sound-file-extension "W07")
-(add-sound-file-extension "W08")
-(add-sound-file-extension "W09")
-(add-sound-file-extension "W10")
-(add-sound-file-extension "w01")
-(add-sound-file-extension "w02")
-(add-sound-file-extension "w03")
-(add-sound-file-extension "w04")
-(add-sound-file-extension "w05")
-(add-sound-file-extension "w06")
-(add-sound-file-extension "w07")
-(add-sound-file-extension "w08")
-(add-sound-file-extension "w09")
-(add-sound-file-extension "w10")
-
+(for-each add-sound-file-extension '("ogg" "OGG" "sf" "SF2" "mp3" "MP3" "W01" "W02" "W03" "W04" "W05" "W06" "W07" 
+				     "W08" "W09" "W10" "w01" "w02" "w03" "w04" "w05" "w06" "w07" "w08" "w09" "w10"))
 
 ;;;
 ;;; disable original Play radio button
@@ -117,89 +87,84 @@
     (add-to-menu 0 "Rename" 
       (lambda ()
 	;; open dialog to get new name, save-as that name, open
-	(if (not rename-dialog)
-	    ;; make a standard dialog
-	    (let* ((xdismiss (XmStringCreate "Go Away" XmFONTLIST_DEFAULT_TAG))
-		   (xhelp (XmStringCreate "Help" XmFONTLIST_DEFAULT_TAG))
-		   (xok (XmStringCreate "DoIt" XmFONTLIST_DEFAULT_TAG))
-		   (titlestr (XmStringCreate "Rename" XmFONTLIST_DEFAULT_TAG))
-		   (new-dialog (XmCreateTemplateDialog
-				 (cadr (main-widgets)) "Rename"
-				 (list XmNcancelLabelString   xdismiss
-				       XmNhelpLabelString     xhelp
-				       XmNokLabelString       xok
-				       XmNautoUnmanage        #f
-				       XmNdialogTitle         titlestr
-				       XmNresizePolicy        XmRESIZE_GROW
-				       XmNnoResize            #f
-				       XmNbackground          *basic-color*
-				       XmNtransient           #f))))
-	      (for-each
-	       (lambda (button color)
-		 (XtVaSetValues
-		   (XmMessageBoxGetChild new-dialog button)
-		   (list XmNarmColor   *selection-color*
-			 XmNbackground color)))
-	       (list XmDIALOG_HELP_BUTTON XmDIALOG_CANCEL_BUTTON XmDIALOG_OK_BUTTON)
-	       (list *highlight-color* *highlight-color* *highlight-color*))
-    
-	      (XtAddCallback new-dialog XmNcancelCallback 
-			      (lambda (w c i) (XtUnmanageChild w)))
-	      
-	      (XtAddCallback new-dialog XmNhelpCallback 
-			      (lambda (w c i)
-				(help-dialog "Rename" "Give a new file name to rename the currently selected sound.")))
-
-	      (XtAddCallback new-dialog XmNokCallback 
-			      (lambda (w c i)
-				(let ((new-name (XmTextFieldGetString rename-text)))
-				  (if (and (string? new-name)
-					   (> (length new-name) 0)
-					   (>= (selected-sound) 0))
-				      (let ();(current-name (file-name)))
-					(save-sound-as new-name)
-					(close-sound)
+	(unless rename-dialog
+	  ;; make a standard dialog
+	  (let* ((xdismiss (XmStringCreate "Go Away" XmFONTLIST_DEFAULT_TAG))
+		 (xhelp (XmStringCreate "Help" XmFONTLIST_DEFAULT_TAG))
+		 (xok (XmStringCreate "DoIt" XmFONTLIST_DEFAULT_TAG))
+		 (titlestr (XmStringCreate "Rename" XmFONTLIST_DEFAULT_TAG))
+		 (new-dialog (XmCreateTemplateDialog
+			      (cadr (main-widgets)) "Rename"
+			      (list XmNcancelLabelString   xdismiss
+				    XmNhelpLabelString     xhelp
+				    XmNokLabelString       xok
+				    XmNautoUnmanage        #f
+				    XmNdialogTitle         titlestr
+				    XmNresizePolicy        XmRESIZE_GROW
+				    XmNnoResize            #f
+				    XmNbackground          *basic-color*
+				    XmNtransient           #f))))
+	    (for-each
+	     (lambda (button color)
+	       (XtVaSetValues
+		(XmMessageBoxGetChild new-dialog button)
+		(list XmNarmColor   *selection-color*
+		      XmNbackground color)))
+	     (list XmDIALOG_HELP_BUTTON XmDIALOG_CANCEL_BUTTON XmDIALOG_OK_BUTTON)
+	     (list *highlight-color* *highlight-color* *highlight-color*))
+	    
+	    (XtAddCallback new-dialog XmNcancelCallback 
+			   (lambda (w c i) (XtUnmanageChild w)))
+	    
+	    (XtAddCallback new-dialog XmNhelpCallback 
+			   (lambda (w c i)
+			     (help-dialog "Rename" "Give a new file name to rename the currently selected sound.")))
+	    
+	    (XtAddCallback new-dialog XmNokCallback 
+			   (lambda (w c i)
+			     (let ((new-name (XmTextFieldGetString rename-text)))
+			       (if (and (string? new-name)
+					(> (length new-name) 0)
+					(>= (selected-sound) 0))
+				   (let ();(current-name (file-name)))
+				     (save-sound-as new-name)
+				     (close-sound)
 					;(rename-file current-name new-name)
-					;; (delete-file current-name) perhaps?
-					(open-sound new-name)
-					(XtUnmanageChild w))))))
-	      (XmStringFree xhelp)
-	      (XmStringFree xok)
-	      (XmStringFree xdismiss)
-	      (XmStringFree titlestr)
-	      (set! rename-dialog new-dialog)
-	      (let* ((mainform (XtCreateManagedWidget "formd" xmRowColumnWidgetClass rename-dialog
-				     (list XmNleftAttachment      XmATTACH_FORM
-					   XmNrightAttachment     XmATTACH_FORM
-					   XmNtopAttachment       XmATTACH_FORM
-					   XmNbottomAttachment    XmATTACH_WIDGET
-					   XmNbottomWidget        (XmMessageBoxGetChild rename-dialog XmDIALOG_SEPARATOR)
-					   XmNorientation         XmVERTICAL
-					   XmNbackground          *basic-color*)))
-		     (label (XtCreateManagedWidget "new name:" xmLabelWidgetClass mainform
-				     (list XmNleftAttachment      XmATTACH_FORM
-					   XmNrightAttachment     XmATTACH_NONE
-					   XmNtopAttachment       XmATTACH_FORM
-					   XmNbottomAttachment    XmATTACH_FORM
-					   XmNbackground          *basic-color*))))
-		(set! rename-text 
-		      (XtCreateManagedWidget "newname" xmTextFieldWidgetClass mainform
-				     (list XmNleftAttachment      XmATTACH_WIDGET
-					   XmNleftWidget          label
-					   XmNrightAttachment     XmATTACH_FORM
-					   XmNtopAttachment       XmATTACH_FORM
-					   XmNbottomAttachment    XmATTACH_FORM
-					   XmNbackground          *basic-color*)))
-		(XtAddEventHandler rename-text EnterWindowMask #f
-				    (lambda (w context ev flag)
-				      (XmProcessTraversal w XmTRAVERSE_CURRENT)
-				      (XtSetValues w (list XmNbackground (white-pixel)))))
-		(XtAddEventHandler rename-text LeaveWindowMask #f
-				    (lambda (w context ev flag)
-				      (XtSetValues w (list XmNbackground *basic-color*)))))))
-	(if (not (XtIsManaged rename-dialog))
-	    (XtManageChild rename-dialog)
-	    (raise-dialog rename-dialog)))
+				     ;; (delete-file current-name) perhaps?
+				     (open-sound new-name)
+				     (XtUnmanageChild w))))))
+	    (for-each XmStringFree (vector xhelp xok xdismiss titlestr))
+	    (set! rename-dialog new-dialog)
+	    (let* ((mainform (XtCreateManagedWidget "formd" xmRowColumnWidgetClass rename-dialog
+						    (list XmNleftAttachment      XmATTACH_FORM
+							  XmNrightAttachment     XmATTACH_FORM
+							  XmNtopAttachment       XmATTACH_FORM
+							  XmNbottomAttachment    XmATTACH_WIDGET
+							  XmNbottomWidget        (XmMessageBoxGetChild rename-dialog XmDIALOG_SEPARATOR)
+							  XmNorientation         XmVERTICAL
+							  XmNbackground          *basic-color*)))
+		   (label (XtCreateManagedWidget "new name:" xmLabelWidgetClass mainform
+						 (list XmNleftAttachment      XmATTACH_FORM
+						       XmNrightAttachment     XmATTACH_NONE
+						       XmNtopAttachment       XmATTACH_FORM
+						       XmNbottomAttachment    XmATTACH_FORM
+						       XmNbackground          *basic-color*))))
+	      (set! rename-text 
+		    (XtCreateManagedWidget "newname" xmTextFieldWidgetClass mainform
+					   (list XmNleftAttachment      XmATTACH_WIDGET
+						 XmNleftWidget          label
+						 XmNrightAttachment     XmATTACH_FORM
+						 XmNtopAttachment       XmATTACH_FORM
+						 XmNbottomAttachment    XmATTACH_FORM
+						 XmNbackground          *basic-color*)))
+	      (XtAddEventHandler rename-text EnterWindowMask #f
+				 (lambda (w context ev flag)
+				   (XmProcessTraversal w XmTRAVERSE_CURRENT)
+				   (XtSetValues w (list XmNbackground (white-pixel)))))
+	      (XtAddEventHandler rename-text LeaveWindowMask #f
+				 (lambda (w context ev flag)
+				   (XtSetValues w (list XmNbackground *basic-color*)))))))
+	((if (not (XtIsManaged rename-dialog)) XtManageChild raise-dialog) rename-dialog))
       8)))
 
 (install-searcher-with-colors (lambda (file) #t))
