@@ -75,8 +75,7 @@
 (define (snap-mix-1 id samps-moved)
   (let* ((samp (+ samps-moved (mix-position id)))
 	 (snd (car (mix-home id)))
-	 (chn (cadr (mix-home id)))
-	 (bps (/ (beats-per-minute snd chn) 60.0))
+	 (bps (/ (beats-per-minute snd (cadr (mix-home id))) 60.0))
 	 (sr (srate snd))
 	 (beat (floor (/ (* samp bps) sr)))
 	 (lower (floor (/ (* beat sr) bps)))
@@ -96,8 +95,7 @@
 (define (snap-syncd-mixes-1 id samps-moved)
   (let* ((samp (+ samps-moved (mix-position id)))
 	 (snd (car (mix-home id)))
-	 (chn (cadr (mix-home id)))
-	 (bps (/ (beats-per-minute snd chn) 60.0))
+	 (bps (/ (beats-per-minute snd (cadr (mix-home id))) 60.0))
 	 (sr (srate snd))
 	 (beat (floor (/ (* samp bps) sr)))
 	 (lower (floor (/ (* beat sr) bps)))
@@ -147,9 +145,9 @@ All mixes sync'd to it are also moved the same number of samples. (hook-remove m
     (lambda (n)
       (help-dialog "Mix Help"
 		   (format #f "Mix ~A (sync: ~A):~%  position: ~D = ~,3F secs~%  length: ~D (~,3F secs)~%  in: ~A[~D]~%  scaler: ~A~%  speed: ~A~%  env: ~A~A"
-			   (format #f (if (mix-name n)
-					  (values "~S (~A)" (mix-name n) n)
-					  (values "~A" n)))
+			   (format #f (if (string=? (mix-name n) "")
+					  (values "~A" n)
+					  (values "~S (~A)" (mix-name n) n)))
 			   (mix-sync n)
 			   (mix-position n)
 			   (* 1.0 (/ (mix-position n) (srate (car (mix-home n)))))
@@ -182,8 +180,7 @@ All mixes sync'd to it are also moved the same number of samples. (hook-remove m
 		((= chn (channels snd)))
 	      (for-each
 	       (lambda (m)
-		 (if (and (string? (mix-name m))
-			  (string=? (mix-name m) name))
+		 (if (equal? (mix-name m) name)
 		     (return m)))
 	       (mixes snd chn))))
 	  (sounds))
@@ -316,10 +313,11 @@ may change)"))
   (let ((documentation "(mixes-length mix-list) returns the number of samples between the start of the earliest mix and the \
 last end of the mixes in 'mix-list'"))
     (lambda (mix-list)
-      (+ 1 (- (apply max (map (lambda (m) 
-				(+ (mix-position m) (framples m))) 
-			      mix-list))
-	      (apply min (map mix-position mix-list)))))))
+      (- (+ (apply max (map (lambda (m) 
+			      (+ (mix-position m) (framples m)))
+			    mix-list))
+	    1)
+	 (apply min (map mix-position mix-list))))))
 
 
 (define env-mixes 
@@ -331,7 +329,7 @@ last end of the mixes in 'mix-list'"))
 	     (end (apply max mix-ends))
 	     (first-x (car overall-amp-env))
 	     (last-x (envelope-last-x overall-amp-env))
-	     (x-scale (/ (- last-x first-x) (+ 1 (- end beg)))))
+	     (x-scale (/ (- last-x first-x) (- (+ end 1) beg))))
 	(as-one-edit
 	 (lambda ()
 	   (for-each 
@@ -426,8 +424,7 @@ panning operation."))
 	   (define (invert-envelope e)
 	     (if (null? e)
 		 ()
-		 (append (list (car e) (- 1.0 (cadr e)))
-			 (invert-envelope (cddr e)))))
+		 (cons (car e) (cons (- 1.0 (cadr e)) (invert-envelope (cddr e))))))
 	   
 	   (let ((incoming-chans (channels name))
 		 (receiving-chans (channels index)))
@@ -440,7 +437,8 @@ panning operation."))
 		     
 		     ;; mono to mono = just scale or envelope
 		     (let ((idx (mix name beg 0 index 0 *with-mix-tags* auto-delete))) ; file start in-chan snd chn ...
-		       (and idx (mix? (car idx))
+		       (and (pair? idx)
+			    (mix? (car idx))
 			    (let ((id (car idx)))
 			      (set! (mix-amp-env id) (invert-envelope pan))
 			      idx)))
@@ -448,8 +446,10 @@ panning operation."))
 		     ;; mono to stereo
 		     (let ((idx0 (mix name beg 0 index 0 *with-mix-tags* deletion-choice))
 			   (idx1 (mix name beg 0 index 1 *with-mix-tags* end-deletion-choice)))
-		       (and idx0 (mix? (car idx0))
-			    idx1 (mix? (car idx1))
+		       (and (pair? idx0)
+			    (mix? (car idx0))
+			    (pair? idx1)
+			    (mix? (car idx1))
 			    (let ((id0 (car idx0))
 				  (id1 (car idx1)))
 			      (set! (mix-amp-env id0) (invert-envelope pan))
@@ -463,8 +463,10 @@ panning operation."))
 		     ;; stereo -> mono => scale or envelope both input chans into the output
 		     (let ((idx0 (mix name beg 0 index 0 *with-mix-tags* deletion-choice))
 			   (idx1 (mix name beg 1 index 0 *with-mix-tags* end-deletion-choice)))
-		       (and idx0 (mix? (car idx0))
-			    idx1 (mix? (car idx1))
+		       (and (pair? idx0)
+			    (mix? (car idx0))
+			    (pair? idx1)
+			    (mix? (car idx1))
 			    (let ((id0 (car idx0))
 				  (id1 (car idx1)))
 			      (set! (mix-amp-env id0) (invert-envelope pan))
@@ -477,10 +479,14 @@ panning operation."))
 			   (idx10 (mix name beg 1 index 0 *with-mix-tags* deletion-choice))
 			   (idx11 (mix name beg 1 index 1 *with-mix-tags* end-deletion-choice)))
 		       
-		       (and idx00 (mix? (car idx00))
-			    idx01 (mix? (car idx01))
-			    idx10 (mix? (car idx10))
-			    idx11 (mix? (car idx11))
+		       (and (pair? idx00)
+			    (mix? (car idx00))
+			    (pair? idx01)
+			    (mix? (car idx01))
+			    (pair? idx10)
+			    (mix? (car idx10))
+			    (pair? idx11)
+			    (mix? (car idx11))
 			    (let ((id00 (car idx00))
 				  (id01 (car idx01))
 				  (id10 (car idx10))
