@@ -55,7 +55,7 @@
 		  'sort!              (lambda (obj f) (#_sort! (obj 'value) f))
 		  'make-iterator      (lambda (obj) (#_make-iterator (obj 'value)))
 		  'arity              (lambda (obj) (#_arity (obj 'value)))
-		  'object->string     (lambda* (obj (w #t)) (if (eq? w :readable) "*mock-vector*" "#<mock-vector-class>"))
+		  'object->string     (lambda* (obj (w #t)) (copy (if (eq? w :readable) "*mock-vector*" "#<mock-vector-class>")))
 		  'vector-dimensions  (lambda (obj) (#_vector-dimensions (obj 'value)))
 		  'fill!              (lambda (obj val) (#_fill! (obj 'value) val))
 		  
@@ -182,7 +182,7 @@
 		  
 		  'fill!              (lambda (obj val)      (#_fill! (obj 'mock-hash-table-table) val))
 		  'reverse            (lambda (obj)          (#_reverse (obj 'mock-hash-table-table)))
-		  'object->string     (lambda* (obj (w #t))  (if (eq? w :readable) "*mock-hash-table*" "#<mock-hash-table-class>"))
+		  'object->string     (lambda* (obj (w #t))  (copy (if (eq? w :readable) "*mock-hash-table*" "#<mock-hash-table-class>")))
 		  'arity              (lambda (obj)          (#_arity (obj 'mock-hash-table-table)))
 		  'copy               (lambda* (source dest . args)
 					(if (mock-hash-table? source)
@@ -265,7 +265,7 @@
 	  (openlet
 	   (inlet 'morally-equal?         (lambda (x y) (#_morally-equal? (x 'value) y))
 		  'reverse                (lambda (obj) (#_reverse (obj 'value)))
-		  'object->string         (lambda* (obj (w #t)) (if (eq? w :readable) "*mock-string*" "#<mock-string-class>"))
+		  'object->string         (lambda* (obj (w #t)) (copy (if (eq? w :readable) "*mock-string*" "#<mock-string-class>")))
 		  'arity                  (lambda (obj) (#_arity (obj 'value)))
 		  'make-iterator          (lambda (obj) (#_make-iterator (obj 'value)))
 		  'let-ref                (lambda (obj i) (#_string-ref (obj 'value) i))           ; these are the implicit cases
@@ -439,7 +439,7 @@
 		  'char-ci<=?         (make-local-method #_char-ci<=?)
 		  'char-ci>=?         (make-local-method #_char-ci>=?)
 		  'string             (make-local-method #_string)
-		  'object->string     (lambda* (obj (w #t)) (if (eq? w :readable) "*mock-char*" "#<mock-char-class>"))
+		  'object->string     (lambda* (obj (w #t)) (copy (if (eq? w :readable) "*mock-char*" "#<mock-char-class>")))
 		  'arity              (lambda (obj) (#_arity (obj 'value)))
 		  'format             (make-local-method #_format)
 		  'make-string        (make-local-method #_make-string)
@@ -518,7 +518,7 @@
 	   (openlet
 	    (inlet 
 		   'morally-equal?   (lambda (x y) (#_morally-equal? (x 'value) y))
-		   'object->string   (lambda* (obj (w #t)) (if (eq? w :readable) "*mock-number*" "#<mock-number-class>"))
+		   'object->string   (lambda* (obj (w #t)) (copy (if (eq? w :readable) "*mock-number*" "#<mock-number-class>")))
 		   'arity            (lambda (obj) (#_arity (obj 'value)))
 		   'real-part        (lambda (obj) (#_real-part (obj 'value)))
 		   'imag-part        (lambda (obj) (#_imag-part (obj 'value)))
@@ -857,7 +857,7 @@
 	   (inlet 'morally-equal?   (lambda (x y) (#_morally-equal? (x 'value) y))
 		  'pair-line-number (lambda (obj) (#_pair-line-number (obj 'value)))
 		  'list->string     (lambda (obj) (#_list->string (obj 'value)))
-		  'object->string   (lambda* (obj (w #t)) (if (eq? w :readable) "*mock-pair*" "#<mock-pair-class>"))
+		  'object->string   (lambda* (obj (w #t)) (copy (if (eq? w :readable) "*mock-pair*" "#<mock-pair-class>")))
 		  'list?            (lambda (obj) (#_list? (obj 'value)))
 		  'car              (lambda (obj) (#_car (obj 'value)))
 		  'cdr              (lambda (obj) (#_cdr (obj 'value)))
@@ -996,7 +996,7 @@
 (define *mock-symbol*
   (let ((mock-symbol-class
 	 (openlet
-	  (inlet 'object->string        (lambda* (obj (w #t)) (if (eq? w :readable) "*mock-symbol*" "#<mock-symbol-class>"))
+	  (inlet 'object->string        (lambda* (obj (w #t)) (copy (if (eq? w :readable) "*mock-symbol*" "#<mock-symbol-class>")))
 		 'morally-equal?        (lambda (x y) (#_morally-equal? (x 'value) y))
 		 'gensym?               (lambda (obj) (#_gensym? (obj 'value)))
 		 'symbol->string        (lambda (obj) (#_symbol->string (obj 'value)))
@@ -1057,7 +1057,7 @@
 		  'char-ready?         (lambda (obj) (#_char-ready? (obj 'value)))
 		  'port-line-number    (lambda (obj) (#_port-line-number (obj 'value)))
 		  'port-filename       (lambda (obj) (#_port-filename (obj 'value)))
-		  'object->string      (lambda* (obj (w #t)) (if (eq? w :readable) "*mock-port*" "#<mock-port-class>"))
+		  'object->string      (lambda* (obj (w #t)) (copy (if (eq? w :readable) "*mock-port*" "#<mock-port-class>")))
 		  'format              (make-local-method #_format)
 		  
 		  'set-current-output-port (lambda (obj) (#_set-current-output-port (obj 'value)))
