@@ -71,15 +71,14 @@
 (define play-often 
   (let ((documentation "(play-often n) plays the selected sound 'n' times (interruptible via C-g)"))
     (lambda (n) 
-      (define play-once
-	(let ((plays (- n 1)))
-	  (lambda (reason)
-	    (if (and (> plays 0)
-		     (= reason 0))
-		(begin
-		  (set! plays (- plays 1))
-		  (play (selected-sound) :start 0 :stop play-once))))))
-      (play (selected-sound) :start 0 :stop play-once))))
+      (letrec ((play-once (let ((plays (- n 1)))
+			    (lambda (reason)
+			      (if (and (> plays 0)
+				       (= reason 0))
+				  (begin
+				    (set! plays (- plays 1))
+				    (play (selected-sound) :start 0 :stop play-once)))))))
+	(play (selected-sound) :start 0 :stop play-once)))))
 
 ;;(bind-key #\p 0 (lambda (n) "play often" (play-often (max 1 n))))
 
@@ -192,7 +191,7 @@ amp: (play-with-amps 0 1.0 0.5) plays channel 2 of stereo sound at half amplitud
 	    ((= i num-oscs))
 	  (set! (frqs i) (hz->radians (car (freqs-and-amps i))))
 	  (set! (amps i) (cadr (freqs-and-amps i))))
-	(let ((ob (make-oscil-bank frqs (make-float-vector num-oscs 0.0) amps #t)))
+	(let ((ob (make-oscil-bank frqs (make-float-vector num-oscs) amps #t)))
 	  (play (lambda ()
 		  (and (positive? (set! len (- len 1)))
 		       (oscil-bank ob)))))))))
