@@ -49,7 +49,7 @@
   (float-vector 0.0 0.0))
 
 (define (dc-block b samp)
-  (set! (b 1) (+ samp (- (* 0.99 (b 1)) (b 0))))
+  (set! (b 1) (- (+ samp (* 0.99 (b 1))) (b 0)))
   (set! (b 0) samp)
   (b 1))
 ;; we could also use a filter generator here: (make-filter 2 (float-vector 1 -1) (float-vector 0 -0.99))
@@ -74,8 +74,7 @@
 (definstrument (plucky beg dur freq amplitude maxa)
   ;; (with-sound () (plucky 0 .3 440 .2 1.0))
 
-  (let* ((lowestfreq 100.0)
-	 (len (+ 1 (floor (/ *clm-srate* lowestfreq)))))
+  (let ((len (+ 1 (floor (/ *clm-srate* 100.0))))) ; 100 = lowest freq
     (let ((delayline (make-delayl len (- (/ *clm-srate* freq) 0.5)))
 	  (filt (make-onezero))
 	  (start (seconds->samples beg))
@@ -94,8 +93,7 @@
 (definstrument (bowstr beg dur frq amplitude maxa)
   ;; (with-sound () (bowstr 0 .3 220 .2 1.0))
 
-  (let* ((lowestfreq 100.0)
-	 (len (+ 1 (floor (/ *clm-srate* lowestfreq)))))
+  (let ((len (+ 1 (floor (/ *clm-srate* 100.0))))) ; 100 = lowest freq
     (let ((ratio 0.8317)
 	  (rate .001)
 	  (bowing #t)
@@ -126,9 +124,7 @@
 		(bowtemp 0.0))
 	    (if bowing
 		(if (not (= maxvelocity bowvelocity))
-		    (if (< bowvelocity maxvelocity)
-			(set! bowvelocity (+ bowvelocity attackrate))
-			(set! bowvelocity (- bowvelocity attackrate))))
+		    (set! bowvelocity ((if (< bowvelocity maxvelocity) + -) bowvelocity attackrate)))
 		(if (> bowvelocity 0.0) 
 		    (set! bowvelocity (- bowvelocity attackrate))))
 	    (set! bowtemp (* 0.3 bowvelocity))
@@ -150,8 +146,7 @@
 
 (definstrument (brass beg dur freq amplitude maxa)
   ;; does this work at all?
-  (let* ((lowestfreq 100.0)
-	 (len (+ 1 (floor (/ *clm-srate* lowestfreq)))))
+  (let ((len (+ 1 (floor (/ *clm-srate* 100.0)))))
     (let ((blowing #t)
 	  (rate .001)
 	  (breathpressure 0.0))  ; 0.1 ?
@@ -169,9 +164,7 @@
 	    ((= i end))
 	  (if blowing
 	      (if (not (= maxpressure breathpressure))
-		  (if (< breathpressure maxpressure)
-		      (set! breathpressure (+ breathpressure attackrate))
-		      (set! breathpressure (- breathpressure attackrate))))
+		  (set! breathpressure ((if (< breathpressure maxpressure) + -) breathpressure attackrate)))
 	      (if (> breathpressure 0.0)
 		  (set! breathpressure (- breathpressure attackrate))))
 	  (set! dout (delayl delayline (dc-block dcblocker
@@ -189,8 +182,7 @@
 (definstrument (clarinet beg dur freq amplitude maxa)
   ;; (with-sound () (clarinet 0 .3 440 .2 1.0))
 
-  (let* ((lowestfreq 100.0)
-	 (len (+ 1 (floor (/ *clm-srate* lowestfreq)))))
+  (let ((len (+ 1 (floor (/ *clm-srate* 100.0)))))
     (let ((blowing #t)
 	  (breathpressure 0.0) ; 0.1 ?
 	  (rate .001))
@@ -209,9 +201,7 @@
 	  (let ((pressurediff 0.0))
 	    (if blowing
 		(if (not (= maxpressure breathpressure))
-		    (if (< breathpressure maxpressure)
-			(set! breathpressure (+ breathpressure attackrate))
-			(set! breathpressure (- breathpressure attackrate))))
+		    (set! breathpressure ((if (< breathpressure maxpressure) + -) breathpressure attackrate)))
 		(if (> breathpressure 0.0)
 		    (set! breathpressure (- breathpressure attackrate))))
 	    (set! pressurediff (- (one-zero filt (* -0.95 dlyout)) breathpressure))
@@ -230,8 +220,7 @@
 (definstrument (flute beg dur freq amplitude maxa)
   ;; (with-sound () (flute 0 .3 440 .2 1.0))
   
-  (let* ((lowestfreq 100.0)
-	 (len (+ 1 (floor (/ *clm-srate* lowestfreq)))))
+  (let ((len (+ 1 (floor (/ *clm-srate* 100.0)))))
     (let ((jetrefl 0.6)
 	  (endrefl 0.6)
 	  (sinphase 0.0)
@@ -263,16 +252,11 @@
 	    (set! randpressure (+ randpressure (* 0.05 breathpressure (sin sinphase))))
 	    (if blowing
 		(if (not (= maxpressure breathpressure))
-		    (if (< breathpressure maxpressure)
-			(set! breathpressure (+ breathpressure attackrate))
-			(set! breathpressure (- breathpressure attackrate))))
+		    (set! breathpressure ((if (< breathpressure maxpressure) + -) breathpressure attackrate)))
 		(if (> breathpressure 0.0) 
 		    (set! breathpressure (- breathpressure attackrate))))
 	    (set! temp (dc-block dcblocker (one-pole filt boreout)))
-	    (set! pressurediff (+ (jettable 
-				   (delayl jetdelay 
-					   (+ breathpressure 
-					      (- randpressure (* jetrefl temp))))) 
+	    (set! pressurediff (+ (jettable (delayl jetdelay (- (+ breathpressure randpressure) (* jetrefl temp))))
 				  (* endrefl temp)))
 	    (set! boreout (delayl boredelay pressurediff))
 	    (outa i (* 0.3 amplitude boreout))
