@@ -32,7 +32,7 @@
 	     (k start (+ k 1)))
 	    ((= k len) dest)
 	  (set! (dest i) (src k)))
-	(do ((i (+ at (- len start 1)) (- i 1))
+	(do ((i (- (+ at len) start 1) (- i 1))
 	     (k (- len 1) (- k 1)))
 	    ((< k start) dest)
 	  (set! (dest i) (src k))))))
@@ -94,17 +94,17 @@
 (define (port? p) (or (input-port? p) (output-port? p)))
 (define binary-port? port?)
 (define textual-port? port?)
-(define (close-port p) (if (input-port? p) (close-input-port p) (close-output-port p)))
+(define (close-port p) ((if (input-port? p) close-input-port close-output-port) p))
 (define open-binary-input-file open-input-file)
 (define open-binary-output-file open-output-file)
-(define (call-with-port port proc) 
-  ((if (input-port? port) call-with-input-file call-with-output-file) port proc))
+(define (call-with-port port proc) ((if (input-port? port) call-with-input-file call-with-output-file) port proc))
 
 
 (define (bytevector-u8-ref b k) (b k))
 (define (bytevector-u8-set! b k c) (set! (b k) c))
+(define bytevector-u8 (dilambda (lambda (b k) (b k)) (lambda (b k c) (set! (b k) c))))
 (define bytevector-length length)
-(define (bytevector-copy . args) (->byte-vector (apply string-copy args)))
+(define (bytevector-copy . args) (->byte-vector (apply r7rs-string-copy args)))
 (define (bytevector-append . args) (->byte-vector (apply string-append args)))
 (define write-bytevector write-string)
 (define* (read-bytevector! bv port (start 0) end)
@@ -382,7 +382,11 @@
     (cons 'current-second g_time)))
 
 
-(define get-environment-variable (*libc* 'getenv))
+(define (get-environment-variable x)
+  (let ((val ((*libc* 'getenv) x)))
+    (and (string? val)
+	 (> (length val) 0)
+	 val)))
 (define get-environment-variables (*libc* 'getenvs))
 (define (r7rs-file-exists? arg) (= ((*libc* 'access) arg (*libc* 'F_OK)) 0))
 (define r7rs-delete-file (*libc* 'unlink))
@@ -391,7 +395,7 @@
 (define (cpu-architecture) (cadr ((*libc* 'uname))))
 (define (machine-name) (caddr ((*libc* 'uname))))
 (define (os-version) (string-append (list-ref ((*libc* 'uname)) 3) " " (list-ref ((*libc* 'uname)) 4)))
-(define (implementation-name) "s7")
+(define (implementation-name) (copy "s7"))
 (define (implementation-version) (substring (s7-version) 3 7))
 
 ;; command-line is problematic: s7 has no access to the caller's "main" function, and
