@@ -228,41 +228,47 @@
 		;; so, locally redefine these three to use the repl top-level while we're in the repl.
 		;; in addition, for each of these, we need to report missing close parens and so on
 		
-		(define (repl-hooks)
-		  (set! (hook-functions *missing-close-paren-hook*) (cons badexpr old-badexpr-hook))
-		  (set! (hook-functions *unbound-variable-hook*) (cons shell? old-unbound-var-hook)))
+		(let ((repl-hooks
+		       (lambda ()
+			 (set! (hook-functions *missing-close-paren-hook*) (cons badexpr old-badexpr-hook))
+			 (set! (hook-functions *unbound-variable-hook*) (cons shell? old-unbound-var-hook))))
 		
-		(define (original-hooks)
-		  (set! unbound-case #f)
-		  (set! (hook-functions *missing-close-paren-hook*) old-badexpr-hook)
-		  (set! (hook-functions *unbound-variable-hook*) old-unbound-var-hook))
+		      (original-hooks
+		       (lambda ()
+			 (set! unbound-case #f)
+			 (set! (hook-functions *missing-close-paren-hook*) old-badexpr-hook)
+			 (set! (hook-functions *unbound-variable-hook*) old-unbound-var-hook))))
 		
-		(define new-load (let ((documentation "this is the repl's load replacement; its default is to use the repl's top-level-let.")
-				       (signature '(values string? let?)))
-				   (lambda* (file (e (*repl* 'top-level-let)))
-				     (dynamic-wind original-hooks (lambda () (load file e)) repl-hooks))))
-		
-		(define new-eval (let ((documentation "this is the repl's eval replacement; its default is to use the repl's top-level-let.")
-				       (signature '(values list? let?)))
-				   (lambda* (form (e (*repl* 'top-level-let)))
-				     (dynamic-wind original-hooks (lambda () (eval form e)) repl-hooks))))
-		
-		(define new-eval-string (let ((documentation "this is the repl's eval-string replacement; its default is to use the repl's top-level-let.")
-					      (signature '(values string? let?)))
-					  (lambda* (str (e (*repl* 'top-level-let)))
-					    (dynamic-wind original-hooks (lambda () (eval-string str e)) repl-hooks))))
-		(dynamic-wind
-		    (lambda ()
-		      (repl-hooks)
-		      (set! eval new-eval)
-		      (set! eval-string new-eval-string)
-		      (set! load new-load))
-		    body
-		    (lambda ()
-		      (set! eval old-eval)
-		      (set! eval-string old-eval-string)
-		      (set! load old-load)
-		      (original-hooks)))))
+		  (let ((new-load 
+			 (let ((documentation "this is the repl's load replacement; its default is to use the repl's top-level-let.")
+			       (signature '(values string? let?)))
+			   (lambda* (file (e (*repl* 'top-level-let)))
+			     (dynamic-wind original-hooks (lambda () (load file e)) repl-hooks))))
+			
+			(new-eval 
+			 (let ((documentation "this is the repl's eval replacement; its default is to use the repl's top-level-let.")
+			       (signature '(values list? let?)))
+			   (lambda* (form (e (*repl* 'top-level-let)))
+			     (dynamic-wind original-hooks (lambda () (eval form e)) repl-hooks))))
+			
+			(new-eval-string 
+			 (let ((documentation "this is the repl's eval-string replacement; its default is to use the repl's top-level-let.")
+			       (signature '(values string? let?)))
+			   (lambda* (str (e (*repl* 'top-level-let)))
+			     (dynamic-wind original-hooks (lambda () (eval-string str e)) repl-hooks)))))
+		    
+		    (dynamic-wind
+			(lambda ()
+			  (repl-hooks)
+			  (set! eval new-eval)
+			  (set! eval-string new-eval-string)
+			  (set! load new-load))
+			body
+			(lambda ()
+			  (set! eval old-eval)
+			  (set! eval-string old-eval-string)
+			  (set! load old-load)
+			  (original-hooks)))))))
 	    
 	    
 	    ;; -------- match parens --------
@@ -389,13 +395,13 @@
 			   (x 0))
 		       (do ((b (read terminal-fd cc 1) (read terminal-fd cc 1)))
 			   ((not (char-numeric? (c 0))))
-			 (set! y (+ (* 10 y) (- (char->integer (c 0)) (char->integer #\0)))))
+			 (set! y (- (+ (* 10 y) (char->integer (c 0))) (char->integer #\0))))
 		       (and (char=? (c 0) #\;)
 			    (do ((b (read terminal-fd cc 1) (read terminal-fd cc 1)))
 				((not (char-numeric? (c 0)))
 				 (and (char=? (c 0) #\R)
 				      (cons x y)))
-			      (set! x (+ (* 10 x) (- (char->integer (c 0)) (char->integer #\0))))))))))
+			      (set! x (- (+ (* 10 x) (char->integer (c 0))) (char->integer #\0)))))))))
 	    
 	    (define (cursor-bounds)
 	      (let ((coords (cursor-coords)))
@@ -433,11 +439,11 @@
 		(format #f "~C[1m~A~C[0m" #\escape text #\escape)) 
 
 	      ;; if a line wraps, it will confuse the redisplay/cursor positioning code. so truncate the display
-	      (let ((line-len (+ (- end start) 1 prompt-length)))
+	      (let ((line-len (- (+ end prompt-length 1) start)))
 		(if (>= line-len last-col)
 		    (set! end (- (+ end line-len) last-col))))
 	      
-	      (if (and red-par-pos
+	      (if (and (integer? red-par-pos)
 		       (<= start red-par-pos)
 		       (< red-par-pos end))
 		  (string-append
@@ -463,7 +469,7 @@
 		(do ((i 0 (+ i 1)))
 		    ((or (= i len)
 			 (= i cursor-pos))
-		     (move-cursor (+ prompt-row row) (+ prompt-col (- cursor-pos start))))
+		     (move-cursor (+ prompt-row row) (- (+ prompt-col cursor-pos) start)))
 		  (when (char=? (cur-line i) #\newline)
 		    (set! row (+ row 1))
 		    (set! start (+ i 1))))))
@@ -605,14 +611,6 @@
 			   (char=? (cur-line i) #\newline))
 		       (if (zero? i) 0 (+ i 1))))))
 	    
-	    (define (count-newlines line)
-	      (let ((len (length line))
-		    (newlines 0))
-		(do ((i 0 (+ i 1)))
-		    ((= i len) newlines)
-		  (if (char=? (cur-line i) #\newline)
-		      (set! newlines (+ newlines 1))))))
-	    
 	    (define (append-newline)
 	      (set! cur-line (string-append cur-line (string #\space #\newline)))
 	      (set! cursor-pos (length cur-line))
@@ -847,9 +845,8 @@
 						i))))
 				  (set! completion (if (< loc 0)
 						       (symbol-completion cur-line)
-						       (if (char=? (cur-line loc) #\")
-							   (filename-completion (substring cur-line (+ loc 1)))
-							   (symbol-completion (substring cur-line (+ loc 1))))))
+						       ((if (char=? (cur-line loc) #\") filename-completion symbol-completion)
+							(substring cur-line (+ loc 1)))))
 				  (when (and completion
 					     (> (length completion) (- end loc 1)))
 				    (save-line)
@@ -948,6 +945,13 @@
 	      ;; Meta key is a problem on the Mac, so I'll package these for easier disposal
 
 	      (define (fixup-new-line)
+		(define (count-newlines line)
+		  (let ((len (length line))
+			(newlines 0))
+		    (do ((i 0 (+ i 1)))
+			((= i len) newlines)
+		      (if (char=? (cur-line i) #\newline)
+			  (set! newlines (+ newlines 1))))))
 		(set! cursor-pos (length cur-line))
 		(let ((newlines (count-newlines cur-line)))
 		  (when (< last-row (+ prompt-row newlines))
