@@ -18,7 +18,7 @@
 ;;; (Uniform Resource Identifier) for this scheme implementation's home
 ;;; page; or false if there isn't one.
 (define (scheme-implementation-home-page)
-  "http://ccrma.stanford.edu/software/snd/")
+  (copy "http://ccrma.stanford.edu/software/snd/"))
 
 ;;@ (scheme-implementation-version) should return a string describing
 ;;; the version the scheme implementation loading this file.
@@ -35,7 +35,7 @@
 	       ((vms) "scheme$src:")
 	       ((ms-dos) "C:\\Program Files\\snd\\")
 	       (else "")))))
-    (lambda () impl-path)))
+    (lambda () (copy impl-path))))
 
 ;;@ (library-vicinity) should be defined to be the pathname of the
 ;;; directory where files of Scheme library functions reside.
@@ -51,29 +51,23 @@
 	    ((vms) "lib$scheme:")
 	    ((ms-dos) "C:\\Program Files\\slib\\")
 	    (else "")))))
-    (lambda () library-path)))
+    (lambda () (copy library-path))))
 
 ;;@ (home-vicinity) should return the vicinity of the user's HOME
 ;;; directory, the directory which typically contains files which
 ;;; customize a computer environment for a user.
 (define (home-vicinity)
   (let ((home (getenv "HOME")))
-    (and home
-	 (case (software-type)
-	   ((unix coherent ms-dos)	;V7 unix has a / on HOME
-	    (if (eqv? #\/ (string-ref home (+ -1 (string-length home))))
-		home
-		(string-append home "/")))
-	   (else home)))))
-
+    (if (and (memq (software-type) '(unix coherent ms-dos))
+	     (not (char=? #\/ (string-ref home (- (string-length home) 1)))))
+	(string-append home "/")
+	home)))
 ;@
 (define in-vicinity string-append)
 
 ;@
 (define (user-vicinity)
-  (case (software-type)
-    ((vms)	"[.]")
-    (else	"")))
+  (copy (if (eq? (software-type) 'vms) "[.]" "")))
 
 (define *load-pathname* #f)	 ; *load-path* is a list of dirs in s7
 
@@ -104,22 +98,23 @@
       (slib:error 'program-vicinity " called; use slib:load to load")))
 ;@
 (define sub-vicinity
-  (case (software-type)
-    ((vms) (lambda (vic name)
-	     (let ((l (string-length vic)))
-	       (if (or (zero? (string-length vic))
-		       (not (char=? #\] (string-ref vic (- l 1)))))
-		   (string-append vic "[" name "]")
-		   (string-append (substring vic 0 (- l 1))
-				  "." name "]")))))
-    (else (let ((*vicinity-suffix*
-		 (case (software-type)
-		   ((nosve) ".")
-		   ((macos thinkc) ":")
-		   ((ms-dos windows atarist os/2) "\\")
-		   ((unix coherent plan9 amiga) "/"))))
-	    (lambda (vic name)
-	      (string-append vic name *vicinity-suffix*))))))
+  (if (eq? (software-type) 'vms)
+      (lambda (vic name)
+	(let ((L (string-length vic)))
+	  (string-append
+	   (if (or (zero? (string-length vic))
+		   (not (char=? #\] (string-ref vic (- L 1)))))
+	       (values vic "[")
+	       (values (substring vic 0 (- L 1)) "."))
+	   name "]")))
+      (let ((*vicinity-suffix* (case (software-type)
+				 ((nosve) ".")
+				 ((macos thinkc) ":")
+				 ((ms-dos windows atarist os/2) "\\")
+				 ((unix coherent plan9 amiga) "/"))))
+	(lambda (vic name)
+	  (string-append vic name *vicinity-suffix*)))))
+
 ;@
 (define (make-vicinity <pathname>) <pathname>)
 ;@
@@ -288,28 +283,27 @@
 (define (defmacro? m) (assq m *defmacros*))
 ;@
 (define (macroexpand-1 e)
-  (if (pair? e)
+  (if (not (pair? e))
+      e
       (let ((a (car e)))
 	(cond ((symbol? a) (set! a (assq a *defmacros*))
 	       (if a (apply (cdr a) (cdr e)) e))
-	      (else e)))
-      e))
+	      (else e)))))
 ;@
 (define (macroexpand e)
-  (if (pair? e)
+  (if (not (pair? e))
+      e
       (let ((a (car e)))
 	(cond ((symbol? a)
 	       (set! a (assq a *defmacros*))
 	       (if a (macroexpand (apply (cdr a) (cdr e))) e))
-	      (else e)))
-      e))
+	      (else e)))))
 ;@
 (define gentemp
   (let ((*gensym-counter* -1))
     (lambda ()
       (set! *gensym-counter* (+ *gensym-counter* 1))
-      (string->symbol
-       (string-append "slib:G" (number->string *gensym-counter*))))))
+      (symbol "slib:G" (number->string *gensym-counter*)))))
 
 (define base:eval slib:eval)
 ;@
@@ -325,9 +319,7 @@
   (lambda args
     (let ((cep (current-error-port)))
       (if (provided? 'trace) (print-call-stack cep))
-      (display "Warn: " cep)
-      (for-each (lambda (x) (display #\space cep) (write x cep)) args)
-      (newline cep))))
+      (format cep "Warn: ~{ ~S~}~%" args))))
 
 ;;@ define an error procedure for the library
 (define slib:error error)
@@ -365,18 +357,18 @@
       (try "netscape '" "'")))
 
 ;;@ define these as appropriate for your system.
-(define slib:tab (integer->char 9))
+(define slib:tab #\tab)
 (define slib:form-feed (integer->char 12))
 
 ;;@ Support for older versions of Scheme.  Not enough code for its own file.
-(define (last-pair l) (if (pair? (cdr l)) (last-pair (cdr l)) l))
+(define (last-pair lst) (if (pair? (cdr lst)) (last-pair (cdr lst)) lst))
 (define t #t)
 (define nil #f)
 
 ;;@ Define these if your implementation's syntax can support it and if
 ;;; they are not already defined.
 (define (1+ n) (+ n 1))
-(define (-1+ n) (+ n -1))
+(define (-1+ n) (- n 1))
 (define 1- -1+)
 
 ;;@ Define SLIB:EXIT to be the implementation procedure to exit or
@@ -385,9 +377,7 @@
 
 ;;@ Here for backward compatability
 (define scheme-file-suffix
-  (let ((suffix (case (software-type)
-		  ((nosve) "_scm")
-		  (else ".scm"))))
+  (let ((suffix (if (eq? (software-type) 'nosve) "_scm" ".scm")))
     (lambda () suffix)))
 
 ;;@ (SLIB:LOAD-SOURCE "foo") should load "foo.scm" or with whatever
