@@ -45,34 +45,30 @@
 	  
 	  (pfun (let ((init (list 0.0 (* .8 (setup 3)))))
 		  (for-each (lambda (b dat)
-			      (set! init (append init (list (- b beg))))
-			      (set! init (append init (list (* 1.0 (dat 3))))))
+			      (set! init (append init (list (- b beg) (* 1.0 (dat 3))))))
 			    (cdr begs)
 			    data)
 		  init))
 	  (gfun (let ((init (list 0.0 0.0)))
 		  (for-each (lambda (b dat)
-			      (set! init (append init (list (- b beg))))
-			      (set! init (append init (list (* 1.0 (dat 4))))))
+			      (set! init (append init (list (- b beg) (* 1.0 (dat 4))))))
 			    (cdr begs)
 			    data)
 		  init))
 	  (nfun (let ((init (list 0.0 (* 1.0 (setup 5)))))
 		  (for-each (lambda (b dat)
-			      (set! init (append init (list (- b beg))))
-			      (set! init (append init (list (* 1.0 (dat 5))))))
+			      (set! init (append init (list (- b beg) (* 1.0 (dat 5))))))
 			    (cdr begs)
 			    data)
 		  init))
 	  (vfun (let ((init (list 0.0 (* 1.0 (setup 6)))))
 		  (for-each (lambda (b dat)
-			      (set! init (append init (list (- b beg))))
-			      (set! init (append init (list (* 1.0 (dat 6))))))
+			      (set! init (append init (list (- b beg) (* 1.0 (dat 6))))))
 			    (cdr begs)
 			    data)
 		  init))
 	  (noiseamps (let* ((len (length data))
-			    (v (make-float-vector len 0.0)))
+			    (v (make-float-vector len)))
 		       (do ((i 0 (+ i 1)))
 			   ((= i len))
 			 (set! (v i) (* 1.0 ((data i) 5))))
@@ -86,8 +82,8 @@
 	    (noise-env (make-env nfun :duration dur))
 	    (ran-vib (make-rand-interp :frequency 10 :amplitude .02))
 	    
-	    (glot-datai (make-float-vector (* 2 (length glts)) 0.0))
-	    (glot-datar (make-float-vector (* 2 (length glts)) 0.0))
+	    (glot-datai (make-float-vector (* 2 (length glts))))
+	    (glot-datar (make-float-vector (* 2 (length glts))))
 	    
 	    (tractlength+8 (+ tractlength 8))
 	    (tractlength+1 (+ tractlength 1))
@@ -101,7 +97,7 @@
 	    (tong-hump-pole 0.998)
 	    (tong-tip-pole 0.998))
 
-	(let ((shape-data (make-float-vector (* (length shps) tractlength+8) 0.0))
+	(let ((shape-data (make-float-vector (* (length shps) tractlength+8)))
 	      
 	      (noselength-1 (- noselength 1))
 	      (noselength-2 (- noselength 2))
@@ -114,10 +110,10 @@
 	      (last-sfd -1)
 	      (last-gfd -1)
 
-	      (glot-table (make-float-vector (+ 1 table-size) 0.0))
-	      (glot-table2 (make-float-vector (+ 1 table-size) 0.0))
-	      ;; (gn-table (make-float-vector (+ 1 table-size) 0.0)) ;(gn-gain 0.0) ;(gn-out 0.0) ;(gn-del (make-float-vector 4 0.0))
-	      ;; (gn-coeffs (make-float-vector 4 0.0)) ; in Perry's C code, these were set in setGlotNoiseFilter but it was never called!
+	      (glot-table (make-float-vector (+ 1 table-size)))
+	      (glot-table2 (make-float-vector (+ 1 table-size)))
+	      ;; (gn-table (make-float-vector (+ 1 table-size))) ;(gn-gain 0.0) ;(gn-out 0.0) ;(gn-del (make-float-vector 4))
+	      ;; (gn-coeffs (make-float-vector 4)) ; in Perry's C code, these were set in setGlotNoiseFilter but it was never called!
 	      (table-increment 0.0)
 	      (glot-refl-gain 0.7)
 	      (pitch 400.0)
@@ -135,9 +131,9 @@
 	      (inz1 0.0)
 	      (inz2 0.0)
 	      ;; nasal tract acoustic tube structure
-	      (nose-coeffs (make-float-vector noselength 0.0))
-	      (nose1 (make-float-vector noselength 0.0))
-	      (nose2 (make-float-vector noselength 0.0))
+	      (nose-coeffs (make-float-vector noselength))
+	      (nose1 (make-float-vector noselength))
+	      (nose2 (make-float-vector noselength))
 	      (velum-pos 0.0)
 	      (nose-last-minus-refl 0.0)
 	      (nose-last-plus-refl 0.0)
@@ -172,19 +168,19 @@
 	      (alpha3 0.0)
 	      (noseposition 3)
 
-	      (target-radii (make-float-vector tractlength+8 0.0))
-	      (target-temp (make-float-vector tractlength+8 0.0))
-	      (radii-poles (make-float-vector tractlength+8 0.0))
-	      (radii-pole-gains (make-float-vector tractlength+8 0.0))
-	      (radii (make-float-vector tractlength+8 0.0))
+	      (target-radii (make-float-vector tractlength+8))
+	      (target-temp (make-float-vector tractlength+8))
+	      (radii-poles (make-float-vector tractlength+8))
+	      (radii-pole-gains (make-float-vector tractlength+8))
+	      (radii (make-float-vector tractlength+8))
 					; the radii array contains the vocal tract section radii
 					; (tractlength-1 of them), then glottal reflection gain
 					; then lip reflection gain, then noise position, then noise gain,
 					; then noise pole angle, then noise pole radius, 
 					; then noise pole angle2, then noise pole radius2, then velum opening radius
-	      (coeffs (make-float-vector tractlength 0.0))
-	      (dline1 (make-float-vector tractlength 0.0))
-	      (dline2 (make-float-vector tractlength 0.0)))
+	      (coeffs (make-float-vector tractlength))
+	      (dline1 (make-float-vector tractlength))
+	      (dline2 (make-float-vector tractlength)))
 
 	  (set! noisev (mus-xcoeffs noisef))
 
@@ -236,8 +232,8 @@
 	  (let ((harms (floor (glot-datai 1)))
 		(temp1 0.0)
 		(temp 0.0)
-		(sines (make-float-vector 200 0.0))
-		(cosines (make-float-vector 200 0.0))
+		(sines (make-float-vector 200))
+		(cosines (make-float-vector 200))
 		(one-over-two-pi  0.159154943)
 		(two-pi-over-table-size (/ two-pi table-size))
 		(a (glot-datar 0))
@@ -256,7 +252,7 @@
 		      (set! (sines 1) (* (+ ca2 (* (- sa2 (sin b2)) temp)) temp1 one-over-two-pi))
 		      (set! (cosines 1) (* (- (* (- ca2 (cos b2)) temp) sa2) temp1 one-over-two-pi))))
 		(set! (sines 1) (+ (sines 1) (* (- (+ 0.75 (* (cos (* 2 a2)) 0.25)) ca2) one-over-two-pi)))
-		(set! (cosines 1) (+ (cosines 1) (- (* (- sa2 (* (sin (* 2 a2)) 0.25)) one-over-two-pi) (* a 0.5))))
+		(set! (cosines 1) (- (+ (cosines 1) (* (- sa2 (* (sin (* 2 a2)) 0.25)) one-over-two-pi)) (* a 0.5)))
 		(do ((k 2 (+ k 1))
 		     (ka2 (* 2 a2) (+ ka2 a2))
 		     (ka1 a2 (+ ka1 a2))
@@ -272,7 +268,7 @@
 				     (/ (* (- (cos ka1) 1.0) 0.5) (- k 1))
 				     (/ (* (- (cos ka3) 1.0) 0.5) (+ k 1))))
 		  (set! (sines k) (* (sines k) one-over-two-pi))
-		  (set! (cosines k) (+ (cosines k) (- (/ (sin ka2) k) (/ (* (sin ka1) 0.5) (- k 1)) (/ (* (sin ka3) 0.5) (+ k 1)))))
+		  (set! (cosines k) (- (+ (cosines k) (/ (sin ka2) k)) (/ (* (sin ka1) 0.5) (- k 1)) (/ (* (sin ka3) 0.5) (+ k 1))))
 		  (set! (cosines k) (* (cosines k) one-over-two-pi)))
 		(fill! glot-table 0.0)
 		(do ((j 0 (+ j 1))
@@ -355,30 +351,26 @@
 		    (r (radii (+ tractlength 4)))
 		    (t2 (radii (+ tractlength 5)))
 		    (r2 (radii (+ tractlength 6))))
-		(let (;; fricative noise generator (set noise angle and radius)
-		      (noise-angle (hz->radians temp1))
-		      (noise-angle2 (hz->radians t2))
-		      (noise-radius r)
-		      (noise-radius2 r2))
-		  (let ((noise-a (* -2.0 (cos (/ noise-angle formant-shift)) noise-radius))
-			(noise-b (* noise-radius noise-radius))
-			(noise-a2 (* -2.0 (cos (/ noise-angle2 formant-shift)) noise-radius2))
-			(noise-b2 (* noise-radius2 noise-radius2)))
+		(let ((noise-angle (hz->radians temp1))     ; fricative noise generator (set noise angle and radius)
+		      (noise-angle2 (hz->radians t2)))
+		  (let ((noise-a (* -2.0 (cos (/ noise-angle formant-shift)) r))
+			(noise-b (* r r))
+			(noise-a2 (* -2.0 (cos (/ noise-angle2 formant-shift)) r2))
+			(noise-b2 (* r2 r2)))
 		    (set! (noisev 0) (+ noise-a noise-a2))
 		    (set! (noisev 1) (+ noise-b noise-b2 (* noise-a noise-a2)))
 		    (set! (noisev 2) (+ (* noise-a2 noise-b) (* noise-b2 noise-a)))
 		    (set! (noisev 3) (* noise-b2 noise-b)))))
-	      
+
 	      (set! lip-radius (radii tractlength-2))
 	      (set! velum-pos (radii (+ tractlength 7)))
 	      (let ((leftradius (radii (- noseposition 2)))
-		    (velumradius velum-pos)
 		    (rightradius (radii (- noseposition 1))))
-		  (let ((temp (max (- rightradius velumradius) 0.0)))
+		  (let ((temp (max (- rightradius velum-pos) 0.0)))
 		    ;; nasal tract (set nasal shape)
 		    (set! alpha1 (* leftradius leftradius))
 		    (set! alpha2 (* temp temp)))
-		  (set! alpha3 (* velumradius velumradius)))
+		  (set! alpha3 (* velum-pos velum-pos)))
 	      (let ((temp1 (/ 2.0 (+ alpha1 alpha2 alpha3))))
 		(set! alpha1 (* alpha1 temp1))
 		(set! alpha2 (* alpha2 temp1))
@@ -416,7 +408,7 @@
 	      (set! lt1 (one-pole lp (+ (dline1 2) temp)))
 
 	      (set! (dline2 1) (+ temp (* (coeffs 1) (- glotsamp temp))))
-	      (set! temp (+ glotsamp (- (dline2 1) temp)))
+	      (set! temp (- (+ glotsamp (dline2 1)) temp))
 	      (set! temp (singer-filter 1 noseposition temp dline1 dline2 coeffs))
 #|
 	      (let ((x 0.0))
@@ -492,7 +484,7 @@
 |#
 
 	      (set! (dline2 tractlength-1) (+ last-lip-refl (* (coeffs tractlength-1) (- (dline1 tractlength-2) last-lip-refl))))
-	      (set! (dline1 tractlength-1) (+ (dline1 tractlength-2) (- (dline2 tractlength-1) last-lip-refl)))
+	      (set! (dline1 tractlength-1) (- (+ (dline1 tractlength-2) (dline2 tractlength-1)) last-lip-refl))
 	      (set! (dline1 tractlength-2) temp)
 	      (if (not (= noise-gain 0.0))
 		  (begin
