@@ -296,6 +296,15 @@
 				(flatten (cdr lst1) (cdr lst2) args)))))
      ,@body))
 
+#|
+;; kinda ugly!
+(define-macro (and-map func args)
+  `(let and-map-loop ((args ,args))
+     (or (null? args)
+	 (and (eval (list ,func (car args)))
+	      (and-map-loop (cdr args))))))
+|#
+
 (define-macro (and-let* vars . body)      ; bind vars, if any is #f stop, else evaluate body with those bindings
   `(let () (and ,@(map (lambda (v) `(define ,@v)) vars) (begin ,@body))))
 
@@ -1397,7 +1406,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 	  (v (unique-reactive-let-name)))
 
       (define (rlet-symbol sym)
-	(string->symbol (string-append "{" (symbol->string sym) "}-rlet")))
+	(symbol "{" (symbol->string sym) "}-rlet"))
 
       (for-each 
        (lambda (bd)
@@ -1633,7 +1642,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 	   (make-shared-vector obj (list new-len) start))
 
           ((string? obj)
-           (if end
+           (if (integer? end)
                (substring obj start end)
                (substring obj start)))
 
