@@ -42,19 +42,14 @@
 	(set! in-glu #f))))
 
 (define (cadr-str data)
-  (let ((sp1 (char-position #\space data)))
-    (let ((sp2 (char-position #\space data (+ sp1 1))))
-      (if sp2
-	  (substring data (+ sp1 1) sp2)
-	  (substring data sp1)))))
+  (let* ((sp1 (char-position #\space data))
+	 (sp2 (char-position #\space data (+ sp1 1))))
+    (substring data (if sp2 (values (+ sp1 1) sp2) sp1))))
 
 (define (caddr-str data)
-  (let ((sp1 (char-position #\space data)))
-    (let ((sp2 (char-position #\space data (+ sp1 1))))
-      (let ((sp3 (char-position #\space data (+ sp2 1))))
-	(if sp3
-	    (substring data (+ sp2 1))
-	    (substring data sp2))))))
+  (let* ((sp2 (char-position #\space data (+ (char-position #\space data) 1)))
+	 (sp3 (char-position #\space data (+ sp2 1))))
+    (substring data (if sp3 (+ sp2 1) sp2))))
 
 (define (car-str data)
   (let ((sp (char-position #\space data)))
@@ -62,12 +57,6 @@
 	(substring data 0 sp)
 	data)))
 
-(define (cdr-str data)
-  (let ((sp (char-position #\space data)))
-    (if sp
-	(substring data (+ sp 1))
-	data)))
-
 (define (ref-arg? arg)
   (and (= (length arg) 3)
        (string? (caddr arg))))
@@ -103,34 +92,23 @@
     (substring type 0 (- (length type) 1))))
 
 (define (deref-name arg)
-  (let ((name (cadr arg)))
-    (string-append "ref_" name)))
-
-(define (derefable type)
-  (let ((len (length type)))
-    (call-with-exit
-     (lambda (return)
-       (do ((i (- len 1) (- i 1))
-	    (ctr 0 (+ 1 ctr)))
-	   ((= i 0) #f)
-	 (if (not (char=? (type i) #\*))
-	     (return (> ctr 1))))))))
+  (string-append "ref_" (cadr arg)))
 
 (define (has-stars type)
   (let ((len (length type)))
     (call-with-exit
      (lambda (return)
        (do ((i (- len 1) (- i 1)))
-	   ((= i 0) #f)
+	   ((= i 0))
 	 (if (char=? (type i) #\*)
 	     (return #t)))
        #f))))
 
 (define (no-stars type)
   (if (string=? type "Display*")
-      "Display"
+      (copy "Display")
       (if (string=? type "XVisualInfo*")
-	  "XVisualInfo"
+	  (copy "XVisualInfo")
 	  (let ((len (length type))
 		(val (string-copy type)))
 	    (do ((i 0 (+ i 1)))
@@ -138,16 +116,6 @@
 	      (if (char=? (val i) #\*)
 		  (set! (val i) #\_)))))))
 
-(define (no-arg-or-stars name)
-  (let ((len (length name)))
-    (call-with-exit
-     (lambda (return)
-       (do ((i 0 (+ i 1)))
-	   ((= i len) name)
-	 (if (or (char=? (name i) #\()
-		 (char=? (name i) #\*))
-	     (return (substring name 0 i))))))))
-
 (define* (parse-args args x)
   (let ((data ())
 	(sp -1)
@@ -158,41 +126,29 @@
 	(do ((i 0 (+ i 1)))
 	    ((= i len) (reverse data))
 	  (let ((ch (args i)))
-	    (if (or (char=? ch #\space)
-		    (= i (- len 1)))
-		(begin
-		  (if type
-		      (let ((given-name (substring args (+ 1 sp) (if (= i (- len 1)) (+ i 1) i)))
-			    (reftype #f))
-			(if (char=? (given-name 0) #\@)
-			    (set! data (cons (list type 
-						   (substring given-name 1 (length given-name))
-						   'null)
-					       data))
-			    (if (char=? (given-name 0) #\#)
-				(set! data (cons (list type 
-						       (substring given-name 1 (length given-name))
-						       'opt)
-						 data))
-				(if (char=? (given-name 0) #\[) 
-				    (begin
-				      (set! reftype (deref-type (list type)))
-				      (set! data (cons (list type 
-							     (substring given-name 1 (- (length given-name) 1))
-							     given-name) 
-						       data)))
-				    (set! data (cons (list type given-name) data)))))
-			(if reftype (set! type reftype))
-			(if (eq? x 'x)
-			    (if (not (member type x-types))
-				(set! x-types (cons type x-types)))
-			    (if (and (not (eq? x 'g))
-				     (not (member type types)))
-				(set! types (cons type types))))
-			(set! type #f))
-		      (if (> i (+ 1 sp))
-			  (set! type (substring args (+ 1 sp) i))))
-		  (set! sp i))))))))
+	    (when (or (char=? ch #\space)
+		      (= i (- len 1)))
+	      (if type
+		  (let ((reftype #f))
+		    (let ((given-name (substring args (+ 1 sp) (if (= i (- len 1)) (+ i 1) i))))
+		      (case (given-name 0)
+			((#\@) (set! data (cons (list type (substring given-name 1) 'null) data)))
+			((#\#) (set! data (cons (list type (substring given-name 1) 'opt) data)))
+			((#\[)
+			 (set! reftype (deref-type (list type)))
+			 (set! data (cons (list type (substring given-name 1 (- (length given-name) 1)) given-name) data)))
+			(else (set! data (cons (list type given-name) data)))))
+		    (if reftype (set! type reftype))
+		    (if (eq? x 'x)
+			(if (not (member type x-types))
+			    (set! x-types (cons type x-types)))
+			(if (not (or (eq? x 'g)
+				     (member type types)))
+			    (set! types (cons type types))))
+		    (set! type #f))
+		  (if (> i (+ 1 sp))
+		      (set! type (substring args (+ 1 sp) i))))
+	      (set! sp i)))))))
 
 (define (helpify name type args)
   (let* ((initial (format #f "  #define H_~A \"~A ~A(" name type name))
@@ -218,8 +174,7 @@
 		  (set! line-len (+ 1 line-len))
 		  (heyc " ")
 		  (set! typed #t)))
-	    (if (and (not (char=? ch #\@))
-		     (not (char=? ch #\#)))
+	    (if (not (memv ch '(#\@ #\#)))
 		(begin
 		  (set! line-len (+ 1 line-len))
 		  (heyc ch))))))
@@ -262,108 +217,99 @@
 		  "gluTessNormal" "gluTessProperty" "gluNewTess"))
 
 (define (c-to-xen-macro-name typ str)
-  (if (string=? str "INT") "C_int_to_Xen_integer"
-      (if (string=? str "DOUBLE") "C_double_to_Xen_real"
-	  (if (string=? str "BOOLEAN") "C_bool_to_Xen_boolean"
-	      (if (string=? str "ULONG") "C_ulong_to_Xen_ulong"
-		  (if (string-ci=? str "String")
-		      (if (string=? (car typ) "guchar*") 
-			  "C_to_Xen_String"
-			  "C_string_to_Xen_string")
-		      (format #f "~A unknown" str)))))))
+  (cond ((assoc str '(("INT"     . "C_int_to_Xen_integer")
+		      ("DOUBLE"  . "C_double_to_Xen_real") 
+		      ("BOOLEAN" . "C_bool_to_Xen_boolean")
+		      ("ULONG"   . "C_ulong_to_Xen_ulong"))
+		string=?) => cdr)
+	((not (string-ci=? str "String")) (format #f "~A unknown" str))
+	((string=? (car typ) "guchar*")   (copy "C_to_Xen_String"))
+	(else                             (copy "C_string_to_Xen_string"))))
 
 (define (xen-to-c-macro-name str)
-  (if (string=? str "INT") "Xen_integer_to_C_int"
-      (if (string=? str "DOUBLE") "Xen_real_to_C_double"
-	  (if (string=? str "BOOLEAN") "Xen_boolean_to_C_bool"
-	      (if (string=? str "ULONG") "Xen_ulong_to_C_ulong"
-		  (if (string-ci=? str "String")
-		      "Xen_string_to_C_string"
-		      (format #f "~A unknown" str)))))))
+  (cond ((assoc str '(("INT"     . "Xen_integer_to_C_int")
+		      ("DOUBLE"  . "Xen_real_to_C_double") 
+		      ("BOOLEAN" . "Xen_boolean_to_C_bool")
+		      ("ULONG"   . "Xen_ulong_to_C_ulong"))
+		string=?) => cdr)
+	((string-ci=? str "String") (copy "Xen_string_to_C_string"))
+	(else (format #f "~A unknown" str))))
 
 (define (type-it type)
-  (let ((typ (assoc type direct-types)))
-    (if typ
-	(if (cdr typ)
-	    (begin
-	      (if (string? (cdr typ))
-		  (begin
-		    (if (not (member (car typ)
-				     (list "Display*" "XVisualInfo*" "int*" "Pixmap" "Font" "GLubyte*"
-					   "GLdouble*" "GLfloat*" "GLvoid*" "GLuint*"
-					   "GLboolean*" "void*" "GLint*" "GLshort*"
-					   "GLsizei" "GLclampd" "GLclampf" "GLbitfield" "GLshort" "GLbyte"
-					   "unsigned_long"
-					   "void**")))
-			(if (string=? (car typ) "constchar*")
-			    (hey "#define C_to_Xen_~A(Arg) C_string_to_Xen_string((char *)(Arg))~%" (no-stars (car typ)))
-			    (hey "#define C_to_Xen_~A(Arg) ~A(Arg)~%" (no-stars (car typ)) (c-to-xen-macro-name typ (cdr typ)))))
-
-		    (if (not (string=? (car typ) "constchar*"))
-			(hey "#define Xen_to_C_~A(Arg) (~A)(~A(Arg))~%" (no-stars (car typ)) (car typ) (xen-to-c-macro-name (cdr typ))))
-
-		    (if (not (string=? (car typ) "constchar*"))
-			(hey "#define Xen_is_~A(Arg) Xen_is_~A(Arg)~%" 
-			     (no-stars (car typ))
-			     (if (string=? (cdr typ) "INT") 
-				 "integer" 
-				 (if (string=? (cdr typ) "ULONG")
-				     "ulong"
-				     (if (string=? (cdr typ) "DOUBLE")
-					 "number"
-					 (apply string (map char-downcase (cdr typ)))))))))
-		  (begin
-		    (hey "#define Xen_is_~A(Arg) 1~%" (no-stars (car typ)))
-		    (hey "#define Xen_to_C_~A(Arg) ((gpointer)Arg)~%" (no-stars (car typ)))))))
-
-	(if (not (or (string=? type "Display*")     ; why are these 2 handled specially?
-		     (string=? type "XVisualInfo*")
-		     (string=? type "GLXContext"))) ; Snd g_snd_gl_context (snd-motif.c) calls this a pointer
-	    (begin
-	      (if (member type glu-1-2) 
-		  (hey "#ifdef GLU_VERSION_1_2~%")
-		  (if (member type (list "GLUnurbs*" "GLUtesselator*" "GLUquadric*" "_GLUfuncptr"))
-		      (hey "#if HAVE_GLU~%")))
-	      (hey "XL_TYPE~A~A(~A, ~A)~%" 
-		   (if (has-stars type) "_PTR" "")
-		   (if (member type (list "int*" "Pixmap" "Font" "GLubyte*" 
-					  "GLdouble*" "GLfloat*" "GLvoid*" 
-					  "GLuint*" "GLboolean*" "GLint*" "GLshort*"
-					  "PangoFontDescription*" "GtkWidget*" "GdkGLConfigMode"
-					  ))
-		       "_1" 
-		       (if (member type (list "GdkVisual*" "PangoFont*" "GdkColormap*"))
-			   "_2" 
-			   ""))
-		   (no-stars type)
-		   type)
-	      (if (or (member type glu-1-2) 
-		      (member type (list "GLUnurbs*" "GLUtesselator*" "GLUquadric*" "_GLUfuncptr")))
-		  (hey "#endif~%")))
-	    (if (string=? type "Display*")
-		(hey "XL_TYPE_PTR(Display, Display*)~%")
-		(if (string=? type "XVisualInfo*")
-		    (hey "XL_TYPE_PTR(XVisualInfo, XVisualInfo*)~%")
-		    (hey "XL_TYPE_PTR(GLXContext, GLXContext)~%")
-		    ))))))
+  (cond ((assoc type direct-types) => 
+	 (lambda (typ)
+	   (when (cdr typ)
+	     (if (string? (cdr typ))
+		 (begin
+		   (if (not (member type
+				    '("Display*" "XVisualInfo*" "int*" "Pixmap" "Font" "GLubyte*"
+				      "GLdouble*" "GLfloat*" "GLvoid*" "GLuint*"
+				      "GLboolean*" "void*" "GLint*" "GLshort*"
+				      "GLsizei" "GLclampd" "GLclampf" "GLbitfield" "GLshort" "GLbyte"
+				      "unsigned_long"
+				      "void**")))
+		       (if (string=? type "constchar*")
+			   (hey "#define C_to_Xen_~A(Arg) C_string_to_Xen_string((char *)(Arg))~%" (no-stars type))
+			   (hey "#define C_to_Xen_~A(Arg) ~A(Arg)~%" (no-stars type) (c-to-xen-macro-name typ (cdr typ)))))
+		   
+		   (unless (string=? type "constchar*")
+		     (hey "#define Xen_to_C_~A(Arg) (~A)(~A(Arg))~%" (no-stars type) type (xen-to-c-macro-name (cdr typ)))
+		     (hey "#define Xen_is_~A(Arg) Xen_is_~A(Arg)~%" 
+			  (no-stars type)
+			  (cond ((assoc (cdr typ) '(("INT"    . "integer") 
+						    ("ULONG"  . "ulong") 
+						    ("DOUBLE" . "number")) string=?)
+				 => cdr)
+				(else (string-downcase (cdr typ)))))))
+		 (begin
+		   (hey "#define Xen_is_~A(Arg) 1~%" (no-stars type))
+		   (hey "#define Xen_to_C_~A(Arg) ((gpointer)Arg)~%" (no-stars type)))))))
+	
+	((not (member type '("Display*" "XVisualInfo*" "GLXContext") string=?))
+	 ;; Snd g_snd_gl_context (snd-motif.c) calls GLXContext a pointer
+	 (if (member type glu-1-2) 
+	     (hey "#ifdef GLU_VERSION_1_2~%")
+	     (if (member type '("GLUnurbs*" "GLUtesselator*" "GLUquadric*" "_GLUfuncptr"))
+		 (hey "#if HAVE_GLU~%")))
+	 (hey "XL_TYPE~A~A(~A, ~A)~%" 
+	      (if (has-stars type) "_PTR" "")
+	      (if (member type '("int*" "Pixmap" "Font" "GLubyte*" 
+				 "GLdouble*" "GLfloat*" "GLvoid*" 
+				 "GLuint*" "GLboolean*" "GLint*" "GLshort*"
+				 "PangoFontDescription*" "GtkWidget*" "GdkGLConfigMode"))
+		  "_1" 
+		  (if (member type '("GdkVisual*" "PangoFont*" "GdkColormap*"))
+		      "_2" 
+		      ""))
+	      (no-stars type)
+	      type)
+	 (if (or (member type glu-1-2) 
+		 (member type '("GLUnurbs*" "GLUtesselator*" "GLUquadric*" "_GLUfuncptr")))
+	     (hey "#endif~%")))
+	
+	((string=? type "Display*")
+	 (hey "XL_TYPE_PTR(Display, Display*)~%"))
+	
+	((string=? type "XVisualInfo*")
+	 (hey "XL_TYPE_PTR(XVisualInfo, XVisualInfo*)~%"))
+	
+	(else (hey "XL_TYPE_PTR(GLXContext, GLXContext)~%"))))
 
 (define* (CFNC data spec spec-name)
   (let ((name (cadr-str data))
 	(args (caddr-str data)))
     (if (assoc name names)
-	(format #t "~A CFNC~%" name)
+	(format () "~A CFNC~%" name)
 	(let ((type (car-str data)))
 	  (if (not (member type types))
 	      (set! types (cons type types)))
 	  (let ((strs (parse-args args)))
-	    (if spec
-		(set! funcs (cons (list name type strs args spec spec-name) funcs))
-		(set! funcs (cons (list name type strs args) funcs)))
+	    (set! funcs (cons (list name type strs (if spec (values args spec spec-name) args)) funcs))
 	    (set! names (cons (cons name 'fnc) names)))))))
 
 (define* (CINT name type)
   (if (assoc name names)
-      (format #t "~A CINT~%" name)
+      (format () "~A CINT~%" name)
       (begin
 	(set! ints (cons name ints))
 	(set! names (cons (cons name 'int) names)))))
@@ -372,32 +318,21 @@
   (let ((name (cadr-str data))
 	(args (caddr-str data)))
     (if (assoc name names)
-	(format #t "~A CFNC-X~%" name)
+	(format () "~A CFNC-X~%" name)
 	(let ((type (car-str data)))
 	  (if (not (member type x-types))
 	      (set! x-types (cons type x-types)))
 	  (let ((strs (parse-args args 'x)))
-	    (if spec
-		(set! x-funcs (cons (list name type strs args spec spec-name) x-funcs))
-		(set! x-funcs (cons (list name type strs args) x-funcs)))
+	    (set! x-funcs (cons (list name type strs (if spec (values args spec spec-name) args)) x-funcs))
 	    (set! names (cons (cons name 'fnc) names)))))))
 
 (define* (CINT-X name type)
   (if (assoc name names)
-      (format #t "~A CINT-X~%" name)
+      (format () "~A CINT-X~%" name)
       (begin
 	(set! x-ints (cons name x-ints))
 	(set! names (cons (cons name 'int) names)))))
 
-(define (no-arg name)
-  (let ((len (length name)))
-    (call-with-exit
-     (lambda (return)
-       (do ((i 0 (+ i 1)))
-	   ((= i len) name)
-	 (if (char=? (name i) #\()
-	     (return (substring name 0 i))))))))
-
 ;;; ---------------------------------------- read data ---------------------------------------- 
 
 (load "gldata.scm")
@@ -568,14 +503,14 @@
    (let* ((name (car data))
 	  (return-type (cadr data))
 	  (args (caddr data))
-	  (cargs (length args))
+	  (argslen (length args))
+	  (cargs argslen)
 	  (refargs (ref-args args))
 	  (xgargs (- cargs refargs))
 	  (argstr (cadddr data))
 	  ;(lambda-type (cdr (assoc name names)))
 	  (arg-start 0)
-	  (line-len 0)
-	  (line-max 120))
+	  (line-len 0))
 
      (define (hey-start)
        ;; start of checked line
@@ -595,12 +530,9 @@
        ;; cr ok after arg
        (set! line-len (+ line-len (length arg)))
        (heyc arg)
-       (if (> line-len line-max)
+       (if (> line-len 120)
 	   (begin
-	     (hey "~%")
-	     (do ((i 0 (+ i 1)))
-		 ((= i arg-start))
-	       (heyc " "))
+	     (format gl-file "~%~NC" arg-start #\space)
 	     (set! line-len arg-start))))
 
      (check-glu name)
@@ -610,9 +542,9 @@
 	      (eq? (data 4) 'if))
 	 (hey "#if HAVE_~A~%" (string-upcase (symbol->string (data 5)))))
      (hey "static Xen gxg_~A(" name)
-     (if (= (length args) 0)
+     (if (null? args)
 	 (heyc "void")
-	 (if (>= (length args) max-args)
+	 (if (>= argslen max-args)
 	     (heyc "Xen arglist")
 	     (let ((previous-arg #f))
 	       (for-each 
@@ -634,7 +566,7 @@
 		    (hey "  ~A ~A[16];~%" (deref-type arg) (deref-name arg))
 		    (hey "  ~A ~A[1];~%" (deref-type arg) (deref-name arg)))))
 	  args))
-     (if (and (>= (length args) max-args)
+     (if (and (>= argslen max-args)
 	      (> xgargs 0))
 	 (let ((previous-arg #f))
 	   (heyc "  Xen ")
@@ -654,7 +586,7 @@
 		    (hey "  ~A = Xen_list_ref(arglist, ~D);~%" (cadr arg) ctr))
 		(set! ctr (+ 1 ctr)))
 	      args))))
-     (if (> (length args) 0)
+     (if (> argslen 0)
 	 (let ((ctr 1))
 	   (for-each
 	    (lambda (arg)
@@ -673,23 +605,23 @@
 				 (no-stars argtype) argname argname ctr name argtype))))
 		(set! ctr (+ 1 ctr))))
 	    args)))
-     (let ((using-result #f))
-       (set! using-result (and (> refargs 0)
-			       (not (string=? return-type "void"))))
+     (let ((using-result (and (> refargs 0)
+			      (not (string=? return-type "void")))))
        (if using-result
 	   (begin
 	     (hey "  {~%")
 	     (hey "    Xen result;~%")))
        (hey-start)
-       (if (not (string=? return-type "void"))
-	   (if (= refargs 0)
-	       (hey-on "  return(C_to_Xen_~A(" (no-stars return-type))
-	       (hey-on "    result = C_to_Xen_~A(" (no-stars return-type)))
-	   (hey-on "  "))
+       (if (string=? return-type "void")
+	   (hey-on "  ")
+	   (hey-on (if (= refargs 0)
+		       "  return(C_to_Xen_~A("
+		       "    result = C_to_Xen_~A(")
+		   (no-stars return-type)))
 
        (hey-on "~A(" name)
        (hey-mark)
-       (if (> (length args) 0)
+       (if (> argslen 0)
 	   (let ((previous-arg #f))
 	     (for-each
 	      (lambda (arg)
@@ -717,13 +649,13 @@
 		   (hey "  {~%")
 		   (if (not using-result)
 		       (hey "    Xen result;~%"))
-		   (hey "    int i, vals;~%")
-		   (hey "    vals = how_many_vals(Xen_to_C_GLenum(pname));~%")
-		   (hey "    result = Xen_empty_list;~%")
-		   (hey "    for (i = 0; i < vals; i++)~%")
+		   (hey "    int i, vals;~%    ~
+                             vals = how_many_vals(Xen_to_C_GLenum(pname));~%    ~
+		             result = Xen_empty_list;~%    ~
+                             for (i = 0; i < vals; i++)~%")
 		   (hey "      result = Xen_cons(C_to_Xen_~A(~A[i]), result);~%" 
-			(no-stars (deref-type (args (- (length args) 1))))
-			(deref-name (args (- (length args) 1))))
+			(no-stars (deref-type (args (- argslen 1))))
+			(deref-name (args (- argslen 1))))
 		   (hey "    return(result);~%")
 		   (hey "  }~%"))
 		 (begin
@@ -763,21 +695,22 @@
 
 (define (argify-func func)
   (let ((cargs (length (caddr func)))
-	(name (car func))
 	(refargs (+ (ref-args (caddr func)) (opt-args (caddr func))))
 	;(args (- cargs refargs))
 	(if-fnc (and (> (length func) 4)
 		     (eq? (func 4) 'if))))
-    (check-glu name)
-    (if (member name glu-1-2) (hey "#ifdef GLU_VERSION_1_2~%"))
+    (let ((name (car func)))
+      (check-glu name)
+      (if (member name glu-1-2) (hey "#ifdef GLU_VERSION_1_2~%")))
     (if if-fnc
 	(hey "#if HAVE_~A~%" (string-upcase (symbol->string (func 5)))))
     (hey "Xen_wrap_~A(gxg_~A_w, gxg_~A)~%" 
 	 (if (>= cargs max-args) 
 	     "any_args"
-	     (if (> refargs 0)
-		 (format #f "~D_optional_arg~A" cargs (if (= cargs 1) "" "s"))
-		 (format #f "~A_arg~A" (if (zero? cargs) "no" (number->string cargs)) (if (= cargs 1) "" "s"))))
+	     (format #f (values (if (> refargs 0)
+				    (values "~D_optional_arg~A" cargs)
+				    (values "~A_arg~A" (if (zero? cargs) "no" (number->string cargs))))
+				(if (= cargs 1) "" "s"))))
 	 (car func) (car func))
     (if if-fnc
 	(hey "#endif~%"))
@@ -796,23 +729,23 @@
 
 (define (gtk-type->s7-type gtk)
   (let ((dt (assoc gtk direct-types)))
-    (if (and (pair? dt)
-	     (string? (cdr dt)))
+    (or (not (and (pair? dt)
+		  (string? (cdr dt))))
 	(let ((direct (cdr dt)))
 	  (cond ((member direct '("INT" "ULONG") string=?) 'integer?)
-		((string=? direct "BOOLEAN")               'boolean?)
-		((string=? direct "DOUBLE")                'real?)
-		((string=? direct "CHAR")                  'char?)
-		((string=? direct "String")                'string?)
-		(#t #t)))
-	#t)))
+		((assoc direct '(("BOOLEAN" . boolean?) 
+				 ("DOUBLE"  . real?) 
+				 ("CHAR"    . char?) 
+				 ("String"  . string?))
+			string=?) => cdr)
+		(#t #t))))))
 	       
 (define (make-signature fnc)
   (define (compress sig)
     (if (and (pair? sig)
 	     (pair? (cdr sig))
-	     (or (not (eq? (car sig) 'pair?))
-		 (not (null? (cddr sig))))
+	     (not (and (eq? (car sig) 'pair?)
+		       (null? (cddr sig))))
 	     (eq? (car sig) (cadr sig)))
 	(compress (cdr sig))
 	sig))
@@ -830,9 +763,7 @@
      (let ((sig (make-signature f)))
        (if (pair? sig)
 	   (let ((count (signatures sig)))
-	     (if (not count)
-		 (set! (signatures sig) 0)
-		 (set! (signatures sig) (+ count 1)))))))
+	     (set! (signatures sig) (if (not (real? count)) 0 (+ count 1)))))))
    lst))
 
 (make-signatures funcs)
@@ -915,14 +846,14 @@
     (if (member name glu-1-2) (hey "#ifdef GLU_VERSION_1_2~%"))
 
     (hey "  gl_define_procedure(~A, gxg_~A_w, ~D, ~D, ~D, H_~A, ~A);~%"
-		     (car func) (car func) 
+		     name name
 		     (if (>= cargs max-args) 0 args)
 		     (if (>= cargs max-args) 0 refargs) ; optional ignored
 		     (if (>= cargs max-args) 1 0)
-		     (car func)
+		     name
 		     (sig-name (make-signature func)))
 
-    (if (member (car func) glu-1-2) (hey "#endif~%"))
+    (if (member name glu-1-2) (hey "#endif~%"))
     ))
 
 (hey "#if USE_MOTIF~%")
@@ -964,11 +895,7 @@
    (hey "  DEFINE_INTEGER(~A);~%" val)) 
  (reverse ints))
 
-(if in-glu
-    (begin
-      (hey "#endif~%")
-      (set! in-glu #f)))
-
+(uncheck-glu)
 
 (hey "}~%~%")
 
