@@ -35,7 +35,7 @@
 (define-constant constants (list #f #t () #\a (/ most-positive-fixnum) (/ -1 most-positive-fixnum) 1.5+i
 			"hi455" :key hi: 'hi (list 1) (list 1 2) (cons 1 2) (list (list 1 2)) (list (list 1)) (list ()) #() 
 			1/0+i 0+0/0i 0+1/0i 1+0/0i 0/0+0i 0/0+0/0i 1+1/0i 0/0+i cons ''2 
-			1+i 1+1e10i 1e15+1e15i 0+1e18i 1e18 (integer->char 255) (string (integer->char 255)) 1e308 
+			1+i 1+1e10i 1e15+1e15i 0+1e18i 1e18 #\xff (string #\xff) 1e308 
 			most-positive-fixnum most-negative-fixnum (- most-positive-fixnum 1) (+ most-negative-fixnum 1)
 			-1 0 0.0 1 1.5 1.0-1.0i 3/4 #\null -63 (make-hash-table) (hash-table '(a . 2) '(b . 3))
 			'((1 2) (3 4)) '((1 (2)) (((3) 4))) "" (list #(1) "1") '(1 2 . 3) (list (cons 'a 2) (cons 'b 3))
@@ -46,12 +46,12 @@
 			quasiquote macroexpand begin let letrec* if case cond (call-with-exit (lambda (goto) goto))
 			(with-baffle (call/cc (lambda (cc) cc)))
 			(string #\a #\null #\b) #2d((1 2) (3 4)) (inlet 'a 2 'b 3)
-			#<undefined> #<unspecified> (make-int-vector 3 0) (make-float-vector 3 -1.4)
+			#<undefined> #<unspecified> (make-int-vector 3) (make-float-vector 3 -1.4)
 			(make-vector '(2 3) "hi") #("hiho" "hi" "hoho") (make-shared-vector (make-int-vector '(2 3) 1) '(6))
 			(make-shared-vector (make-shared-vector (make-float-vector '(2 3) 1.0) '(6)) '(2 2))
 			(vector-ref #2d((#(1 2 3)) (#(3 4 5))) 0 0) (define-macro (m a) `(+ ,a 1))
 			(c-pointer 0) (c-pointer -1) :readable :else (define-bacro* (m (a 1)) `(+ ,a 1))
-			(byte-vector 0 1 2) (byte-vector) (byte-vector 255 0 127) (make-iterator (vector '(a . 2)))
+			(byte-vector 0 1 2) (byte-vector) (byte-vector 255 0 127) (make-iterator #((a . 2)))
 			(lambda (dir) 1.0) (float-vector) (make-float-vector '(2 32)) 
 			'((a . 1)) #(1) '((((A . B) C . D) (E . F) G . H) ((I . J) K . L) (M . N) O . P)
 
@@ -181,25 +181,25 @@
 (define (test-sym sym)
   (if (and (not (memq sym baddies))
 	   (defined? sym))
-      (let ((f (symbol->value sym)))
-	(let ((argn (and (or (procedure? f) (let? f)) (arity f))))
-	  (if argn
-	      (let ((bottom (car argn))
-		    (top (min (cdr argn) max-args))
-		    (strname (symbol->string sym)))
-		(if (not (memq (strname 0) '(#\{ #\[ #\()))
-		    (begin
-		      (if (< top bottom)
-			  (format *stderr* ";~A (bottom: ~A, top: ~A)...~%" sym bottom top))
-		      ;(format *stderr* ";~A...~%" sym)
-		      (set! low bottom)
-		      (if (positive? (cdr argn))
-			  (let ((sig (cond ((eq? sym 'append)
-					    (let ((lst (list 'list?)))
-					      (set-cdr! lst lst)))
-					   ((procedure-signature f) => copy))))
-			    (map-values sig)
-			    (autotest f () 0 top (if (pair? sig) (cdr sig) ()))))))))))))
+      (let* ((f (symbol->value sym))
+	     (argn (and (or (procedure? f) (let? f)) (arity f))))
+	(if argn
+	    (let ((bottom (car argn))
+		  (top (min (cdr argn) max-args))
+		  (strname (symbol->string sym)))
+	      (if (not (memv (strname 0) '(#\{ #\[ #\()))
+		  (begin
+		    (if (< top bottom)
+			(format *stderr* ";~A (bottom: ~A, top: ~A)...~%" sym bottom top))
+					;(format *stderr* ";~A...~%" sym)
+		    (set! low bottom)
+		    (if (positive? (cdr argn))
+			(let ((sig (cond ((eq? sym 'append)
+					  (let ((lst (list 'list?)))
+					    (set-cdr! lst lst)))
+					 ((procedure-signature f) => copy))))
+			  (map-values sig)
+			  (autotest f () 0 top (if (pair? sig) (cdr sig) ())))))))))))
 
 (define (all)
   (let ((st (symbol-table)))
