@@ -293,9 +293,7 @@
 	   
 	   (if (and play output-to-file)
 	       (if to-snd
-		   (if *clm-player*
-		       (*clm-player* snd-output)
-		       (*default-player* snd-output))
+		   ((or *clm-player* *default-player*) snd-output)
 		   (*default-player* output-1)))
 
 	   (if (and to-snd output-to-file)
@@ -698,25 +696,17 @@
 (define ws-save-state 
   (let ((documentation "(ws-save-state filename) is an after-save-state-hook function that saves the current with-sound global settings"))
     (lambda (hook)
-      (let ((filename (hook 'name)))
-
-	(define (open-appending filename)
-	  (open-output-file filename "a"))
-    
-	(define close-appending close-output-port)
-    
-	(let ((fd (open-appending filename)))
-	  ;; fd is a Scheme port at this point (not an integer), so we can use format etc
-	  ;; should the save-state file load this file if it hasn't been loaded? (what path?)
-	  (format fd "~%~%;;; from ws.scm~%")
-	  (format fd "(if (defined? '*clm-srate*)~%")
-	  (format fd "    (begin~%")
-	  (format fd "      (set! *clm-srate* ~A)~%" *clm-srate*)
-	  (format fd "      (set! *clm-file-name* ~S)~%" *clm-file-name*)
-	  (format fd "      (set! *clm-channels* ~A)~%" *clm-channels*)
-	  (format fd "      (set! *clm-sample-type* ~A)~%" (mus-sample-type->string *clm-sample-type*))
-	  (format fd "      (set! *clm-header-type* ~A)))~%" (mus-header-type->string *clm-header-type*))
-	  (close-appending fd))))))
+      (let ((fd (open-output-file (hook 'name) "a")))
+	;; should the save-state file load this file if it hasn't been loaded? (what path?)
+	(format fd "~%~%;;; from ws.scm~%")
+	(format fd "(if (defined? '*clm-srate*)~%")
+	(format fd "    (begin~%")
+	(format fd "      (set! *clm-srate* ~A)~%" *clm-srate*)
+	(format fd "      (set! *clm-file-name* ~S)~%" *clm-file-name*)
+	(format fd "      (set! *clm-channels* ~A)~%" *clm-channels*)
+	(format fd "      (set! *clm-sample-type* ~A)~%" (mus-sample-type->string *clm-sample-type*))
+	(format fd "      (set! *clm-header-type* ~A)))~%" (mus-header-type->string *clm-header-type*))
+	(close-output-port fd)))))
 
 (if (not (memq ws-save-state (hook-functions after-save-state-hook)))
     (set! (hook-functions after-save-state-hook) (list ws-save-state)))
@@ -745,7 +735,7 @@ symbol: 'e4 for example.  If 'pythagorean', the frequency calculation uses small
 				  (and (> (length name) 2) 
 				       (char-numeric? (name 2))
 				       (name 2))))
-		 (base (modulo (+ 5 (- (char->integer base-char) (char->integer #\a))) 7)) ; c-based (diatonic) octaves
+		 (base (modulo (- (+ (char->integer base-char) 5) (char->integer #\a)) 7)) ; c-based (diatonic) octaves
 		 (sign (if (not sign-char) 0 (if (char=? sign-char #\f) -1 1)))
 		 (octave (if octave-char (- (char->integer octave-char) (char->integer #\0)) last-octave))
 		 (base-pitch (+ sign (case base ((0) 0) ((1) 2) ((2) 4) ((3) 5) ((4) 7) ((5) 9) ((6) 11))))
@@ -773,8 +763,7 @@ symbol: 'e4 for example.  If 'pythagorean', the frequency calculation uses small
 (define-macro (defgenerator struct-name . fields)
 
   (define (list->bindings lst)
-    (let* ((len (length lst))
-	   (nlst (make-list (* len 2))))
+    (let ((nlst (make-list (* (length lst) 2))))
       (do ((old lst (cdr old))
 	   (nsym nlst (cddr nsym)))
 	  ((null? old) nlst)
@@ -808,18 +797,18 @@ symbol: 'e4 for example.  If 'pythagorean', the frequency calculation uses small
 				(eq? (struct-name 3) :methods)
 				(struct-name 4))))))
     `(begin 
-       (define ,(string->symbol (string-append sname "?")) #f)
-       (define ,(string->symbol (string-append "make-" sname)) #f)
+       (define ,(symbol sname "?") #f)
+       (define ,(symbol "make-" sname) #f)
 
-       (let ((gen-type ',(string->symbol (string-append "+" sname "+")))
+       (let ((gen-type ',(symbol "+" sname "+"))
 	     (gen-methods (and ,methods (apply inlet ,methods))))
 	 
-	 (set! ,(string->symbol (string-append sname "?"))
+	 (set! ,(symbol sname "?")
 	       (lambda (obj)
 		 (and (let? obj)
 		      (eq? (obj 'mus-generator-type) gen-type))))
 
-	 (set! ,(string->symbol (string-append "make-" sname))
+	 (set! ,(symbol "make-" sname)
 	       (lambda* ,(map (lambda (n) 
 				(if (pair? n) n (list n 0.0)))
 			      fields)
